#line 2 "input_lexer.cc"

#line 4 "input_lexer.cc"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 5
#define YY_FLEX_SUBMINOR_VERSION 35
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#endif /* ! C99 */

#endif /* ! FLEXINT_H */

#ifdef __cplusplus

/* The "const" storage-class-modifier is valid. */
#define YY_USE_CONST

#else	/* ! __cplusplus */

/* C99 requires __STDC__ to be defined as 1. */
#if defined (__STDC__)

#define YY_USE_CONST

#endif	/* defined (__STDC__) */
#endif	/* ! __cplusplus */

#ifdef YY_USE_CONST
#define yyconst const
#else
#define yyconst
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an unsigned
 * integer for use as an array index.  If the signed char is negative,
 * we want to instead treat it as an 8-bit unsigned char, hence the
 * double cast.
 */
#define YY_SC_TO_UI(c) ((unsigned int) (unsigned char) c)

/* An opaque pointer. */
#ifndef YY_TYPEDEF_YY_SCANNER_T
#define YY_TYPEDEF_YY_SCANNER_T
typedef void* yyscan_t;
#endif

/* For convenience, these vars (plus the bison vars far below)
   are macros in the reentrant scanner. */
#define yyin yyg->yyin_r
#define yyout yyg->yyout_r
#define yyextra yyg->yyextra_r
#define yyleng yyg->yyleng_r
#define yytext yyg->yytext_r
#define yylineno (YY_CURRENT_BUFFER_LVALUE->yy_bs_lineno)
#define yycolumn (YY_CURRENT_BUFFER_LVALUE->yy_bs_column)
#define yy_flex_debug yyg->yy_flex_debug_r

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN yyg->yy_start = 1 + 2 *

/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START ((yyg->yy_start - 1) / 2)
#define YYSTATE YY_START

/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)

/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE giac_yyrestart(yyin ,yyscanner )

#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k.
 * Moreover, YY_BUF_SIZE is 2*YY_READ_BUF_SIZE in the general case.
 * Ditto for the __ia64__ case accordingly.
 */
#define YY_BUF_SIZE 32768
#else
#define YY_BUF_SIZE 16384
#endif /* __ia64__ */
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2

    #define YY_LESS_LINENO(n)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = yyg->yy_hold_char; \
		YY_RESTORE_YY_MORE_OFFSET \
		yyg->yy_c_buf_p = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up yytext again */ \
		} \
	while ( 0 )

#define unput(c) yyunput( c, yyg->yytext_ptr , yyscanner )

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	yy_size_t yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	int yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */
    
	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via giac_yyrestart()), so that the user can continue scanning by
	 * just pointing yyin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( yyg->yy_buffer_stack \
                          ? yyg->yy_buffer_stack[yyg->yy_buffer_stack_top] \
                          : NULL)

/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE yyg->yy_buffer_stack[yyg->yy_buffer_stack_top]

void giac_yyrestart (FILE *input_file ,yyscan_t yyscanner );
void giac_yy_switch_to_buffer (YY_BUFFER_STATE new_buffer ,yyscan_t yyscanner );
YY_BUFFER_STATE giac_yy_create_buffer (FILE *file,int size ,yyscan_t yyscanner );
void giac_yy_delete_buffer (YY_BUFFER_STATE b ,yyscan_t yyscanner );
void giac_yy_flush_buffer (YY_BUFFER_STATE b ,yyscan_t yyscanner );
void giac_yypush_buffer_state (YY_BUFFER_STATE new_buffer ,yyscan_t yyscanner );
void giac_yypop_buffer_state (yyscan_t yyscanner );

static void giac_yyensure_buffer_stack (yyscan_t yyscanner );
static void giac_yy_load_buffer_state (yyscan_t yyscanner );
static void giac_yy_init_buffer (YY_BUFFER_STATE b,FILE *file ,yyscan_t yyscanner );

#define YY_FLUSH_BUFFER giac_yy_flush_buffer(YY_CURRENT_BUFFER ,yyscanner)

YY_BUFFER_STATE giac_yy_scan_buffer (char *base,yy_size_t size ,yyscan_t yyscanner );
YY_BUFFER_STATE giac_yy_scan_string (yyconst char *yy_str ,yyscan_t yyscanner );
YY_BUFFER_STATE giac_yy_scan_bytes (yyconst char *bytes,int len ,yyscan_t yyscanner );

void *giac_yyalloc (yy_size_t ,yyscan_t yyscanner );
void *giac_yyrealloc (void *,yy_size_t ,yyscan_t yyscanner );
void giac_yyfree (void * ,yyscan_t yyscanner );

#define yy_new_buffer giac_yy_create_buffer

#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        giac_yyensure_buffer_stack (yyscanner); \
		YY_CURRENT_BUFFER_LVALUE =    \
            giac_yy_create_buffer(yyin,YY_BUF_SIZE ,yyscanner); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}

#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        giac_yyensure_buffer_stack (yyscanner); \
		YY_CURRENT_BUFFER_LVALUE =    \
            giac_yy_create_buffer(yyin,YY_BUF_SIZE ,yyscanner); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}

#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */

#define giac_yywrap(n) 1
#define YY_SKIP_YYWRAP

typedef unsigned char YY_CHAR;

typedef int yy_state_type;

#define yytext_ptr yytext_r

static yy_state_type yy_get_previous_state (yyscan_t yyscanner );
static yy_state_type yy_try_NUL_trans (yy_state_type current_state  ,yyscan_t yyscanner);
static int yy_get_next_buffer (yyscan_t yyscanner );
static void yy_fatal_error (yyconst char msg[] ,yyscan_t yyscanner );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up yytext.
 */
#define YY_DO_BEFORE_ACTION \
	yyg->yytext_ptr = yy_bp; \
	yyleng = (size_t) (yy_cp - yy_bp); \
	yyg->yy_hold_char = *yy_cp; \
	*yy_cp = '\0'; \
	yyg->yy_c_buf_p = yy_cp;

#define YY_NUM_RULES 430
#define YY_END_OF_BUFFER 431
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static yyconst flex_int16_t yy_accept[1316] =
    {   0,
        0,    0,   23,   23,    0,    0,    0,    0,    0,    0,
      431,  429,    1,    2,  192,    3,  427,  150,  244,  200,
       31,   96,   97,  221,  194,   94,  216,  224,  230,  400,
      400,   34,   32,   88,  147,   89,   29,  165,  425,  425,
      425,  295,  425,  425,  425,  425,   43,  425,  425,  425,
      425,  425,  425,  425,  425,  425,  425,  425,  425,   98,
       99,  252,   30,   16,  425,  425,  425,  425,  296,  425,
      425,  425,   38,  425,  425,  425,  425,  425,  425,  425,
      425,  425,  425,  425,  425,  425,  117,  177,  118,  201,
       41,  425,  425,  425,  425,  425,  429,  425,   23,   25,

       24,  430,  428,  430,   15,    6,    5,  430,   18,   17,
       19,    1,  134,    0,    0,    0,    0,    0,    0,    0,
        0,  151,  245,  232,  148,  426,  101,  102,    0,   45,
       44,  426,  119,  120,  171,  225,  235,  226,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,  255,  223,  195,  196,   95,
      100,  197,    0,  128,  198,  127,  227,  199,  218,  187,
      241,  421,  256,  231,   22,    0,  240,  116,  419,  400,
      401,    0,    0,    0,    0,    0,    0,   36,   35,  154,

        0,    0,    0,  125,  141,  136,  161,    0,  162,  129,
      160,  145,  126,  164,  166,  425,  425,  425,  425,  425,
      425,  425,  425,  425,  425,  366,  425,  425,  425,  425,
      425,  425,  425,  425,  425,  425,  425,  425,  313,  376,
      425,  425,  425,  425,  182,   50,  425,  425,   49,  425,
      425,  425,  425,  425,  425,  425,  425,  425,  425,  425,
      425,  253,  237,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,  425,  425,  425,
      425,  425,  285,  425,  425,  425,  425,  425,  367,  425,
      425,  425,  425,  425,  425,  425,  425,  425,  425,  425,

      425,   65,  312,  425,  425,  425,  425,  425,  425,  425,
      425,  425,  425,  337,  425,   47,  425,  425,  425,  425,
      425,  425,  425,  425,  425,  425,  425,  425,  425,  425,
      425,  425,  425,  425,  425,  425,  425,  425,  425,  425,
      425,  425,  115,  236,  178,   33,  425,  204,  205,  425,
       60,   39,   37,   48,  425,  425,  425,  425,  425,  425,
      425,    0,  425,   23,   24,   24,   26,    0,  428,   15,
        4,   14,    7,    8,   12,   13,    9,   11,   10,   18,
        0,    0,  411,  412,  410,  414,  413,  415,  246,  109,
      110,  103,  104,  121,  122,  234,  426,  107,  108,   46,

        0,    0,    0,    0,  152,  247,    0,    0,  228,  214,
      219,    0,  242,    0,  142,    0,    0,  149,    0,  144,
        0,  169,    0,  257,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,  131,  189,  422,
        0,  233,    0,   21,  419,  420,    0,    0,    0,  423,
        0,  417,  416,  418,  402,    0,    0,    0,    0,  239,
        0,  130,  238,  173,  193,  425,  425,  425,  389,  425,
      425,  425,  425,  425,  425,  425,  425,  425,  425,  307,
      380,  425,  425,  425,  425,  425,  425,  425,  425,  425,
      385,  425,  330,  425,  425,  425,  425,  425,  425,  425,

      425,  388,  425,  356,  425,  425,  425,  425,  425,  186,
        0,    0,    0,    0,    0,    0,  318,    0,    0,    0,
        0,    0,    0,  181,    0,    0,    0,    0,    0,    0,
        0,  425,  425,  425,  425,  425,  425,  425,  425,  425,
      425,  425,  425,  425,  425,  425,  425,  425,  425,  425,
      425,  425,  306,  425,  425,  425,  425,  425,  425,   55,
      425,  425,  425,  425,  323,  425,  425,  249,  332,  425,
      329,  425,  425,  425,  425,  425,  425,  425,  425,  425,
      254,  425,  425,  425,  425,  425,  425,  425,  425,  425,
      425,  425,  425,  425,  425,  425,  425,  425,  425,  425,

      425,  425,  425,  425,  425,  425,  425,  183,    0,  425,
       42,  213,  206,  207,  208,  209,  210,  211,  297,  159,
      394,  399,  217,  202,   53,  203,  395,  397,  396,  398,
      222,  158,  157,  212,   40,  298,    7,    8,    0,    0,
        0,    0,    0,  111,  112,  105,  106,  123,  124,    0,
       92,   90,  135,  248,  174,  190,  155,  139,  137,  132,
      146,  167,    0,    0,  317,    0,    0,    0,    0,    0,
      336,  180,    0,    0,    0,  179,    0,    0,  421,    0,
      420,    0,    0,    0,  419,    0,    0,  424,    0,  403,
        0,   20,    0,    0,    0,    0,  425,  291,  292,  425,

      425,  425,  425,  425,  425,  383,  425,  425,  378,  386,
      308,  425,  425,  425,  425,  425,  315,  322,  379,  425,
      425,  425,  425,  425,  425,  425,  425,  425,  425,  368,
      425,  363,  425,  425,  176,    0,    0,    0,    0,    0,
        0,    0,    0,    0,  251,    0,  334,    0,    0,    0,
        0,    0,    0,    0,  184,  425,  425,  425,  425,  425,
      425,  425,  425,  289,  425,  425,  425,  425,    0,  425,
      425,  425,  425,  425,  425,  425,  425,  425,  425,  425,
      425,  425,  425,  425,  314,  425,  425,  425,  425,  425,
       62,  425,  425,  425,    0,  425,  425,  425,  425,  425,

      425,   73,  425,  425,  425,  425,  425,  425,  425,  425,
      425,  354,  425,  355,  425,   63,   64,  425,  425,  425,
      358,  425,  425,  425,  425,  425,  425,  425,  425,  425,
      425,    0,  425,    7,    0,    0,  113,  114,    0,   93,
       91,  175,    0,    0,    0,    0,  250,  333,    0,    0,
      185,    0,  422,    0,    0,    0,  419,    0,    0,  420,
        0,    0,  374,  373,  375,  163,  290,  382,  293,  425,
      425,  425,  425,  425,  302,  425,  425,  425,  425,  425,
      425,  345,  384,  370,  425,  425,  425,  425,  392,  425,
      372,  365,  381,    0,    0,    0,    0,    0,    0,    0,

      143,    0,  229,  215,    0,    0,    0,    0,    0,    0,
      425,  425,  425,  425,  425,  425,  425,  425,  425,  425,
      425,  425,    0,    0,    0,  425,  299,  301,  300,  425,
      425,  425,  425,  425,  425,  425,  425,  425,  425,  425,
      425,  425,  425,  425,   70,   67,   66,  425,  425,  425,
        0,  425,  425,  425,  340,  425,  425,  425,  425,  425,
      425,  343,  425,  425,  425,  425,  425,  425,   85,  425,
      425,  425,  425,  425,  425,  425,  425,  425,  425,   59,
      425,  425,  425,  425,  364,    0,  425,   27,   28,    0,
      282,  316,    0,    0,    0,    0,    0,  420,    0,    0,

      425,  265,  387,  259,  425,  261,  425,  425,  425,  425,
      391,  349,  352,  425,  377,  425,  357,    0,    0,  133,
        0,  168,    0,    0,  328,  258,  191,    0,    0,    0,
      361,  425,  425,  425,  279,  283,  286,  425,  425,  425,
      325,   78,  294,  310,  309,    0,  425,  425,  303,  304,
      425,  425,  425,  425,  425,   69,  425,  425,  425,  425,
      425,  425,  425,  425,  425,  331,  272,  425,  339,  425,
      425,   76,   80,  425,  425,  425,  425,  347,  425,  425,
      350,  425,  425,  324,  425,  425,  359,  326,  425,   77,
      425,  425,  425,  425,  425,   54,   86,   87,    0,    0,

      327,    0,  360,  404,  425,  425,  425,  260,  262,  425,
      371,  425,  156,  243,    0,    0,    0,  153,    0,    0,
      425,  425,  425,  281,  284,  287,   81,  425,  425,    0,
      277,  425,  425,  338,   83,   74,  425,  425,  425,  425,
      425,  425,  425,   72,  425,  335,  425,  425,  425,  425,
      425,  425,  425,  348,  425,  425,  425,  425,  425,  266,
      425,  425,  425,   71,  362,    0,    0,  353,  405,  425,
      369,  263,  425,  425,  170,    0,  140,    0,  138,  425,
      425,  425,  425,  425,  311,  425,  305,   75,  425,  319,
      425,   52,  188,  425,  425,   61,  425,   57,  425,  425,

      280,  346,  351,  425,  425,  425,  425,  344,  425,  425,
        0,    0,    0,    0,  390,  264,  393,    0,  220,  425,
      425,  425,  288,  425,  425,  425,   79,  425,  425,   58,
      425,   84,  425,   68,  425,  425,  425,  425,  425,  172,
        0,  408,    0,  321,  425,  425,  425,  425,  425,  425,
      425,  425,  341,  425,  425,  425,  425,  425,  425,  320,
        0,  406,  425,  425,  269,  425,  425,   51,  425,  275,
      425,  425,  425,  425,  425,  425,    0,  407,  425,  268,
      273,  425,  425,  425,  425,   82,  425,   56,  425,  409,
      425,  425,  425,  278,  425,  425,  342,  425,  425,  425,

      425,  274,  425,  425,  425,  425,  425,  425,  271,  425,
      425,  276,  267,  270,    0
    } ;

static yyconst flex_int32_t yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        1,    1,    2,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    4,    5,    6,    7,    8,    9,   10,   11,   12,
       13,   14,   15,   16,   17,   18,   19,   20,   21,   22,
       23,   23,   23,   23,   23,   24,   24,   25,   26,   27,
       28,   29,   30,   31,   32,   33,   34,   35,   36,   37,
       38,   39,   40,   41,   42,   43,   44,   45,   46,   47,
       41,   48,   49,   50,   51,   52,   53,   54,   41,   41,
       55,   56,   57,   58,   59,   60,   61,   62,   63,   64,

       65,   66,   67,   68,   69,   41,   70,   71,   72,   73,
       74,   75,   76,   77,   78,   79,   80,   81,   82,   83,
       84,   41,   85,   86,   87,   88,    1,   89,   90,   91,
       92,   93,   94,   95,   41,   96,   97,   98,   41,   41,
       41,   41,   99,   41,   41,  100,   41,   41,   41,  101,
      102,   41,   41,  103,   41,   41,   41,  104,   41,  105,
      106,  107,   41,  108,  109,  110,  111,   41,   41,   41,
      112,   41,   41,   41,  113,  114,  115,  116,  117,  118,
      119,  120,  121,  122,  123,  124,   41,   41,   41,   41,
      125,   41,   41,  126,  127,   41,   41,   41,   41,   41,

       41,   41,   41,   41,   41,  128,  129,   41,   41,   41,
       41,   41,   41,   41,   41,   41,   41,   41,   41,   41,
       41,   41,   41,   41,   41,  130,   41,   41,   41,   41,
       41,   41,   41,   41,   41,   41,   41,  131,  132,   41,
       41,   41,   41,   41,   41,   41,   41,   41,   41,   41,
       41,   41,   41,   41,    1
    } ;

static yyconst flex_int32_t yy_meta[133] =
    {   0,
        1,    1,    2,    1,    1,    3,    1,    4,    4,    1,
        1,    1,    1,    5,    1,    1,    1,    1,    4,    6,
        6,    6,    6,    6,    1,    1,    1,    4,    1,    6,
        1,    7,    7,    7,    7,    7,    7,    7,    7,    7,
        7,    7,    7,    7,    7,    7,    7,    7,    7,    7,
        7,    7,    7,    7,    4,    3,    4,    1,    7,    8,
        7,    7,    7,    7,    7,    7,    7,    7,    7,    7,
        7,    7,    7,    7,    7,    7,    7,    7,    7,    7,
        7,    7,    7,    7,    4,    1,    4,    6,    7,    7,
        7,    7,    7,    7,    7,    7,    7,    7,    7,    7,

        7,    7,    7,    7,    7,    7,    7,    7,    7,    7,
        7,    7,    7,    7,    7,    7,    7,    7,    7,    7,
        7,    7,    7,    7,    7,    7,    7,    7,    7,    7,
        1,    7
    } ;

static yyconst flex_int16_t yy_base[1333] =
    {   0,
        0,    0,  130,  131,  132,  133,  134,  135,  136,  139,
     1973, 1974,  146, 1974, 1944, 1974,  188, 1974,  173,  146,
      267, 1974, 1974,  129,  134,  136,  136,  285,  152,  293,
      339,  150, 1974,  156,  217,  130, 1974,  243,  106, 1923,
      209,  302,  106,  121, 1896,  287,  140,    0, 1929,  124,
     1922, 1919,  326,  182,  191,  103, 1934,  161, 1919, 1974,
     1974,  205,  319, 1974,  330,  198,  114,  169,  337,  214,
      203, 1903,  279, 1898,  199,  257,  272, 1887,  352,  307,
      370,  350,  254,  192, 1893, 1886, 1940,  263, 1974, 1974,
        0,  325,  291,  188, 1869,  358, 1868, 1867,    0, 1974,

      351, 1952, 1974, 1974,    0, 1974, 1948,  440,    0, 1974,
     1974,  233, 1974, 1938, 1935,  446,  464,  513,  531,  451,
      580, 1974,  571, 1923, 1974,    0, 1974, 1974,  202,    0,
        0, 1881, 1974, 1974, 1974, 1974, 1974, 1974, 1877, 1869,
     1868, 1918, 1934,  345, 1934, 1932, 1931, 1930, 1922, 1928,
     1910,  447,  378,  416,  426, 1926,  351,  224,  369, 1862,
      426, 1870, 1861, 1859, 1846, 1974, 1974, 1974, 1974, 1974,
     1974, 1974, 1914, 1974, 1974, 1974, 1974, 1974, 1974, 1912,
     1974,  599, 1974, 1901, 1974, 1925, 1974, 1974,  627,  647,
      299,  616,  426,  501,  652, 1813, 1907, 1974, 1974, 1974,

     1845, 1847, 1843, 1894, 1974, 1974, 1974, 1850, 1974, 1892,
     1974, 1974, 1891,  519, 1974,    0, 1883, 1839, 1880, 1866,
     1869, 1842, 1849,  461, 1873,    0,  495, 1836, 1861, 1839,
     1859, 1829, 1826,  379, 1830, 1834, 1828, 1840, 1850,    0,
     1856, 1827, 1823, 1846,    0, 1852, 1846, 1813,    0, 1817,
      123,  414, 1809, 1852, 1839, 1805, 1808, 1838, 1845, 1815,
     1835, 1974, 1974,  509, 1813, 1805,  432,  525, 1815,  586,
     1805, 1801,  444, 1816,  451, 1803, 1801, 1803, 1806, 1797,
     1808, 1792,    0, 1806, 1794,  533, 1790, 1789,    0, 1801,
     1786, 1783,  483, 1791, 1786, 1791, 1779,  547, 1796, 1783,

     1785, 1974,  509,  506, 1790,  552, 1787, 1774, 1779, 1787,
     1783,  412, 1778,  492, 1774,    0,  579, 1768,  609, 1772,
     1768, 1771,  511, 1781, 1768, 1768, 1768, 1770,  482, 1765,
     1760, 1771, 1773, 1761, 1756, 1757,  618, 1766, 1767, 1752,
     1759, 1750, 1974, 1974, 1974,    0, 1822,    0,    0, 1699,
        0,    0,    0,    0,  579, 1711, 1723,  620,  501, 1720,
      583, 1728,  580,    0,  613,  690, 1974, 1817, 1974,    0,
     1974, 1974,  707,  713, 1974, 1974, 1974, 1974, 1974,    0,
     1804, 1801,  718, 1974, 1974,  767,  723,  785,  755, 1974,
     1974, 1974, 1974, 1974, 1974, 1974,    0, 1974, 1974,    0,

     1742, 1790, 1789, 1803, 1974, 1974, 1802, 1801, 1974, 1974,
     1974, 1800, 1974, 1799, 1974, 1798, 1797, 1974, 1796, 1974,
     1795, 1974, 1794, 1974, 1740, 1736,  643, 1723, 1728, 1736,
     1720, 1787, 1786, 1717, 1726, 1717, 1782, 1974, 1974,  625,
      837, 1974, 1789, 1974,  842,  711,  859,  869,  736,  772,
      889,  587,  749,  894,  803, 1788, 1717, 1722, 1715, 1974,
     1708, 1974, 1974,    0,    0, 1754, 1749, 1734,    0, 1712,
     1731, 1731, 1740, 1708, 1709, 1702, 1701, 1729, 1695,    0,
        0, 1699, 1722, 1704, 1698, 1702, 1691, 1694, 1730, 1722,
        0, 1689,    0, 1723, 1724, 1683, 1680, 1723, 1707, 1677,

     1676,    0, 1711, 1695, 1674, 1681, 1702, 1707, 1678,    0,
     1684, 1669, 1665, 1665, 1670, 1678, 1974, 1663,  255, 1668,
     1676, 1668, 1659, 1974, 1657, 1654, 1662, 1658, 1671,  641,
     1655, 1672, 1659, 1652,  699, 1648, 1657, 1663, 1650, 1592,
     1642, 1653, 1717, 1651, 1658, 1640, 1643, 1651,  647, 1637,
     1645, 1649,    0,  762, 1632, 1645, 1647, 1644, 1631, 1638,
     1641, 1630, 1639, 1624,    0, 1625, 1621,    0,    0, 1628,
     1695, 1639, 1620, 1627, 1630, 1615, 1615, 1637, 1618, 1606,
        0, 1627, 1621, 1623, 1621,  764, 1624, 1605, 1624, 1617,
     1616, 1625, 1624, 1546, 1612, 1601, 1597, 1542, 1608, 1601,

     1593, 1605, 1600, 1591, 1588, 1599, 1594,    0, 1534, 1553,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0, 1974,    0,    0,  847,  876, 1647, 1646,
     1643, 1642,  736, 1974, 1974, 1974, 1974, 1974, 1974, 1632,
     1629, 1628, 1974, 1974, 1974, 1974, 1974, 1974, 1974, 1974,
     1974, 1974, 1644, 1576, 1974, 1588, 1587, 1571, 1639, 1638,
     1974, 1974, 1568, 1573, 1635, 1974,  918,  899,  923,  946,
      749,  956,  967,  928,  973,  984,  989,  994, 1005, 1013,
     1642, 1974, 1581, 1571, 1579, 1615, 1598,    0,    0, 1574,

     1600, 1605, 1586, 1561, 1555,    0, 1598, 1584,    0,    0,
        0, 1560, 1555, 1560, 1556, 1560,    0,    0,    0, 1577,
     1589, 1559, 1548, 1590, 1573, 1555, 1542, 1586, 1577,    0,
     1551,    0, 1579, 1549, 1974, 1544, 1543, 1550, 1537, 1531,
     1543, 1531, 1528, 1525, 1974, 1525, 1974, 1525, 1537, 1534,
     1533, 1520, 1522, 1523, 1974, 1517, 1530, 1520, 1519, 1523,
     1530, 1518, 1513,    0, 1517, 1498, 1521, 1504,  770, 1513,
     1512, 1517, 1504, 1503, 1506, 1501, 1498, 1505, 1510, 1501,
     1508, 1497, 1500, 1491,    0, 1504, 1495, 1490, 1507, 1510,
      422, 1495, 1485, 1501, 1492, 1486, 1498, 1484, 1491, 1490,

     1496, 1974, 1475,  776, 1492, 1487,  688,  737, 1471, 1473,
     1494,    0, 1482,    0, 1474, 1974, 1974, 1457, 1484, 1485,
     1469, 1453, 1480, 1475, 1461, 1472, 1470, 1477, 1461, 1454,
     1468, 1436, 1405, 1018,  371,  758, 1974, 1974, 1520, 1974,
     1974, 1974, 1518, 1517, 1439, 1430, 1974, 1974, 1411, 1400,
     1974, 1023, 1028, 1038, 1048, 1053, 1058, 1068, 1073, 1078,
     1088, 1383, 1974, 1974, 1974, 1974,    0,    0,    0, 1424,
     1407, 1384, 1370, 1369,    0, 1377, 1336, 1327, 1344, 1324,
     1353,    0,    0,    0, 1352, 1356, 1322, 1326, 1355, 1352,
        0,    0,    0, 1329, 1331, 1323, 1330, 1313, 1314, 1310,

     1974, 1311, 1974, 1974, 1311, 1322, 1321, 1308, 1304, 1310,
     1305, 1322, 1297, 1301, 1305, 1304, 1311, 1295, 1309, 1279,
     1317, 1306, 1296, 1303, 1291, 1293,    0,    0,    0, 1307,
      172,  208,  235,  283,  482,  510,  571,  607,  656,  689,
      713,  742,  732,  754, 1974, 1974, 1974,  753,  794,  784,
      783,  802,  798,  812,    0,  807,  819,  839,  846,  839,
      849,    0,  851,  867,  857,  872,  876,  889, 1974,  884,
      886,  878,  910,  906,  906,  891,  922,  943,  931,    0,
      929,  945,  946,  953,    0,  926,  964, 1016, 1037, 1003,
     1974, 1974,  988, 1056, 1013, 1076, 1094, 1099, 1109,  988,

     1066,    0,    0,    0, 1025,    0, 1060, 1049, 1049, 1073,
        0,    0,    0, 1056,    0, 1096,    0, 1064, 1073, 1974,
     1078, 1974, 1062, 1080, 1974, 1974, 1974, 1069, 1083, 1084,
     1974, 1077, 1070, 1089, 1081, 1082, 1083, 1097, 1079, 1071,
        0, 1974,    0, 1974, 1974, 1081, 1083, 1090,    0,    0,
     1089, 1094, 1105, 1106, 1083, 1974, 1090, 1087, 1087, 1087,
     1106, 1097, 1114, 1101, 1105, 1974,    0, 1098,    0, 1100,
     1101, 1974, 1974, 1098, 1111, 1100, 1113,    0, 1102, 1107,
        0, 1108, 1113,    0, 1105, 1111,    0,    0, 1107, 1974,
     1119, 1122, 1113, 1134, 1125, 1974,    0,    0, 1119, 1127,

     1974, 1182, 1974, 1174, 1150, 1127, 1118,    0,    0, 1135,
        0, 1154, 1974, 1974, 1125, 1140, 1135, 1974, 1144, 1137,
     1142, 1149, 1139,    0,    0,    0, 1974, 1133, 1154, 1151,
        0, 1154, 1154,    0, 1974, 1974, 1162, 1153, 1141, 1151,
     1137, 1151, 1156, 1974, 1151,    0, 1148, 1163, 1161, 1163,
     1154, 1158, 1167,    0, 1167, 1170, 1168, 1167, 1170,    0,
     1164, 1174, 1174, 1974,    0, 1165, 1178, 1974, 1224, 1193,
        0,    0, 1184, 1200, 1974, 1188, 1974, 1173, 1974, 1194,
     1190, 1181, 1191, 1185, 1974, 1186,    0, 1974, 1204,    0,
     1187,    0,    0, 1196, 1196,    0, 1241,    0, 1209, 1187,

        0,    0,    0, 1212, 1199, 1204, 1196,    0, 1212, 1195,
     1247, 1195, 1255, 1191,    0,    0,    0, 1202, 1974, 1204,
     1214, 1220,    0, 1211, 1225, 1215, 1974, 1221, 1206,    0,
     1226, 1974, 1222, 1974, 1229, 1228, 1223, 1226, 1235, 1974,
     1286, 1278, 1186, 1974, 1230, 1244, 1241, 1243, 1231, 1248,
     1251, 1232,    0, 1241, 1254, 1235, 1250, 1243, 1238, 1974,
     1229, 1299, 1253, 1252,    0, 1261, 1258,    0, 1253,    0,
     1255, 1264, 1276, 1251, 1267, 1260, 1218, 1316, 1261,    0,
        0, 1281, 1269, 1271, 1271, 1974, 1281,    0, 1270, 1974,
     1269, 1287, 1268,    0, 1274, 1281,    0, 1284, 1284, 1291,

     1285,    0, 1284, 1294, 1283, 1300, 1289, 1285,    0, 1285,
     1287,    0,    0,    0, 1974, 1408, 1416, 1424, 1432, 1437,
     1439, 1446, 1454, 1462, 1470, 1478, 1486, 1488, 1495, 1503,
     1511, 1519
    } ;

static yyconst flex_int16_t yy_def[1333] =
    {   0,
     1315,    1, 1316, 1316, 1317, 1317, 1318, 1318, 1319, 1319,
     1315, 1315, 1315, 1315, 1315, 1315, 1315, 1315, 1320, 1315,
     1315, 1315, 1315, 1315, 1315, 1315, 1315, 1315, 1315, 1315,
     1315, 1315, 1315, 1315, 1315, 1315, 1315, 1315, 1321, 1321,
     1321, 1321, 1321, 1321, 1321, 1321, 1321, 1321, 1321, 1321,
     1321, 1321, 1321, 1321, 1321, 1321, 1321, 1321, 1321, 1315,
     1315, 1315, 1315, 1315, 1321, 1321, 1321, 1321, 1321, 1321,
     1321, 1321, 1321, 1321, 1321, 1321, 1321, 1321, 1321, 1321,
     1321, 1321, 1321, 1321, 1321, 1321, 1315, 1315, 1315, 1315,
     1321, 1321, 1321, 1321, 1321, 1321, 1315, 1321, 1322, 1315,

     1323, 1324, 1315, 1315, 1325, 1315, 1315, 1326, 1327, 1315,
     1315, 1315, 1315, 1315, 1315, 1315, 1315, 1315, 1315, 1315,
     1315, 1315, 1315, 1315, 1315, 1328, 1315, 1315, 1315, 1328,
     1328, 1328, 1315, 1315, 1315, 1315, 1315, 1315, 1315, 1315,
     1315, 1315, 1315, 1315, 1315, 1315, 1315, 1315, 1315, 1315,
     1315, 1315, 1315, 1315, 1315, 1315, 1315, 1315, 1315, 1315,
     1315, 1315, 1315, 1315, 1315, 1315, 1315, 1315, 1315, 1315,
     1315, 1315, 1315, 1315, 1315, 1315, 1315, 1315, 1315, 1315,
     1315, 1315, 1315, 1315, 1315, 1329, 1315, 1315, 1315, 1315,
     1315, 1315, 1315, 1315, 1315, 1315, 1315, 1315, 1315, 1315,

     1315, 1315, 1315, 1315, 1315, 1315, 1315, 1315, 1315, 1315,
     1315, 1315, 1315, 1315, 1315, 1321, 1321, 1321, 1321, 1321,
     1321, 1321, 1321, 1321, 1321, 1321, 1321, 1321, 1321, 1321,
     1321, 1321, 1321, 1321, 1321, 1321, 1321, 1321, 1321, 1321,
     1321, 1321, 1321, 1321, 1321, 1321, 1321, 1321, 1321, 1321,
     1321, 1321, 1321, 1321, 1321, 1321, 1321, 1321, 1321, 1321,
     1321, 1315, 1315, 1315, 1315, 1315, 1315, 1315, 1315, 1315,
     1315, 1315, 1315, 1315, 1315, 1315, 1315, 1321, 1321, 1321,
     1321, 1321, 1321, 1321, 1321, 1321, 1321, 1321, 1321, 1321,
     1321, 1321, 1321, 1321, 1321, 1321, 1321, 1321, 1321, 1321,

     1321, 1315, 1321, 1321, 1321, 1321, 1321, 1321, 1321, 1321,
     1321, 1321, 1321, 1321, 1321, 1321, 1321, 1321, 1321, 1321,
     1321, 1321, 1321, 1321, 1321, 1321, 1321, 1321, 1321, 1321,
     1321, 1321, 1321, 1321, 1321, 1321, 1321, 1321, 1321, 1321,
     1321, 1321, 1315, 1315, 1315, 1321, 1321, 1321, 1321, 1321,
     1321, 1321, 1321, 1321, 1321, 1321, 1321, 1321, 1321, 1321,
     1321, 1315, 1321, 1322, 1323, 1323, 1315, 1324, 1315, 1325,
     1315, 1315, 1315, 1315, 1315, 1315, 1315, 1315, 1315, 1327,
     1330, 1331, 1315, 1315, 1315, 1315, 1315, 1315, 1315, 1315,
     1315, 1315, 1315, 1315, 1315, 1315, 1328, 1315, 1315, 1328,

     1315, 1315, 1315, 1315, 1315, 1315, 1315, 1315, 1315, 1315,
     1315, 1315, 1315, 1315, 1315, 1315, 1315, 1315, 1315, 1315,
     1315, 1315, 1315, 1315, 1315, 1315, 1315, 1315, 1315, 1315,
     1315, 1315, 1315, 1315, 1315, 1315, 1315, 1315, 1315, 1315,
     1315, 1315, 1329, 1315, 1315, 1315, 1315, 1315, 1315, 1315,
     1315, 1315, 1315, 1315, 1315, 1332, 1315, 1315, 1315, 1315,
     1315, 1315, 1315, 1321, 1321, 1321, 1321, 1321, 1321, 1321,
     1321, 1321, 1321, 1321, 1321, 1321, 1321, 1321, 1321, 1321,
     1321, 1321, 1321, 1321, 1321, 1321, 1321, 1321, 1321, 1321,
     1321, 1321, 1321, 1321, 1321, 1321, 1321, 1321, 1321, 1321,

     1321, 1321, 1321, 1321, 1321, 1321, 1321, 1321, 1321, 1321,
     1315, 1315, 1315, 1315, 1315, 1315, 1315, 1315, 1315, 1315,
     1315, 1315, 1315, 1315, 1315, 1315, 1315, 1315, 1315, 1315,
     1315, 1321, 1321, 1321, 1321, 1321, 1321, 1321, 1321, 1321,
     1321, 1321, 1321, 1321, 1321, 1321, 1321, 1321, 1321, 1321,
     1321, 1321, 1321, 1321, 1321, 1321, 1321, 1321, 1321, 1321,
     1321, 1321, 1321, 1321, 1321, 1321, 1321, 1321, 1321, 1321,
     1321, 1321, 1321, 1321, 1321, 1321, 1321, 1321, 1321, 1321,
     1321, 1321, 1321, 1321, 1321, 1321, 1321, 1321, 1321, 1321,
     1321, 1321, 1321, 1321, 1321, 1321, 1321, 1321, 1321, 1321,

     1321, 1321, 1321, 1321, 1321, 1321, 1321, 1321, 1315, 1321,
     1321, 1321, 1321, 1321, 1321, 1321, 1321, 1321, 1321, 1321,
     1321, 1321, 1321, 1321, 1321, 1321, 1321, 1321, 1321, 1321,
     1321, 1321, 1321, 1315, 1321, 1321, 1315, 1315, 1330, 1330,
     1331, 1331, 1315, 1315, 1315, 1315, 1315, 1315, 1315, 1315,
     1315, 1315, 1315, 1315, 1315, 1315, 1315, 1315, 1315, 1315,
     1315, 1315, 1315, 1315, 1315, 1315, 1315, 1315, 1315, 1315,
     1315, 1315, 1315, 1315, 1315, 1315, 1315, 1315, 1315, 1315,
     1315, 1315, 1315, 1315, 1315, 1315, 1315, 1315, 1315, 1315,
     1332, 1315, 1315, 1315, 1315, 1315, 1321, 1321, 1321, 1321,

     1321, 1321, 1321, 1321, 1321, 1321, 1321, 1321, 1321, 1321,
     1321, 1321, 1321, 1321, 1321, 1321, 1321, 1321, 1321, 1321,
     1321, 1321, 1321, 1321, 1321, 1321, 1321, 1321, 1321, 1321,
     1321, 1321, 1321, 1321, 1315, 1315, 1315, 1315, 1315, 1315,
     1315, 1315, 1315, 1315, 1315, 1315, 1315, 1315, 1315, 1315,
     1315, 1315, 1315, 1315, 1315, 1321, 1321, 1321, 1321, 1321,
     1321, 1321, 1321, 1321, 1321, 1321, 1321, 1321, 1315, 1321,
     1321, 1321, 1321, 1321, 1321, 1321, 1321, 1321, 1321, 1321,
     1321, 1321, 1321, 1321, 1321, 1321, 1321, 1321, 1321, 1321,
     1321, 1321, 1321, 1321, 1315, 1321, 1321, 1321, 1321, 1321,

     1321, 1315, 1321, 1321, 1321, 1321, 1321, 1321, 1321, 1321,
     1321, 1321, 1321, 1321, 1321, 1315, 1315, 1321, 1321, 1321,
     1321, 1321, 1321, 1321, 1321, 1321, 1321, 1321, 1321, 1321,
     1321, 1315, 1321, 1315, 1330, 1331, 1315, 1315, 1315, 1315,
     1315, 1315, 1315, 1315, 1315, 1315, 1315, 1315, 1315, 1315,
     1315, 1315, 1315, 1315, 1315, 1315, 1315, 1315, 1315, 1315,
     1315, 1315, 1315, 1315, 1315, 1315, 1321, 1321, 1321, 1321,
     1321, 1321, 1321, 1321, 1321, 1321, 1321, 1321, 1321, 1321,
     1321, 1321, 1321, 1321, 1321, 1321, 1321, 1321, 1321, 1321,
     1321, 1321, 1321, 1315, 1315, 1315, 1315, 1315, 1315, 1315,

     1315, 1315, 1315, 1315, 1315, 1315, 1315, 1315, 1315, 1315,
     1321, 1321, 1321, 1321, 1321, 1321, 1321, 1321, 1321, 1321,
     1321, 1321, 1315, 1315, 1315, 1321, 1321, 1321, 1321, 1321,
     1321, 1321, 1321, 1321, 1321, 1321, 1321, 1321, 1321, 1321,
     1321, 1321, 1321, 1321, 1315, 1315, 1315, 1321, 1321, 1321,
     1315, 1321, 1321, 1321, 1321, 1321, 1321, 1321, 1321, 1321,
     1321, 1321, 1321, 1321, 1321, 1321, 1321, 1321, 1315, 1321,
     1321, 1321, 1321, 1321, 1321, 1321, 1321, 1321, 1321, 1321,
     1321, 1321, 1321, 1321, 1321, 1315, 1321, 1330, 1331, 1315,
     1315, 1315, 1315, 1315, 1315, 1315, 1315, 1315, 1315, 1315,

     1321, 1321, 1321, 1321, 1321, 1321, 1321, 1321, 1321, 1321,
     1321, 1321, 1321, 1321, 1321, 1321, 1321, 1315, 1315, 1315,
     1315, 1315, 1315, 1315, 1315, 1315, 1315, 1315, 1315, 1315,
     1315, 1321, 1321, 1321, 1321, 1321, 1321, 1321, 1321, 1321,
     1321, 1315, 1321, 1315, 1315, 1315, 1321, 1321, 1321, 1321,
     1321, 1321, 1321, 1321, 1321, 1315, 1321, 1321, 1321, 1321,
     1321, 1321, 1321, 1321, 1321, 1315, 1321, 1321, 1321, 1321,
     1321, 1315, 1315, 1321, 1321, 1321, 1321, 1321, 1321, 1321,
     1321, 1321, 1321, 1321, 1321, 1321, 1321, 1321, 1321, 1315,
     1321, 1321, 1321, 1321, 1321, 1315, 1321, 1321, 1315, 1315,

     1315, 1315, 1315, 1315, 1321, 1321, 1321, 1321, 1321, 1321,
     1321, 1321, 1315, 1315, 1315, 1315, 1315, 1315, 1315, 1315,
     1321, 1321, 1321, 1321, 1321, 1321, 1315, 1321, 1321, 1315,
     1321, 1321, 1321, 1321, 1315, 1315, 1321, 1321, 1321, 1321,
     1321, 1321, 1321, 1315, 1321, 1321, 1321, 1321, 1321, 1321,
     1321, 1321, 1321, 1321, 1321, 1321, 1321, 1321, 1321, 1321,
     1321, 1321, 1321, 1315, 1321, 1315, 1315, 1315, 1315, 1321,
     1321, 1321, 1321, 1321, 1315, 1315, 1315, 1315, 1315, 1321,
     1321, 1321, 1321, 1321, 1315, 1321, 1321, 1315, 1321, 1321,
     1321, 1321, 1321, 1321, 1321, 1321, 1321, 1321, 1321, 1321,

     1321, 1321, 1321, 1321, 1321, 1321, 1321, 1321, 1321, 1321,
     1315, 1315, 1315, 1315, 1321, 1321, 1321, 1315, 1315, 1321,
     1321, 1321, 1321, 1321, 1321, 1321, 1315, 1321, 1321, 1321,
     1321, 1315, 1321, 1315, 1321, 1321, 1321, 1321, 1321, 1315,
     1315, 1315, 1315, 1315, 1321, 1321, 1321, 1321, 1321, 1321,
     1321, 1321, 1321, 1321, 1321, 1321, 1321, 1321, 1321, 1315,
     1315, 1315, 1321, 1321, 1321, 1321, 1321, 1321, 1321, 1321,
     1321, 1321, 1321, 1321, 1321, 1321, 1315, 1315, 1321, 1321,
     1321, 1321, 1321, 1321, 1321, 1315, 1321, 1321, 1321, 1315,
     1321, 1321, 1321, 1321, 1321, 1321, 1321, 1321, 1321, 1321,

     1321, 1321, 1321, 1321, 1321, 1321, 1321, 1321, 1321, 1321,
     1321, 1321, 1321, 1321,    0, 1315, 1315, 1315, 1315, 1315,
     1315, 1315, 1315, 1315, 1315, 1315, 1315, 1315, 1315, 1315,
     1315, 1315
    } ;

static yyconst flex_int16_t yy_nxt[2107] =
    {   0,
       12,   13,   14,   13,   15,   16,   17,   18,   19,   20,
       21,   22,   23,   24,   25,   26,   27,   28,   29,   30,
       31,   31,   31,   31,   32,   33,   34,   35,   36,   37,
       38,   39,   40,   41,   42,   43,   44,   45,   46,   47,
       48,   49,   50,   48,   51,   52,   53,   54,   55,   56,
       48,   57,   58,   59,   60,   13,   61,   62,   63,   64,
       65,   66,   67,   68,   69,   70,   71,   72,   73,   74,
       75,   76,   77,   78,   79,   48,   80,   81,   82,   83,
       84,   85,   86,   48,   87,   88,   89,   90,   48,   48,
       48,   48,   48,   48,   48,   48,   48,   48,   48,   48,

       48,   48,   48,   48,   48,   91,   48,   48,   48,   48,
       48,   48,   48,   48,   48,   48,   48,   48,   48,   48,
       48,   48,   48,   48,   48,   92,   93,   94,   95,   96,
       97,   98,  100,  100,  103,  103,  106,  106,  110,  107,
      107,  110,  166,  101,  101,  104,  104,  112,  168,  112,
      217,  170,  172,  229,  173,  135,  167,  212,  213,  136,
      184,  169,  174,  175,  176,  185,  231,  256,  197,  498,
      186,  257,  499,  137,  198,  199,  239,  200,  218,  187,
      122,  123,  204,  205,  206,  242,  201,  286,  230,  108,
      108,  124,  171,  287,  232,  111,  202,  243,  111,  259,

      125,  112,  114,  138,  115,  240,  139,  116,  116,  117,
      117,  118,  140,  398,  399,  203,  141,  251,  262,  118,
      118,  118,  118,  118,  118,  207,  208,  127,  260,  128,
      254,  129,  263,  288,  112, 1049,  112,  130,  188,  255,
      220,  131,  289,  209,  210,  211,  252,  132,  118,  119,
      118,  118,  118,  118,  221,  253,  339,  133,  284,  134,
      340,  120,  214,  214,  214,  214,  214,  306,  285,  299,
      121,  142,  307,  215,  143,  144,  145,  296,  297,  300,
      146,  147,  222,  148,  149,  150, 1050,  298,  112,  427,
      344,  151,  223,  152,  153,  154,  428,  155,  177,  178,

      352,  179,  180,  181,  182,  182,  182,  182,  182,  353,
      189, 1051,  190,  190,  190,  190,  190,  308,  234,  742,
      235,  236,  191,  237,  156,  309,  337,  157,  192,  238,
      310,  338,  743,  302,  448,  158,  311,  224,  159,  160,
      161,  225,  183,  162,  303,  312,  163,  226,  345,  164,
      313,  304,  165, 1052,  193,  406,  189,  192,  190,  190,
      190,  190,  190,  448,  366,  246,  194,  322,  191,  367,
      227,  323,  407,  324,  192,  195,  247,  988,  228,  264,
      325,  326,  265,  266,  267,  835,  248,  268,  418,  269,
      270,  271,  272,  273,  249,  274,  275,  350,  276,  250,

      278,  277,  279,  192,  280,  419,  281,  282,  283,  290,
      334,  291,  292,  293,  315,  351,  294,  335,  196,  295,
      316,  483,  317,  425,  318,  319,  420,  426,  320,  336,
      327,  321,  328,  946,  329,  346,  422,  429,  330,  347,
      348,  349,  430,  421,  331,  452,  452,  355,  332,  333,
      356,  484,  357,  358,  359,  360,  423,  415,  361,  373,
      373,  373,  373,  374,  196,  116,  116,  117,  117,  118,
      387,  387,  387,  387,  416,  417,  947,  118,  118,  118,
      118,  118,  118,  117,  117,  117,  117,  118,  570,  500,
      571,  432,  501,  471,  515,  118,  118,  118,  118,  118,

      118,  375,  433,  472,  516,  376,  118,  383,  118,  118,
      118,  118,  377,  384,  525,  528,  378,  526,  379,  385,
      453,  453,  453,  453,  118,  118,  118,  118,  118,  118,
      529,  384,  118,  118,  118,  118,  118,  385,  214,  214,
      214,  214,  214,  546,  118,  118,  118,  118,  118,  118,
      386,  386,  118,  118,  118,  474,  573,  592, 1053,  547,
      593,  475,  118,  118,  118,  118,  118,  118,  559,  557,
      574,  560,  476,  118,  118,  118,  118,  118,  118,  389,
      384,  511,  390,  391,  561,  585,  512,  558, 1054,  586,
      517,  118,  118,  118,  118,  118,  118,  518,  384,  388,

      388,  388,  388,  388,  539,  628,  452,  452,  629,  630,
      540,  388,  388,  388,  388,  388,  388,  552,  182,  182,
      182,  182,  182,  553,  563,  392, 1315,  393,  440,  564,
      449, 1315,  449, 1055,  441,  450,  450,  450,  450,  450,
      388,  388,  388,  388,  388,  388,  445,  445,  445,  445,
      445,  451,  576,  665,  520,  394,  446,  395,  577,  521,
      677, 1056,  447,  441,  189,  522,  190,  190,  190,  190,
      190,  454,  454,  454,  454,  454,  191,  579,  601,  580,
      451,  602,  192,  454,  454,  454,  454,  454,  454,  677,
      581,  447,  635,  611,  612,  603,  613,  614,  615,  616,

      617,  618,  632,  366,  636,  753,  633,  775,  367,  754,
      621,  192,  454,  454,  454,  454,  454,  454,  622,  623,
      776,  666,  624,  625, 1057,  626,  637,  637,  637,  637,
      638,  627,  638,  638,  638,  638,  638,  118,  118,  118,
      118,  118,  387,  387,  387,  387,  683,  837,  838,  118,
      118,  118,  118,  118,  118,  450,  450,  450,  450,  450,
      963,  759, 1058,  643,  989,  964,  644,  645,  453,  453,
      453,  453,  196, 1059,  836,  683,  760,  761,  118,  118,
      118,  118,  118,  118,  855,  384,  386,  386,  118,  118,
      118,  450,  450,  450,  450,  450,  959,  965,  118,  118,

      118,  118,  118,  118,  388,  388,  388,  388,  388,  646,
     1060,  647, 1061,  855, 1062,  966,  388,  388,  388,  388,
      388,  388,  690,  690,  690,  690,  690,  118,  118,  118,
      118,  118,  118,  923,  384, 1063,  780,  809,  924,  648,
      960,  649,  781,  810,  925,  388,  388,  388,  388,  388,
      388,  678, 1064,  678, 1065, 1066,  679,  679,  679,  679,
      679,  445,  445,  445,  445,  445,  834,  834,  834,  834,
      638,  681,  680,  684, 1067,  684, 1068,  682,  685,  685,
      685,  685,  685,  687, 1069,  687, 1070, 1071,  688,  688,
      688,  688,  688, 1072,  686,  638,  638,  638,  638,  638,

     1073,  680, 1074,  449,  689,  449,  682, 1075,  450,  450,
      450,  450,  450,  454,  454,  454,  454,  454,  679,  679,
      679,  679,  679,  686, 1076,  454,  454,  454,  454,  454,
      454, 1077,  852,  689,  852, 1078, 1079,  853,  853,  853,
      853,  853,  679,  679,  679,  679,  679,  685,  685,  685,
      685,  685, 1080,  854,  454,  454,  454,  454,  454,  454,
      678, 1081,  678, 1082, 1083,  679,  679,  679,  679,  679,
      856, 1084,  856, 1085, 1086,  857,  857,  857,  857,  857,
     1087,  859,  854,  859, 1088, 1089,  860,  860,  860,  860,
      860,  858,  685,  685,  685,  685,  685, 1090,  684, 1091,

      684, 1092,  861,  685,  685,  685,  685,  685,  688,  688,
      688,  688,  688,  688,  688,  688,  688,  688, 1093,  687,
      858,  687, 1094, 1095,  688,  688,  688,  688,  688, 1096,
      640,  861,  690,  690,  690,  690,  690,  638,  638,  638,
      638,  638,  853,  853,  853,  853,  853,  853,  853,  853,
      853,  853,  852,  642,  852, 1097, 1098,  853,  853,  853,
      853,  853,  997, 1099,  997, 1100, 1101,  998,  998,  998,
      998,  998,  857,  857,  857,  857,  857,  857,  857,  857,
      857,  857,  856,  999,  856, 1102, 1103,  857,  857,  857,
      857,  857,  860,  860,  860,  860,  860,  860,  860,  860,

      860,  860,  859, 1104,  859, 1105, 1106,  860,  860,  860,
      860,  860,  999,  998,  998,  998,  998,  998,  998,  998,
      998,  998,  998,  997, 1107,  997, 1108, 1109,  998,  998,
      998,  998,  998, 1110, 1111, 1112, 1113, 1114, 1115, 1116,
     1117, 1118,  862, 1119, 1120, 1121, 1122, 1123, 1124, 1125,
     1126, 1127, 1128, 1129, 1130, 1131, 1132, 1133, 1134, 1135,
     1136, 1137, 1138, 1139, 1140, 1141, 1142, 1143, 1144, 1145,
     1146, 1147, 1148, 1149, 1150, 1151, 1152, 1153, 1154, 1155,
     1156, 1157, 1158, 1159, 1160, 1161, 1162, 1163, 1164, 1165,
     1166, 1167, 1168, 1169, 1169, 1169, 1169, 1169, 1170, 1171,

     1172, 1173, 1174, 1175, 1176, 1177, 1178, 1179, 1180, 1181,
     1182, 1183, 1184, 1185, 1186, 1187, 1188, 1189, 1190, 1191,
     1192, 1193, 1194, 1195, 1196, 1197, 1198, 1199, 1200, 1201,
     1202, 1203, 1204, 1205, 1206, 1207, 1208, 1209, 1210, 1211,
     1212, 1213, 1215, 1169, 1169, 1169, 1169, 1169, 1216, 1217,
     1218, 1219, 1220, 1221, 1222, 1223, 1224, 1226, 1227, 1228,
     1229, 1230, 1231, 1232, 1233, 1225, 1234, 1235, 1236, 1237,
     1238, 1239, 1240, 1241, 1242, 1242, 1242, 1242, 1242, 1243,
     1244, 1245, 1246, 1247, 1248, 1249, 1250, 1251, 1252, 1253,
     1254, 1255, 1256, 1257, 1258, 1259, 1260, 1242, 1242, 1242,

     1242, 1242, 1262, 1263, 1264, 1265, 1266, 1267, 1268, 1269,
     1270, 1271, 1272, 1273, 1274, 1275, 1276, 1277, 1278, 1278,
     1278, 1278, 1278, 1279, 1280, 1281, 1282, 1283, 1284, 1285,
     1286, 1287, 1288, 1289, 1290, 1278, 1278, 1278, 1278, 1278,
     1291, 1292, 1293, 1294, 1295, 1296, 1297, 1298, 1299, 1300,
     1301, 1302, 1303, 1214, 1304, 1305, 1306, 1307, 1308, 1309,
     1310, 1311, 1312, 1313, 1314, 1048, 1047, 1046, 1045, 1044,
     1043, 1042, 1041, 1040, 1039, 1038, 1037, 1036, 1035, 1034,
     1033, 1032, 1031, 1030, 1029, 1028, 1027, 1026, 1025, 1024,
     1023, 1022, 1021, 1020, 1019, 1018, 1017, 1016, 1015, 1014,

     1013, 1012, 1011, 1010, 1009, 1008, 1007, 1261,   99,   99,
       99,   99,   99,   99,   99,   99,  102,  102,  102,  102,
      102,  102,  102,  102,  105,  105,  105,  105,  105,  105,
      105,  105,  109,  109,  109,  109,  109,  109,  109,  109,
      126, 1006, 1005,  126,  216,  216,  364, 1004,  364,  364,
     1003,  364,  364,  364,  365, 1002,  365,  365,  365,  365,
      365,  365,  368,  368,  368,  368, 1001,  368,  368,  368,
      370, 1000,  996,  370,  370,  370,  370,  370,  372,  372,
      372,  372,  372,  372,  372,  372,  380,  995,  380,  380,
      380,  380,  380,  397,  397,  443,  443,  443,  443,  443,

      443,  443,  443,  639,  639,  639,  639,  994,  639,  639,
      639,  641,  641,  641,  641,  993,  641,  641,  641,  691,
      691,  691,  691,  691,  691,  691,  691,  992,  991,  990,
      987,  986,  985,  984,  983,  982,  981,  980,  979,  978,
      977,  976,  975,  974,  973,  972,  971,  970,  969,  968,
      967,  962,  961,  958,  957,  956,  955,  954,  953,  952,
      951,  950,  949,  948,  945,  944,  943,  942,  941,  940,
      939,  938,  937,  936,  935,  934,  933,  932,  931,  930,
      929,  928,  927,  926,  922,  921,  920,  919,  918,  917,
      916,  915,  914,  913,  912,  911,  910,  909,  908,  907,

      906,  905,  904,  903,  902,  901,  900,  899,  898,  897,
      896,  895,  894,  893,  892,  891,  890,  889,  888,  887,
      886,  885,  884,  883,  882,  881,  880,  879,  878,  877,
      876,  875,  874,  873,  872,  871,  870,  869,  868,  867,
      866,  865,  864,  863,  692,  851,  850,  849,  848,  847,
      846,  845,  844,  843,  842,  841,  840,  839,  836,  642,
      835,  640,  833,  832,  831,  830,  829,  828,  827,  826,
      825,  824,  823,  822,  821,  820,  819,  818,  817,  816,
      815,  814,  813,  812,  811,  808,  807,  806,  805,  804,
      803,  802,  801,  800,  799,  798,  797,  796,  795,  794,

      793,  792,  791,  790,  789,  788,  787,  786,  785,  784,
      783,  782,  779,  778,  777,  774,  773,  772,  771,  770,
      769,  768,  767,  766,  765,  764,  763,  762,  758,  757,
      756,  755,  752,  751,  750,  749,  748,  747,  746,  745,
      744,  741,  740,  739,  738,  737,  736,  735,  734,  733,
      732,  731,  730,  729,  728,  727,  726,  725,  724,  723,
      722,  721,  720,  719,  718,  717,  716,  715,  714,  713,
      712,  711,  710,  709,  708,  707,  706,  705,  704,  703,
      702,  701,  700,  699,  698,  697,  696,  695,  694,  693,
      692,  444,  676,  675,  674,  673,  672,  671,  670,  669,

      668,  667,  664,  663,  662,  661,  660,  659,  658,  657,
      656,  655,  654,  653,  652,  651,  650,  642,  640,  369,
      634,  631,  620,  619,  610,  609,  608,  607,  606,  605,
      604,  600,  599,  598,  597,  596,  595,  594,  591,  590,
      589,  588,  587,  584,  583,  582,  578,  575,  572,  569,
      568,  567,  566,  565,  562,  556,  555,  554,  551,  550,
      549,  548,  545,  544,  543,  542,  541,  538,  537,  536,
      535,  534,  533,  532,  531,  530,  527,  524,  523,  519,
      514,  513,  510,  509,  508,  507,  506,  505,  504,  503,
      502,  497,  496,  495,  494,  493,  492,  491,  490,  489,

      488,  487,  486,  485,  482,  481,  480,  479,  478,  477,
      473,  470,  469,  468,  467,  466,  465,  464,  463,  462,
      461,  460,  459,  458,  457,  456,  455,  444,  442,  439,
      438,  437,  436,  435,  434,  431,  424,  414,  413,  412,
      411,  410,  409,  408,  405,  404,  403,  402,  401,  400,
      396,  382,  381,  371,  369,  363,  362,  354,  343,  342,
      341,  314,  305,  301,  261,  258,  245,  244,  241,  233,
      219,  113, 1315,   11, 1315, 1315, 1315, 1315, 1315, 1315,
     1315, 1315, 1315, 1315, 1315, 1315, 1315, 1315, 1315, 1315,
     1315, 1315, 1315, 1315, 1315, 1315, 1315, 1315, 1315, 1315,

     1315, 1315, 1315, 1315, 1315, 1315, 1315, 1315, 1315, 1315,
     1315, 1315, 1315, 1315, 1315, 1315, 1315, 1315, 1315, 1315,
     1315, 1315, 1315, 1315, 1315, 1315, 1315, 1315, 1315, 1315,
     1315, 1315, 1315, 1315, 1315, 1315, 1315, 1315, 1315, 1315,
     1315, 1315, 1315, 1315, 1315, 1315, 1315, 1315, 1315, 1315,
     1315, 1315, 1315, 1315, 1315, 1315, 1315, 1315, 1315, 1315,
     1315, 1315, 1315, 1315, 1315, 1315, 1315, 1315, 1315, 1315,
     1315, 1315, 1315, 1315, 1315, 1315, 1315, 1315, 1315, 1315,
     1315, 1315, 1315, 1315, 1315, 1315, 1315, 1315, 1315, 1315,
     1315, 1315, 1315, 1315, 1315, 1315, 1315, 1315, 1315, 1315,

     1315, 1315, 1315, 1315, 1315, 1315
    } ;

static yyconst flex_int16_t yy_chk[2107] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    3,    4,    5,    6,    7,    8,    9,    7,
        8,   10,   24,    3,    4,    5,    6,   13,   25,   13,
       39,   26,   27,   43,   27,   20,   24,   36,   36,   20,
       29,   25,   27,   27,   27,   29,   44,   56,   32,  251,
       29,   56,  251,   20,   32,   32,   47,   32,   39,   29,
       19,   19,   34,   34,   34,   50,   32,   67,   43,    7,
        8,   19,   26,   67,   44,    9,   32,   50,   10,   58,

       19,   13,   17,   20,   17,   47,   20,   17,   17,   17,
       17,   17,   20,  129,  129,   32,   20,   54,   62,   17,
       17,   17,   17,   17,   17,   35,   35,   19,   58,   19,
       55,   19,   62,   68,  112,  931,  112,   19,   29,   55,
       41,   19,   68,   35,   35,   35,   54,   19,   17,   17,
       17,   17,   17,   17,   41,   54,   84,   19,   66,   19,
       84,   17,   38,   38,   38,   38,   38,   75,   66,   71,
       17,   21,   75,   38,   21,   21,   21,   70,   70,   71,
       21,   21,   41,   21,   21,   21,  932,   70,  112,  158,
       88,   21,   41,   21,   21,   21,  158,   21,   28,   28,

       94,   28,   28,   28,   28,   28,   28,   28,   28,   94,
       30,  933,   30,   30,   30,   30,   30,   76,   46,  519,
       46,   46,   30,   46,   21,   76,   83,   21,   30,   46,
       76,   83,  519,   73,  191,   21,   77,   42,   21,   21,
       21,   42,   28,   21,   73,   77,   21,   42,   88,   21,
       77,   73,   21,  934,   30,  144,   31,   30,   31,   31,
       31,   31,   31,  191,  101,   53,   30,   80,   31,  101,
       42,   80,  144,   80,   31,   30,   53,  835,   42,   63,
       80,   80,   63,   63,   63,  835,   53,   63,  153,   63,
       63,   63,   63,   63,   53,   63,   63,   93,   63,   53,

       65,   63,   65,   31,   65,  153,   65,   65,   65,   69,
       82,   69,   69,   69,   79,   93,   69,   82,   30,   69,
       79,  234,   79,  157,   79,   79,  154,  157,   79,   82,
       81,   79,   81,  791,   81,   92,  155,  159,   81,   92,
       92,   92,  159,  154,   81,  193,  193,   96,   81,   81,
       96,  234,   96,   96,   96,   96,  155,  152,   96,  108,
      108,  108,  108,  108,   31,  116,  116,  116,  116,  116,
      120,  120,  120,  120,  152,  152,  791,  116,  116,  116,
      116,  116,  116,  117,  117,  117,  117,  117,  312,  252,
      312,  161,  252,  224,  267,  117,  117,  117,  117,  117,

      117,  108,  161,  224,  267,  108,  116,  116,  116,  116,
      116,  116,  108,  116,  273,  275,  108,  273,  108,  116,
      194,  194,  194,  194,  117,  117,  117,  117,  117,  117,
      275,  117,  118,  118,  118,  118,  118,  117,  214,  214,
      214,  214,  214,  293,  118,  118,  118,  118,  118,  118,
      119,  119,  119,  119,  119,  227,  314,  329,  935,  293,
      329,  227,  119,  119,  119,  119,  119,  119,  304,  303,
      314,  304,  227,  118,  118,  118,  118,  118,  118,  123,
      118,  264,  123,  123,  304,  323,  264,  303,  936,  323,
      268,  119,  119,  119,  119,  119,  119,  268,  119,  121,

      121,  121,  121,  121,  286,  359,  452,  452,  359,  359,
      286,  121,  121,  121,  121,  121,  121,  298,  182,  182,
      182,  182,  182,  298,  306,  123,  365,  123,  182,  306,
      192,  365,  192,  937,  182,  192,  192,  192,  192,  192,
      121,  121,  121,  121,  121,  121,  189,  189,  189,  189,
      189,  192,  317,  427,  270,  123,  189,  123,  317,  270,
      440,  938,  189,  182,  190,  270,  190,  190,  190,  190,
      190,  195,  195,  195,  195,  195,  190,  319,  337,  319,
      192,  337,  190,  195,  195,  195,  195,  195,  195,  440,
      319,  189,  363,  355,  355,  337,  355,  355,  355,  355,

      355,  355,  361,  366,  363,  530,  361,  549,  366,  530,
      358,  190,  195,  195,  195,  195,  195,  195,  358,  358,
      549,  427,  358,  358,  939,  358,  373,  373,  373,  373,
      373,  358,  374,  374,  374,  374,  374,  383,  383,  383,
      383,  383,  387,  387,  387,  387,  446,  643,  643,  383,
      383,  383,  383,  383,  383,  449,  449,  449,  449,  449,
      807,  535,  940,  389,  836,  807,  389,  389,  453,  453,
      453,  453,  190,  941,  836,  446,  535,  535,  383,  383,
      383,  383,  383,  383,  681,  383,  386,  386,  386,  386,
      386,  450,  450,  450,  450,  450,  804,  808,  386,  386,

      386,  386,  386,  386,  388,  388,  388,  388,  388,  389,
      942,  389,  943,  681,  944,  808,  388,  388,  388,  388,
      388,  388,  455,  455,  455,  455,  455,  386,  386,  386,
      386,  386,  386,  769,  386,  948,  554,  586,  769,  389,
      804,  389,  554,  586,  769,  388,  388,  388,  388,  388,
      388,  441,  949,  441,  950,  951,  441,  441,  441,  441,
      441,  445,  445,  445,  445,  445,  637,  637,  637,  637,
      637,  445,  441,  447,  952,  447,  953,  445,  447,  447,
      447,  447,  447,  448,  954,  448,  956,  957,  448,  448,
      448,  448,  448,  958,  447,  638,  638,  638,  638,  638,

      959,  441,  960,  451,  448,  451,  445,  961,  451,  451,
      451,  451,  451,  454,  454,  454,  454,  454,  678,  678,
      678,  678,  678,  447,  963,  454,  454,  454,  454,  454,
      454,  964,  677,  448,  677,  965,  966,  677,  677,  677,
      677,  677,  679,  679,  679,  679,  679,  684,  684,  684,
      684,  684,  967,  677,  454,  454,  454,  454,  454,  454,
      680,  968,  680,  970,  971,  680,  680,  680,  680,  680,
      682,  972,  682,  973,  974,  682,  682,  682,  682,  682,
      975,  683,  677,  683,  976,  977,  683,  683,  683,  683,
      683,  682,  685,  685,  685,  685,  685,  978,  686,  979,

      686,  981,  683,  686,  686,  686,  686,  686,  687,  687,
      687,  687,  687,  688,  688,  688,  688,  688,  982,  689,
      682,  689,  983,  984,  689,  689,  689,  689,  689,  986,
      988,  683,  690,  690,  690,  690,  690,  834,  834,  834,
      834,  834,  852,  852,  852,  852,  852,  853,  853,  853,
      853,  853,  854,  989,  854,  987,  987,  854,  854,  854,
      854,  854,  855,  990,  855,  993,  994,  855,  855,  855,
      855,  855,  856,  856,  856,  856,  856,  857,  857,  857,
      857,  857,  858,  855,  858,  995,  996,  858,  858,  858,
      858,  858,  859,  859,  859,  859,  859,  860,  860,  860,

      860,  860,  861, 1000,  861, 1001, 1005,  861,  861,  861,
      861,  861,  855,  997,  997,  997,  997,  997,  998,  998,
      998,  998,  998,  999, 1007,  999, 1008, 1009,  999,  999,
      999,  999,  999, 1010, 1014, 1016, 1018, 1019, 1021, 1023,
     1024, 1028,  690, 1029, 1030, 1032, 1033, 1034, 1035, 1036,
     1037, 1038, 1039, 1040, 1046, 1047, 1048, 1051, 1052, 1053,
     1054, 1055, 1057, 1058, 1059, 1060, 1061, 1062, 1063, 1064,
     1065, 1068, 1070, 1071, 1074, 1075, 1076, 1077, 1079, 1080,
     1082, 1083, 1085, 1086, 1089, 1091, 1092, 1093, 1094, 1095,
     1099, 1100, 1102, 1104, 1104, 1104, 1104, 1104, 1105, 1106,

     1107, 1110, 1112, 1115, 1116, 1117, 1119, 1120, 1121, 1122,
     1123, 1128, 1129, 1130, 1132, 1133, 1137, 1138, 1139, 1140,
     1141, 1142, 1143, 1145, 1147, 1148, 1149, 1150, 1151, 1152,
     1153, 1155, 1156, 1157, 1158, 1159, 1161, 1162, 1163, 1166,
     1167, 1169, 1170, 1169, 1169, 1169, 1169, 1169, 1173, 1174,
     1176, 1178, 1180, 1181, 1182, 1183, 1184, 1186, 1189, 1191,
     1194, 1195, 1197, 1199, 1200, 1184, 1204, 1205, 1206, 1207,
     1209, 1210, 1211, 1212, 1213, 1213, 1213, 1213, 1213, 1214,
     1218, 1220, 1221, 1222, 1224, 1225, 1226, 1228, 1229, 1231,
     1233, 1235, 1236, 1237, 1238, 1239, 1241, 1242, 1242, 1242,

     1242, 1242, 1243, 1245, 1246, 1247, 1248, 1249, 1250, 1251,
     1252, 1254, 1255, 1256, 1257, 1258, 1259, 1261, 1262, 1262,
     1262, 1262, 1262, 1263, 1264, 1266, 1267, 1269, 1271, 1272,
     1273, 1274, 1275, 1276, 1277, 1278, 1278, 1278, 1278, 1278,
     1279, 1282, 1283, 1284, 1285, 1287, 1289, 1291, 1292, 1293,
     1295, 1296, 1298, 1169, 1299, 1300, 1301, 1303, 1304, 1305,
     1306, 1307, 1308, 1310, 1311,  930,  926,  925,  924,  923,
      922,  921,  920,  919,  918,  917,  916,  915,  914,  913,
      912,  911,  910,  909,  908,  907,  906,  905,  902,  900,
      899,  898,  897,  896,  895,  894,  890,  889,  888,  887,

      886,  885,  881,  880,  879,  878,  877, 1242, 1316, 1316,
     1316, 1316, 1316, 1316, 1316, 1316, 1317, 1317, 1317, 1317,
     1317, 1317, 1317, 1317, 1318, 1318, 1318, 1318, 1318, 1318,
     1318, 1318, 1319, 1319, 1319, 1319, 1319, 1319, 1319, 1319,
     1320,  876,  874, 1320, 1321, 1321, 1322,  873, 1322, 1322,
      872, 1322, 1322, 1322, 1323,  871, 1323, 1323, 1323, 1323,
     1323, 1323, 1324, 1324, 1324, 1324,  870, 1324, 1324, 1324,
     1325,  862,  850, 1325, 1325, 1325, 1325, 1325, 1326, 1326,
     1326, 1326, 1326, 1326, 1326, 1326, 1327,  849, 1327, 1327,
     1327, 1327, 1327, 1328, 1328, 1329, 1329, 1329, 1329, 1329,

     1329, 1329, 1329, 1330, 1330, 1330, 1330,  846, 1330, 1330,
     1330, 1331, 1331, 1331, 1331,  845, 1331, 1331, 1331, 1332,
     1332, 1332, 1332, 1332, 1332, 1332, 1332,  844,  843,  839,
      833,  832,  831,  830,  829,  828,  827,  826,  825,  824,
      823,  822,  821,  820,  819,  818,  815,  813,  811,  810,
      809,  806,  805,  803,  801,  800,  799,  798,  797,  796,
      795,  794,  793,  792,  790,  789,  788,  787,  786,  784,
      783,  782,  781,  780,  779,  778,  777,  776,  775,  774,
      773,  772,  771,  770,  768,  767,  766,  765,  763,  762,
      761,  760,  759,  758,  757,  756,  754,  753,  752,  751,

      750,  749,  748,  746,  744,  743,  742,  741,  740,  739,
      738,  737,  736,  734,  733,  731,  729,  728,  727,  726,
      725,  724,  723,  722,  721,  720,  716,  715,  714,  713,
      712,  708,  707,  705,  704,  703,  702,  701,  700,  697,
      696,  695,  694,  693,  691,  675,  674,  673,  670,  669,
      668,  667,  666,  664,  663,  652,  651,  650,  642,  641,
      640,  639,  610,  609,  607,  606,  605,  604,  603,  602,
      601,  600,  599,  598,  597,  596,  595,  594,  593,  592,
      591,  590,  589,  588,  587,  585,  584,  583,  582,  580,
      579,  578,  577,  576,  575,  574,  573,  572,  571,  570,

      567,  566,  564,  563,  562,  561,  560,  559,  558,  557,
      556,  555,  552,  551,  550,  548,  547,  546,  545,  544,
      543,  542,  541,  540,  539,  538,  537,  536,  534,  533,
      532,  531,  529,  528,  527,  526,  525,  523,  522,  521,
      520,  518,  516,  515,  514,  513,  512,  511,  509,  508,
      507,  506,  505,  504,  503,  501,  500,  499,  498,  497,
      496,  495,  494,  492,  490,  489,  488,  487,  486,  485,
      484,  483,  482,  479,  478,  477,  476,  475,  474,  473,
      472,  471,  470,  468,  467,  466,  461,  459,  458,  457,
      456,  443,  437,  436,  435,  434,  433,  432,  431,  430,

      429,  428,  426,  425,  423,  421,  419,  417,  416,  414,
      412,  408,  407,  404,  403,  402,  401,  382,  381,  368,
      362,  360,  357,  356,  350,  347,  342,  341,  340,  339,
      338,  336,  335,  334,  333,  332,  331,  330,  328,  327,
      326,  325,  324,  322,  321,  320,  318,  315,  313,  311,
      310,  309,  308,  307,  305,  301,  300,  299,  297,  296,
      295,  294,  292,  291,  290,  288,  287,  285,  284,  282,
      281,  280,  279,  278,  277,  276,  274,  272,  271,  269,
      266,  265,  261,  260,  259,  258,  257,  256,  255,  254,
      253,  250,  248,  247,  246,  244,  243,  242,  241,  239,

      238,  237,  236,  235,  233,  232,  231,  230,  229,  228,
      225,  223,  222,  221,  220,  219,  218,  217,  213,  210,
      208,  204,  203,  202,  201,  197,  196,  186,  184,  180,
      173,  165,  164,  163,  162,  160,  156,  151,  150,  149,
      148,  147,  146,  145,  143,  142,  141,  140,  139,  132,
      124,  115,  114,  107,  102,   98,   97,   95,   87,   86,
       85,   78,   74,   72,   59,   57,   52,   51,   49,   45,
       40,   15,   11, 1315, 1315, 1315, 1315, 1315, 1315, 1315,
     1315, 1315, 1315, 1315, 1315, 1315, 1315, 1315, 1315, 1315,
     1315, 1315, 1315, 1315, 1315, 1315, 1315, 1315, 1315, 1315,

     1315, 1315, 1315, 1315, 1315, 1315, 1315, 1315, 1315, 1315,
     1315, 1315, 1315, 1315, 1315, 1315, 1315, 1315, 1315, 1315,
     1315, 1315, 1315, 1315, 1315, 1315, 1315, 1315, 1315, 1315,
     1315, 1315, 1315, 1315, 1315, 1315, 1315, 1315, 1315, 1315,
     1315, 1315, 1315, 1315, 1315, 1315, 1315, 1315, 1315, 1315,
     1315, 1315, 1315, 1315, 1315, 1315, 1315, 1315, 1315, 1315,
     1315, 1315, 1315, 1315, 1315, 1315, 1315, 1315, 1315, 1315,
     1315, 1315, 1315, 1315, 1315, 1315, 1315, 1315, 1315, 1315,
     1315, 1315, 1315, 1315, 1315, 1315, 1315, 1315, 1315, 1315,
     1315, 1315, 1315, 1315, 1315, 1315, 1315, 1315, 1315, 1315,

     1315, 1315, 1315, 1315, 1315, 1315
    } ;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
#line 1 "input_lexer.ll"
/* -*- mode: C++; compile-command: "flex input_lexer.ll && make input_lexer.o " -*- */
/* Note: for the nspire port, after flex, move from #ifdef HAVE_CONFIG_H 
   to #include "first.h" before #include<stdio.h> 
   and map "log" to log10 instead of ln
*/
/** @file input_lexer.ll
 *
 *  Lexical analyzer definition for reading expressions.
 *  Note Maple input should be processed replacing # with // and { } for set
 *  This file must be processed with flex. */
/*
 *  Copyright (C) 2001,14 B. Parisse, Institut Fourier, 38402 St Martin d'Heres
 *  The very first version was inspired by GiNaC lexer
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
/*
 * The lexer will first check for static patterns and strings (defined below)
 * If a match is not found, it calls find_or_make_symbol
 * This function looks first if the string should be translated
 * (e.g. add a prefix from the export table)
 * then look in lexer_functions for a match, then look in sym_tab
 * if not found in sym_tab, a new identificateur is created & added in sym_tab
 * Functions in lexer_functions are added during the construction
 * of the corresponding unary_functions using lexer_functions_register
 */
/*
 *  Definitions
 */
#line 48 "input_lexer.ll"
#include "giacPCH.h"
#ifdef HAVE_CONFIG_H
#include "config.h"
#endif
#include <iostream>
#include <stdexcept>

#include "gen.h"
#include "input_lexer.h"
#include "help.h"
#include "identificateur.h"
#include "usual.h"
#include "derive.h"
#include "series.h"
#include "intg.h"
#include "sym2poly.h"
#include "moyal.h"
#include "subst.h"
#include "vecteur.h"
#include "modpoly.h"
#include "lin.h"
#include "solve.h"
#include "ifactor.h"
#include "alg_ext.h"
#include "gauss.h"
#include "isom.h"
#include "plot.h"
#include "ti89.h"

#include "prog.h"
#include "rpn.h"
#include "ezgcd.h"
#include "tex.h"
#include "risch.h"
#include "permu.h"
#include "input_parser.h"    

#if defined(RTOS_THREADX) || defined(__MINGW_H) || defined NSPIRE || defined MS_SMART || defined(FREERTOS)
  int isatty (int ){ return 0; }
#endif

#if defined BESTA_OS || defined(FREERTOS)
#define EINTR           4
#endif

#ifdef NSPIRE
  // after flex, move #include "config.h" and first.h before all includes
  // include "static.h" then giacPCH.h
  // then edit input_lexer.cc and search for isatty, replace by 0 for interactive
  void clearerr(FILE *){}
#endif

  using namespace std;
  using namespace giac;
  void giac_yyset_column (int  column_no , yyscan_t yyscanner);
  int giac_yyget_column (yyscan_t yyscanner);
#define YY_USER_ACTION giac_yyset_column(giac_yyget_column(yyscanner)+yyleng,yyscanner);
#define YY_USER_INIT giac_yyset_column(1,yyscanner);

#ifndef NO_NAMESPACE_GIAC
  namespace giac {
#endif // ndef NO_NAMESPACE_GIAC

    void increment_lexer_line_number_setcol(yyscan_t yyscanner,GIAC_CONTEXT){
      giac_yyset_column(1,yyscanner);
      increment_lexer_line_number(contextptr);
    }
    bool doing_insmod = false;

#ifdef HAVE_LIBPTHREAD
    static pthread_mutex_t * syms_mutex_ptr = 0;
    
    int lock_syms_mutex(){
      if (!syms_mutex_ptr){
	pthread_mutex_t tmp=PTHREAD_MUTEX_INITIALIZER;
	syms_mutex_ptr=new pthread_mutex_t(tmp);
      }
      return pthread_mutex_lock(syms_mutex_ptr);
    }
    
    void unlock_syms_mutex(){
      if (syms_mutex_ptr) 
	pthread_mutex_unlock(syms_mutex_ptr);    
    }

#else
    int lock_syms_mutex(){ return 0; }
    void unlock_syms_mutex(){}
#endif

    sym_string_tab & syms(){
      static sym_string_tab * ans=0;
      if (!ans) ans=new sym_string_tab;
      return * ans;
    }


    std::vector<int> & lexer_localization_vector(){
      static std::vector<int> * ans=0;
      if (!ans) ans=new  std::vector<int>;
      return *ans;
    }

#ifdef USTL
    ustl::map<std::string,std::string> & lexer_localization_map(){
      static ustl::map<std::string,std::string> * ans = 0;
      if (!ans) ans=new ustl::map<std::string,std::string>;
      return * ans;
    }
    ustl::multimap<std::string,localized_string> & back_lexer_localization_map(){
      static ustl::multimap<std::string,localized_string> * ans= 0;
      if (!ans) ans=new ustl::multimap<std::string,localized_string>;
      return * ans;
    }

    // lexer_localization_vector() is the list of languages currently translated
    // lexer_localization_map translates keywords from the locale to giac 
    // back_lexer_localization_map() lists for a giac keyword the translations

    ustl::map<std::string,std::vector<std::string> > & lexer_translator (){
      static ustl::map<std::string,std::vector<std::string> > * ans = 0;
      if (!ans) ans=new ustl::map<std::string,std::vector<std::string> >;
      return * ans;
    }
    // lexer_translator will be updated when export/with is called
    // To each string (w/o ::) in a given library, 
    // If it exists, we push_back the full string (with ::)
    // If not we create a vector with the full string
    // If a library is unexported we remove the corresponding entry in the 
    // vector and remove the entry if the vector is empty
    ustl::map<std::string,std::vector<std::string> > & library_functions (){
      static ustl::map<std::string,std::vector<std::string> > * ans=0;
      if (!ans) ans=new ustl::map<std::string,std::vector<std::string> >;
      return *ans;
    }

#else
    std::map<std::string,std::string> & lexer_localization_map(){
      static std::map<std::string,std::string> * ans = 0;
      if (!ans) ans=new std::map<std::string,std::string>;
      return * ans;
    }
    std::multimap<std::string,localized_string> & back_lexer_localization_map(){
      static std::multimap<std::string,localized_string> * ans= 0;
      if (!ans) ans=new std::multimap<std::string,localized_string>;
      return * ans;
    }
    // lexer_localization_vector() is the list of languages currently translated
    // lexer_localization_map translates keywords from the locale to giac 
    // back_lexer_localization_map() lists for a giac keyword the translations

    std::map<std::string,std::vector<std::string> > & lexer_translator (){
      static std::map<std::string,std::vector<std::string> > * ans = 0;
      if (!ans) ans=new std::map<std::string,std::vector<std::string> >;
      return * ans;
    }
    // lexer_translator will be updated when export/with is called
    // To each string (w/o ::) in a given library, 
    // If it exists, we push_back the full string (with ::)
    // If not we create a vector with the full string
    // If a library is unexported we remove the corresponding entry in the 
    // vector and remove the entry if the vector is empty
    std::map<std::string,std::vector<std::string> > & library_functions (){
      static std::map<std::string,std::vector<std::string> > * ans=0;
      if (!ans) ans=new std::map<std::string,std::vector<std::string> >;
      return *ans;
    }

#endif

    // First string is the library name, second is the vector of function names
    // User defined relations
    vector<user_function> & registered_lexer_functions(){
      static vector<user_function> * ans = 0;
      if (!ans){
	ans = new vector<user_function>;
	// ans->reserve(50);
      }
      return * ans;
    }

    bool tri1(const lexer_tab_int_type & a,const lexer_tab_int_type & b){
      int res= strcmp(a.keyword,b.keyword);
      return res<0;
    }

    bool tri2(const char * a,const char * b){
      return strcmp(a,b)<0;
    }

    const lexer_tab_int_type lexer_tab_int_values []={
#ifdef GIAC_HAS_STO_38
#include "lexer_tab38_int.h"
#else
#include "lexer_tab_int.h"
#endif
    };

    const lexer_tab_int_type * const lexer_tab_int_values_begin = lexer_tab_int_values;
    const unsigned lexer_tab_int_values_n=sizeof(lexer_tab_int_values)/sizeof(lexer_tab_int_type);
    const lexer_tab_int_type * const lexer_tab_int_values_end = lexer_tab_int_values+lexer_tab_int_values_n;
#ifndef NO_NAMESPACE_GIAC
  } // namespace giac
#endif // ndef NO_NAMESPACE_GIAC

/* Abbreviations */
/* If changed, modify isalphan in help.cc FIXME is . allowed inside alphanumeric ? answer NO */




/*
 *  Lexical rules
 */
#line 1608 "input_lexer.cc"

#define INITIAL 0
#define comment 1
#define comment_hash 2
#define str 3
#define backquote 4

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

/* Holds the entire state of the reentrant scanner. */
struct yyguts_t
    {

    /* User-defined. Not touched by flex. */
    YY_EXTRA_TYPE yyextra_r;

    /* The rest are the same as the globals declared in the non-reentrant scanner. */
    FILE *yyin_r, *yyout_r;
    size_t yy_buffer_stack_top; /**< index of top of stack. */
    size_t yy_buffer_stack_max; /**< capacity of stack. */
    YY_BUFFER_STATE * yy_buffer_stack; /**< Stack as an array. */
    char yy_hold_char;
    int yy_n_chars;
    int yyleng_r;
    char *yy_c_buf_p;
    int yy_init;
    int yy_start;
    int yy_did_buffer_switch_on_eof;
    int yy_start_stack_ptr;
    int yy_start_stack_depth;
    int *yy_start_stack;
    yy_state_type yy_last_accepting_state;
    char* yy_last_accepting_cpos;

    int yylineno_r;
    int yy_flex_debug_r;

    char *yytext_r;
    int yy_more_flag;
    int yy_more_len;

    YYSTYPE * yylval_r;

    }; /* end struct yyguts_t */

static int yy_init_globals (yyscan_t yyscanner );

    /* This must go here because YYSTYPE and YYLTYPE are included
     * from bison output in section 1.*/
    #    define yylval yyg->yylval_r
    
int giac_yylex_init (yyscan_t* scanner);

int giac_yylex_init_extra (YY_EXTRA_TYPE user_defined,yyscan_t* scanner);

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int giac_yylex_destroy (yyscan_t yyscanner );

int giac_yyget_debug (yyscan_t yyscanner );

void giac_yyset_debug (int debug_flag ,yyscan_t yyscanner );

YY_EXTRA_TYPE giac_yyget_extra (yyscan_t yyscanner );

void giac_yyset_extra (YY_EXTRA_TYPE user_defined ,yyscan_t yyscanner );

FILE *giac_yyget_in (yyscan_t yyscanner );

void giac_yyset_in  (FILE * in_str ,yyscan_t yyscanner );

FILE *giac_yyget_out (yyscan_t yyscanner );

void giac_yyset_out  (FILE * out_str ,yyscan_t yyscanner );

int giac_yyget_leng (yyscan_t yyscanner );

char *giac_yyget_text (yyscan_t yyscanner );

int giac_yyget_lineno (yyscan_t yyscanner );

void giac_yyset_lineno (int line_number ,yyscan_t yyscanner );

int giac_yyget_column  (yyscan_t yyscanner );

void giac_yyset_column (int column_no ,yyscan_t yyscanner );

YYSTYPE * giac_yyget_lval (yyscan_t yyscanner );

void giac_yyset_lval (YYSTYPE * yylval_param ,yyscan_t yyscanner );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int giac_yywrap (yyscan_t yyscanner );
#else
extern int giac_yywrap (yyscan_t yyscanner );
#endif
#endif

    static void yyunput (int c,char *buf_ptr  ,yyscan_t yyscanner);
    
#ifndef yytext_ptr
static void yy_flex_strncpy (char *,yyconst char *,int ,yyscan_t yyscanner);
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * ,yyscan_t yyscanner);
#endif

#ifndef YY_NO_INPUT

#ifdef __cplusplus
static int yyinput (yyscan_t yyscanner );
#else
static int input (yyscan_t yyscanner );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k */
#define YY_READ_BUF_SIZE 16384
#else
#define YY_READ_BUF_SIZE 8192
#endif /* __ia64__ */
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO do { if (fwrite( yytext, yyleng, 1, yyout )) {} } while (0)
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		size_t n; \
		for ( n = 0; n < max_size && \
			     (c = getc( yyin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( yyin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = fread(buf, 1, max_size, yyin))==0 && ferror(yyin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(yyin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg , yyscanner)
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int giac_yylex \
               (YYSTYPE * yylval_param ,yyscan_t yyscanner);

#define YY_DECL int giac_yylex \
               (YYSTYPE * yylval_param , yyscan_t yyscanner)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after yytext and yyleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK break;
#endif

#define YY_RULE_SETUP \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	register yy_state_type yy_current_state;
	register char *yy_cp, *yy_bp;
	register int yy_act;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

#line 275 "input_lexer.ll"


#line 1857 "input_lexer.cc"

    yylval = yylval_param;

	if ( !yyg->yy_init )
		{
		yyg->yy_init = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! yyg->yy_start )
			yyg->yy_start = 1;	/* first start state */

		if ( ! yyin )
			yyin = stdin;

		if ( ! yyout )
			yyout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			giac_yyensure_buffer_stack (yyscanner);
			YY_CURRENT_BUFFER_LVALUE =
				giac_yy_create_buffer(yyin,YY_BUF_SIZE ,yyscanner);
		}

		giac_yy_load_buffer_state(yyscanner );
		}

	while ( 1 )		/* loops until end-of-file is reached */
		{
		yy_cp = yyg->yy_c_buf_p;

		/* Support of yytext. */
		*yy_cp = yyg->yy_hold_char;

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = yyg->yy_start;
yy_match:
		do
			{
			register YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)];
			if ( yy_accept[yy_current_state] )
				{
				yyg->yy_last_accepting_state = yy_current_state;
				yyg->yy_last_accepting_cpos = yy_cp;
				}
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 1316 )
					yy_c = yy_meta[(unsigned int) yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
			++yy_cp;
			}
		while ( yy_base[yy_current_state] != 1974 );

yy_find_action:
		yy_act = yy_accept[yy_current_state];
		if ( yy_act == 0 )
			{ /* have to back up */
			yy_cp = yyg->yy_last_accepting_cpos;
			yy_current_state = yyg->yy_last_accepting_state;
			yy_act = yy_accept[yy_current_state];
			}

		YY_DO_BEFORE_ACTION;

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*yy_cp = yyg->yy_hold_char;
			yy_cp = yyg->yy_last_accepting_cpos;
			yy_current_state = yyg->yy_last_accepting_state;
			goto yy_find_action;

case 1:
YY_RULE_SETUP
#line 277 "input_lexer.ll"
/* skip whitespace */
	YY_BREAK
case 2:
/* rule 2 can match eol */
YY_RULE_SETUP
#line 278 "input_lexer.ll"
increment_lexer_line_number_setcol(yyscanner,yyextra); //CERR << "Scanning line " << lexer_line_number(yyextra) << endl;
	YY_BREAK
/* Strings */
/* \"[^\"]*\"        yylval = string2gen( giac_yytext); return T_STRING; */
case 3:
YY_RULE_SETUP
#line 281 "input_lexer.ll"
BEGIN(str); comment_s("",yyextra);
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 282 "input_lexer.ll"
increment_comment_s('"',yyextra);
	YY_BREAK
case 5:
YY_RULE_SETUP
#line 283 "input_lexer.ll"
{  index_status(yyextra)=1; BEGIN(INITIAL); 
                  (*yylval)=string2gen(comment_s(yyextra),false); 
                  return T_STRING; }
	YY_BREAK
case 6:
/* rule 6 can match eol */
YY_RULE_SETUP
#line 286 "input_lexer.ll"
increment_comment_s('\n',yyextra); increment_lexer_line_number_setcol(yyscanner,yyextra);
	YY_BREAK
case 7:
YY_RULE_SETUP
#line 287 "input_lexer.ll"
{
                   /* octal escape sequence */
                   int result=0;
                   (void) sscanf( yytext + 1, "%o", &result ); // not supported on FXCG
                   increment_comment_s(char(result & 0xff),yyextra);
                   }
	YY_BREAK
case 8:
YY_RULE_SETUP
#line 293 "input_lexer.ll"
{
                   /* generate error - bad escape sequence; something
                    * like '\48' or '\0777777'
                    */
                   }
	YY_BREAK
case 9:
YY_RULE_SETUP
#line 298 "input_lexer.ll"
increment_comment_s('\n',yyextra);
	YY_BREAK
case 10:
YY_RULE_SETUP
#line 299 "input_lexer.ll"
increment_comment_s('\t',yyextra);
	YY_BREAK
case 11:
YY_RULE_SETUP
#line 300 "input_lexer.ll"
increment_comment_s('\r',yyextra);
	YY_BREAK
case 12:
YY_RULE_SETUP
#line 301 "input_lexer.ll"
increment_comment_s('\b',yyextra);
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 302 "input_lexer.ll"
increment_comment_s('\f',yyextra);
	YY_BREAK
case 14:
/* rule 14 can match eol */
YY_RULE_SETUP
#line 303 "input_lexer.ll"
increment_comment_s(yytext[1],yyextra);
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 304 "input_lexer.ll"
increment_comment_s(yytext,yyextra);
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 305 "input_lexer.ll"
if (rpn_mode(yyextra)){ index_status(yyextra)=0; return T_ACCENTGRAVE; } else { BEGIN(backquote); comment_s("",yyextra); }
	YY_BREAK
case 17:
/* rule 17 can match eol */
YY_RULE_SETUP
#line 306 "input_lexer.ll"
increment_comment_s('\n',yyextra); increment_lexer_line_number_setcol(yyscanner,yyextra);
	YY_BREAK
case 18:
YY_RULE_SETUP
#line 307 "input_lexer.ll"
increment_comment_s(yytext,yyextra);
	YY_BREAK
case 19:
YY_RULE_SETUP
#line 308 "input_lexer.ll"
{  index_status(yyextra)=1; BEGIN(INITIAL); 
  return find_or_make_symbol(comment_s(yyextra),(*yylval),yyscanner,true,yyextra); }
	YY_BREAK
case 20:
/* rule 20 can match eol */
YY_RULE_SETUP
#line 311 "input_lexer.ll"
index_status(yyextra)=0; increment_lexer_line_number_setcol(yyscanner,yyextra);
	YY_BREAK
case 21:
/* rule 21 can match eol */
YY_RULE_SETUP
#line 312 "input_lexer.ll"
index_status(yyextra)=0; increment_lexer_line_number_setcol(yyscanner,yyextra);/* (*yylval) = string2gen('"'+string(giac_yytext).substr(2,string(giac_yytext).size()-3)+'"');   return T_COMMENT; */
	YY_BREAK
case 22:
YY_RULE_SETUP
#line 313 "input_lexer.ll"
BEGIN(comment); comment_s(yyextra)="";
	YY_BREAK
case 23:
YY_RULE_SETUP
#line 315 "input_lexer.ll"
comment_s(yyextra)+=yytext; /* eat anything that's not a '*' */
	YY_BREAK
case 24:
YY_RULE_SETUP
#line 316 "input_lexer.ll"
comment_s(yyextra)+=yytext; /* eat up '*'s not followed by '/'s */
	YY_BREAK
case 25:
/* rule 25 can match eol */
YY_RULE_SETUP
#line 317 "input_lexer.ll"
comment_s(yyextra) += '\n'; increment_lexer_line_number_setcol(yyscanner,yyextra); CERR << "(Comment) scanning line " << lexer_line_number(yyextra) << endl;
	YY_BREAK
case 26:
YY_RULE_SETUP
#line 318 "input_lexer.ll"
BEGIN(INITIAL); index_status(yyextra)=0; /* (*yylval) = string2gen(comment_s(yyextra),false); return T_COMMENT; */
	YY_BREAK
case 27:
/* rule 27 can match eol */
YY_RULE_SETUP
#line 319 "input_lexer.ll"
index_status(yyextra)=0; /* (*yylval) = string2gen('"'+string(yytext).substr(3,string(yytext).size()-6)+'"'); return T_COMMENT; */
	YY_BREAK
case 28:
/* rule 28 can match eol */
YY_RULE_SETUP
#line 320 "input_lexer.ll"
index_status(yyextra)=0; /* (*yylval) = string2gen('"'+string(yytext).substr(3,string(yytext).size()-6)+'"'); return T_COMMENT; */
	YY_BREAK
case 29:
YY_RULE_SETUP
#line 322 "input_lexer.ll"
if (index_status(yyextra)) return T_INTERROGATION; if (calc_mode(yyextra)==1){ *yylval=undef; return T_SYMBOL;}  return T_HELP;
	YY_BREAK
case 30:
YY_RULE_SETUP
#line 323 "input_lexer.ll"
opened_quote(yyextra) |= 2; return T_UNIT;
	YY_BREAK
case 31:
YY_RULE_SETUP
#line 324 "input_lexer.ll"
if (opened_quote(yyextra) & 1) { opened_quote(yyextra) &= 0x7ffffffe; return T_QUOTE; } if (index_status(yyextra) && !in_rpn(yyextra) && xcas_mode(yyextra)!= 1) return T_PRIME; opened_quote(yyextra) |= 1; return T_QUOTE;
	YY_BREAK
case 32:
YY_RULE_SETUP
#line 325 "input_lexer.ll"
index_status(yyextra)=0; if (xcas_mode(yyextra)==3) return TI_SEMI; (*yylval)=0; return T_SEMI;
	YY_BREAK
/* commented otherwise for(;;) will not work ";;"			index_status(yyextra)=0; if (xcas_mode(yyextra)==3) return TI_SEMI; (*yylval)=0; return T_SEMI; */
case 33:
YY_RULE_SETUP
#line 327 "input_lexer.ll"
index_status(yyextra)=0; if (xcas_mode(yyextra)==3) return T_SEMI; return TI_SEMI;
	YY_BREAK
case 34:
YY_RULE_SETUP
#line 328 "input_lexer.ll"
if (spread_formula(yyextra)) return T_DEUXPOINTS; if ( xcas_mode(yyextra)==3 ) { index_status(yyextra)=0; return TI_DEUXPOINTS; }  index_status(yyextra)=0; if (xcas_mode(yyextra)>0) { (*yylval)=1; return T_SEMI; } else return T_DEUXPOINTS;
	YY_BREAK
case 35:
YY_RULE_SETUP
#line 329 "input_lexer.ll"
index_status(yyextra)=0; (*yylval)=1; return T_SEMI;
	YY_BREAK
case 36:
YY_RULE_SETUP
#line 330 "input_lexer.ll"
index_status(yyextra)=0;return T_DOUBLE_DEUX_POINTS;
	YY_BREAK
/* special values */
case 37:
YY_RULE_SETUP
#line 334 "input_lexer.ll"
index_status(yyextra)=1; (*yylval)=theta__IDNT_e; return T_SYMBOL;
	YY_BREAK
case 38:
YY_RULE_SETUP
#line 335 "input_lexer.ll"
index_status(yyextra)=1; if (xcas_mode(yyextra) > 0 || !i_sqrt_minus1(yyextra)) { (*yylval)=i__IDNT_e; return T_SYMBOL; } else { (*yylval) = cst_i; return T_LITERAL;};
	YY_BREAK
case 39:
YY_RULE_SETUP
#line 336 "input_lexer.ll"
index_status(yyextra)=1; (*yylval) = cst_i; return T_LITERAL;
	YY_BREAK
case 40:
YY_RULE_SETUP
#line 337 "input_lexer.ll"
index_status(yyextra)=1; (*yylval) = cst_i; return T_LITERAL;
	YY_BREAK
case 41:
YY_RULE_SETUP
#line 338 "input_lexer.ll"
index_status(yyextra)=1; (*yylval) = cst_i; return T_LITERAL;
	YY_BREAK
/* \xef\xbd\x89            index_status(yyextra)=1; (*yylval) = cst_i; return T_LITERAL; */
case 42:
YY_RULE_SETUP
#line 340 "input_lexer.ll"
index_status(yyextra)=1; (*yylval) = cst_i; return T_LITERAL;
	YY_BREAK
case 43:
YY_RULE_SETUP
#line 341 "input_lexer.ll"
index_status(yyextra)=1; if (xcas_mode(yyextra)==0 || xcas_mode(yyextra)==3 || rpn_mode(yyextra)) { return find_or_make_symbol(yytext,(*yylval),yyscanner,true,yyextra); } else { (*yylval) = cst_i; return T_LITERAL; };
	YY_BREAK
case 44:
YY_RULE_SETUP
#line 342 "input_lexer.ll"
index_status(yyextra)=1; (*yylval) = cst_i; return T_LITERAL;
	YY_BREAK
case 45:
YY_RULE_SETUP
#line 343 "input_lexer.ll"
index_status(yyextra)=1; (*yylval) = symbolic(at_exp,1); return T_LITERAL;
	YY_BREAK
case 46:
YY_RULE_SETUP
#line 344 "input_lexer.ll"
index_status(yyextra)=1; (*yylval) = cst_pi; return T_LITERAL;
	YY_BREAK
case 47:
YY_RULE_SETUP
#line 345 "input_lexer.ll"
index_status(yyextra)=1; (*yylval) = cst_pi; return T_LITERAL;
	YY_BREAK
case 48:
YY_RULE_SETUP
#line 346 "input_lexer.ll"
index_status(yyextra)=1; (*yylval) = cst_pi; return T_LITERAL;
	YY_BREAK
case 49:
YY_RULE_SETUP
#line 347 "input_lexer.ll"
index_status(yyextra)=1; (*yylval) = cst_pi; return T_LITERAL;
	YY_BREAK
case 50:
YY_RULE_SETUP
#line 348 "input_lexer.ll"
index_status(yyextra)=1; (*yylval) = cst_pi; return T_LITERAL;
	YY_BREAK
case 51:
YY_RULE_SETUP
#line 349 "input_lexer.ll"
index_status(yyextra)=1; (*yylval) = cst_euler_gamma; return T_LITERAL;
	YY_BREAK
case 52:
YY_RULE_SETUP
#line 350 "input_lexer.ll"
index_status(yyextra)=1; (*yylval) = unsigned_inf; return T_LITERAL;
	YY_BREAK
case 53:
YY_RULE_SETUP
#line 351 "input_lexer.ll"
index_status(yyextra)=1; (*yylval) = plus_inf; return T_LITERAL;
	YY_BREAK
case 54:
YY_RULE_SETUP
#line 352 "input_lexer.ll"
index_status(yyextra)=1; (*yylval) = unsigned_inf; return T_LITERAL;
	YY_BREAK
case 55:
YY_RULE_SETUP
#line 353 "input_lexer.ll"
index_status(yyextra)=1; (*yylval) = plus_inf; return T_LITERAL;
	YY_BREAK
case 56:
YY_RULE_SETUP
#line 354 "input_lexer.ll"
index_status(yyextra)=1; (*yylval) = unsigned_inf; return T_LITERAL;
	YY_BREAK
case 57:
YY_RULE_SETUP
#line 355 "input_lexer.ll"
index_status(yyextra)=1; (*yylval) = plus_inf; return T_LITERAL;
	YY_BREAK
case 58:
YY_RULE_SETUP
#line 356 "input_lexer.ll"
index_status(yyextra)=1; (*yylval) = minus_inf; return T_LITERAL;
	YY_BREAK
case 59:
YY_RULE_SETUP
#line 357 "input_lexer.ll"
index_status(yyextra)=1; (*yylval) = undef; return T_LITERAL;
	YY_BREAK
case 60:
YY_RULE_SETUP
#line 358 "input_lexer.ll"
return T_END_INPUT;
	YY_BREAK
/* integer values */
case 61:
YY_RULE_SETUP
#line 361 "input_lexer.ll"
if (xcas_mode(yyextra)==2){ (*yylval) = gen(at_user_operator,6); index_status(yyextra)=0; return T_UNARY_OP; }  index_status(yyextra)=0; (*yylval) = _FUNC; (*yylval).subtype=_INT_TYPE; return T_TYPE_ID;
	YY_BREAK
case 62:
YY_RULE_SETUP
#line 362 "input_lexer.ll"
if (python_compat(yyextra)){ *yylval=at_python_list; return T_UNARY_OP; } if (xcas_mode(yyextra)==3) { index_status(yyextra)=1; return find_or_make_symbol(yytext,(*yylval),yyscanner,true,yyextra); } index_status(yyextra)=0; (*yylval) = _MAPLE_LIST ; (*yylval).subtype=_INT_MAPLECONVERSION ;return T_TYPE_ID;
	YY_BREAK
/* vector/polynom/matrice delimiters */
case 63:
YY_RULE_SETUP
#line 366 "input_lexer.ll"
(*yylval) = _SEQ__VECT; return T_VECT_DISPATCH;
	YY_BREAK
case 64:
YY_RULE_SETUP
#line 367 "input_lexer.ll"
(*yylval) = _SET__VECT; return T_VECT_DISPATCH;
	YY_BREAK
case 65:
YY_RULE_SETUP
#line 368 "input_lexer.ll"
(*yylval) = _INTERVAL__VECT; return T_VECT_DISPATCH;
	YY_BREAK
case 66:
YY_RULE_SETUP
#line 369 "input_lexer.ll"
index_status(yyextra)=0; (*yylval) = _LIST__VECT; return T_VECT_DISPATCH;
	YY_BREAK
case 67:
YY_RULE_SETUP
#line 370 "input_lexer.ll"
index_status(yyextra)=0; (*yylval) = _LIST__VECT; return T_BEGIN_PAR;
	YY_BREAK
case 68:
YY_RULE_SETUP
#line 371 "input_lexer.ll"
(*yylval) = _RPN_FUNC__VECT; return T_VECT_DISPATCH;
	YY_BREAK
case 69:
YY_RULE_SETUP
#line 372 "input_lexer.ll"
(*yylval) = _GROUP__VECT; return T_VECT_DISPATCH;
	YY_BREAK
case 70:
YY_RULE_SETUP
#line 373 "input_lexer.ll"
(*yylval) = _LINE__VECT; return T_VECT_DISPATCH;
	YY_BREAK
case 71:
YY_RULE_SETUP
#line 374 "input_lexer.ll"
(*yylval) = _VECTOR__VECT; return T_VECT_DISPATCH;
	YY_BREAK
case 72:
YY_RULE_SETUP
#line 375 "input_lexer.ll"
(*yylval) = _MATRIX__VECT; return T_VECT_DISPATCH;
	YY_BREAK
case 73:
YY_RULE_SETUP
#line 376 "input_lexer.ll"
(*yylval) = _PNT__VECT; return T_VECT_DISPATCH;
	YY_BREAK
case 74:
YY_RULE_SETUP
#line 377 "input_lexer.ll"
(*yylval) = _GGB__VECT; return T_VECT_DISPATCH;
	YY_BREAK
case 75:
YY_RULE_SETUP
#line 378 "input_lexer.ll"
(*yylval) = _GGBVECT; return T_VECT_DISPATCH;
	YY_BREAK
case 76:
YY_RULE_SETUP
#line 379 "input_lexer.ll"
(*yylval) = _POINT__VECT; return T_VECT_DISPATCH;
	YY_BREAK
case 77:
YY_RULE_SETUP
#line 380 "input_lexer.ll"
(*yylval) = _TUPLE__VECT; return T_VECT_DISPATCH;
	YY_BREAK
case 78:
YY_RULE_SETUP
#line 381 "input_lexer.ll"
(*yylval) = _CURVE__VECT; return T_VECT_DISPATCH;
	YY_BREAK
case 79:
YY_RULE_SETUP
#line 382 "input_lexer.ll"
(*yylval) = _HALFLINE__VECT; return T_VECT_DISPATCH;
	YY_BREAK
case 80:
YY_RULE_SETUP
#line 383 "input_lexer.ll"
(*yylval) = _POLY1__VECT; return T_VECT_DISPATCH;
	YY_BREAK
case 81:
YY_RULE_SETUP
#line 384 "input_lexer.ll"
(*yylval) = _ASSUME__VECT; return T_VECT_DISPATCH;
	YY_BREAK
case 82:
YY_RULE_SETUP
#line 385 "input_lexer.ll"
(*yylval) = _SPREAD__VECT; return T_VECT_DISPATCH;
	YY_BREAK
case 83:
YY_RULE_SETUP
#line 386 "input_lexer.ll"
(*yylval) = _FOLDER__VECT; return T_VECT_DISPATCH;
	YY_BREAK
case 84:
YY_RULE_SETUP
#line 387 "input_lexer.ll"
(*yylval) = _POLYEDRE__VECT; return T_VECT_DISPATCH;
	YY_BREAK
case 85:
YY_RULE_SETUP
#line 388 "input_lexer.ll"
(*yylval) = _RGBA__VECT; return T_VECT_DISPATCH;
	YY_BREAK
case 86:
YY_RULE_SETUP
#line 389 "input_lexer.ll"
index_status(yyextra)=0; (*yylval) = _LIST__VECT; return T_VECT_DISPATCH;
	YY_BREAK
case 87:
YY_RULE_SETUP
#line 390 "input_lexer.ll"
index_status(yyextra)=1; return T_VECT_END;
	YY_BREAK
case 88:
YY_RULE_SETUP
#line 391 "input_lexer.ll"
index_status(yyextra)=0; (*yylval)=gen(at_inferieur_strict,2);  return T_TEST_EQUAL;
	YY_BREAK
case 89:
YY_RULE_SETUP
#line 392 "input_lexer.ll"
index_status(yyextra)=0; (*yylval)=gen(at_superieur_strict,2); return T_TEST_EQUAL;
	YY_BREAK
case 90:
YY_RULE_SETUP
#line 393 "input_lexer.ll"
index_status(yyextra)=0; (*yylval)=gen(at_inferieur_strict,2);  return T_TEST_EQUAL;
	YY_BREAK
case 91:
YY_RULE_SETUP
#line 394 "input_lexer.ll"
index_status(yyextra)=0; (*yylval)=gen(at_inferieur_egal,2);  return T_TEST_EQUAL;
	YY_BREAK
case 92:
YY_RULE_SETUP
#line 395 "input_lexer.ll"
index_status(yyextra)=0; (*yylval)=gen(at_superieur_strict,2); return T_TEST_EQUAL;
	YY_BREAK
case 93:
YY_RULE_SETUP
#line 396 "input_lexer.ll"
index_status(yyextra)=0; (*yylval)=gen(at_superieur_egal,2); return T_TEST_EQUAL;
	YY_BREAK
case 94:
YY_RULE_SETUP
#line 397 "input_lexer.ll"
index_status(yyextra)=0; return T_VIRGULE;
	YY_BREAK
case 95:
YY_RULE_SETUP
#line 398 "input_lexer.ll"
index_status(yyextra)=0; return T_VIRGULE;
	YY_BREAK
case 96:
YY_RULE_SETUP
#line 399 "input_lexer.ll"
index_status(yyextra)=0; *yylval = 0; return T_BEGIN_PAR;
	YY_BREAK
case 97:
YY_RULE_SETUP
#line 400 "input_lexer.ll"
index_status(yyextra)=1; return T_END_PAR;
	YY_BREAK
case 98:
YY_RULE_SETUP
#line 401 "input_lexer.ll"
if (index_status(yyextra)) { index_status(yyextra)=0; return T_INDEX_BEGIN; } else { (*yylval) = 0; return T_VECT_DISPATCH; } ;
	YY_BREAK
case 99:
YY_RULE_SETUP
#line 402 "input_lexer.ll"
index_status(yyextra)=1; return T_VECT_END;
	YY_BREAK
case 100:
YY_RULE_SETUP
#line 403 "input_lexer.ll"
index_status(yyextra)=1; return T_VECT_END;
	YY_BREAK
case 101:
YY_RULE_SETUP
#line 404 "input_lexer.ll"
index_status(yyextra)=0; (*yylval) = _POLY1__VECT; return T_VECT_DISPATCH; 
	YY_BREAK
case 102:
YY_RULE_SETUP
#line 405 "input_lexer.ll"
index_status(yyextra)=1; return T_VECT_END;
	YY_BREAK
case 103:
YY_RULE_SETUP
#line 406 "input_lexer.ll"
index_status(yyextra)=0; (*yylval) = _MATRIX__VECT; return T_VECT_DISPATCH; 
	YY_BREAK
case 104:
YY_RULE_SETUP
#line 407 "input_lexer.ll"
index_status(yyextra)=1; return T_VECT_END;
	YY_BREAK
case 105:
YY_RULE_SETUP
#line 408 "input_lexer.ll"
index_status(yyextra)=0; (*yylval) = _ASSUME__VECT; return T_VECT_DISPATCH; 
	YY_BREAK
case 106:
YY_RULE_SETUP
#line 409 "input_lexer.ll"
index_status(yyextra)=1; return T_VECT_END;
	YY_BREAK
/* geometric delimiters */
case 107:
YY_RULE_SETUP
#line 411 "input_lexer.ll"
index_status(yyextra)=0; (*yylval) = _GROUP__VECT; return T_VECT_DISPATCH;
	YY_BREAK
case 108:
YY_RULE_SETUP
#line 412 "input_lexer.ll"
index_status(yyextra)=1; return T_VECT_END;
	YY_BREAK
case 109:
YY_RULE_SETUP
#line 413 "input_lexer.ll"
index_status(yyextra)=0; (*yylval) = _LINE__VECT; return T_VECT_DISPATCH; 
	YY_BREAK
case 110:
YY_RULE_SETUP
#line 414 "input_lexer.ll"
index_status(yyextra)=1; return T_VECT_END;
	YY_BREAK
case 111:
YY_RULE_SETUP
#line 415 "input_lexer.ll"
index_status(yyextra)=0; (*yylval) = _VECTOR__VECT; return T_VECT_DISPATCH; 
	YY_BREAK
case 112:
YY_RULE_SETUP
#line 416 "input_lexer.ll"
index_status(yyextra)=1; return T_VECT_END;
	YY_BREAK
case 113:
YY_RULE_SETUP
#line 417 "input_lexer.ll"
index_status(yyextra)=0; (*yylval) = _CURVE__VECT; return T_VECT_DISPATCH; 
	YY_BREAK
case 114:
YY_RULE_SETUP
#line 418 "input_lexer.ll"
index_status(yyextra)=1; return T_VECT_END;
	YY_BREAK
/* gen delimiters */
case 115:
YY_RULE_SETUP
#line 420 "input_lexer.ll"
index_status(yyextra)=0; (*yylval)=_TABLE__VECT;return T_VECT_DISPATCH; 
	YY_BREAK
case 116:
YY_RULE_SETUP
#line 421 "input_lexer.ll"
index_status(yyextra)=1;  return T_VECT_END;
	YY_BREAK
case 117:
YY_RULE_SETUP
#line 422 "input_lexer.ll"
index_status(yyextra)=0;  if (rpn_mode(yyextra)||calc_mode(yyextra)==1) { (*yylval)=0; return T_VECT_DISPATCH; } if (xcas_mode(yyextra)==3 || abs_calc_mode(yyextra)==38){ (*yylval) = _LIST__VECT;  return T_VECT_DISPATCH; } if (xcas_mode(yyextra) > 0 ){ (*yylval)=_SET__VECT; return T_VECT_DISPATCH; } else return T_BLOC_BEGIN;
	YY_BREAK
case 118:
YY_RULE_SETUP
#line 423 "input_lexer.ll"
index_status(yyextra)=1; if (rpn_mode(yyextra) || calc_mode(yyextra)==1 || python_compat(yyextra)) return T_VECT_END; if (xcas_mode(yyextra)==3 || abs_calc_mode(yyextra)==38) return T_VECT_END; if (xcas_mode(yyextra) > 0) return T_VECT_END; else return T_BLOC_END;
	YY_BREAK
case 119:
YY_RULE_SETUP
#line 424 "input_lexer.ll"
index_status(yyextra)=0;  (*yylval)=_SET__VECT; return T_VECT_DISPATCH;
	YY_BREAK
case 120:
YY_RULE_SETUP
#line 425 "input_lexer.ll"
index_status(yyextra)=1; return T_VECT_END;
	YY_BREAK
case 121:
YY_RULE_SETUP
#line 426 "input_lexer.ll"
index_status(yyextra)=0; return T_ROOTOF_BEGIN;
	YY_BREAK
case 122:
YY_RULE_SETUP
#line 427 "input_lexer.ll"
index_status(yyextra)=1; return T_ROOTOF_END;
	YY_BREAK
case 123:
YY_RULE_SETUP
#line 428 "input_lexer.ll"
index_status(yyextra)=0; return T_SPOLY1_BEGIN;
	YY_BREAK
case 124:
YY_RULE_SETUP
#line 429 "input_lexer.ll"
index_status(yyextra)=1; return T_SPOLY1_END;
	YY_BREAK
case 125:
YY_RULE_SETUP
#line 430 "input_lexer.ll"
index_status(yyextra)=0; if (abs_calc_mode(yyextra)!=38){ (*yylval)=gen(at_rotate,2); return T_UNION; } ++in_rpn(yyextra); return T_RPN_BEGIN;
	YY_BREAK
case 126:
YY_RULE_SETUP
#line 431 "input_lexer.ll"
index_status(yyextra)=0; if (abs_calc_mode(yyextra)!=38){ (*yylval)=gen(at_shift,2); return T_UNION; } --in_rpn(yyextra); return T_RPN_END;
	YY_BREAK
/* binary operators */
case 127:
YY_RULE_SETUP
#line 434 "input_lexer.ll"
index_status(yyextra)=0; return T_MAPSTO;
	YY_BREAK
case 128:
YY_RULE_SETUP
#line 435 "input_lexer.ll"
(*yylval) = gen(at_couleur,2); index_status(yyextra)=0; return T_INTERVAL;
	YY_BREAK
case 129:
YY_RULE_SETUP
#line 436 "input_lexer.ll"
index_status(yyextra)=0; (*yylval)=gen(at_same,2); return T_TEST_EQUAL;
	YY_BREAK
case 130:
YY_RULE_SETUP
#line 437 "input_lexer.ll"
index_status(yyextra)=0; (*yylval)=gen(at_equal,2); return T_EQUAL;
	YY_BREAK
case 131:
YY_RULE_SETUP
#line 438 "input_lexer.ll"
index_status(yyextra)=0; (*yylval)=gen(at_deuxpoints,2); return T_DEUXPOINTS;
	YY_BREAK
case 132:
YY_RULE_SETUP
#line 439 "input_lexer.ll"
index_status(yyextra)=0; (*yylval)=gen(at_same,2); return T_QUOTED_BINARY;
	YY_BREAK
case 133:
YY_RULE_SETUP
#line 440 "input_lexer.ll"
index_status(yyextra)=0; (*yylval)=gen(at_same,2); return T_QUOTED_BINARY;
	YY_BREAK
case 134:
YY_RULE_SETUP
#line 441 "input_lexer.ll"
index_status(yyextra)=0; (*yylval)=gen(at_different,2); return T_TEST_EQUAL;
	YY_BREAK
case 135:
YY_RULE_SETUP
#line 442 "input_lexer.ll"
index_status(yyextra)=0; (*yylval)=gen(at_different,2); return T_QUOTED_BINARY;
	YY_BREAK
case 136:
YY_RULE_SETUP
#line 443 "input_lexer.ll"
index_status(yyextra)=0; (*yylval)=gen(at_different,2); return T_TEST_EQUAL;
	YY_BREAK
case 137:
YY_RULE_SETUP
#line 444 "input_lexer.ll"
index_status(yyextra)=0; (*yylval)=gen(at_different,2); return T_QUOTED_BINARY;
	YY_BREAK
case 138:
YY_RULE_SETUP
#line 445 "input_lexer.ll"
index_status(yyextra)=0; (*yylval)=gen(at_different,2); return T_QUOTED_BINARY;
	YY_BREAK
case 139:
YY_RULE_SETUP
#line 446 "input_lexer.ll"
index_status(yyextra)=0; (*yylval)=gen(at_inferieur_egal,2); return T_QUOTED_BINARY;
	YY_BREAK
case 140:
YY_RULE_SETUP
#line 447 "input_lexer.ll"
index_status(yyextra)=0; (*yylval)=gen(at_inferieur_egal,2); return T_QUOTED_BINARY;
	YY_BREAK
case 141:
YY_RULE_SETUP
#line 448 "input_lexer.ll"
index_status(yyextra)=0; (*yylval)=gen(at_inferieur_egal,2); return T_TEST_EQUAL;
	YY_BREAK
case 142:
YY_RULE_SETUP
#line 449 "input_lexer.ll"
index_status(yyextra)=0; (*yylval)=gen(at_inferieur_strict,2); return T_QUOTED_BINARY;
	YY_BREAK
case 143:
YY_RULE_SETUP
#line 450 "input_lexer.ll"
index_status(yyextra)=0; (*yylval)=gen(at_inferieur_strict,2); return T_QUOTED_BINARY;
	YY_BREAK
case 144:
YY_RULE_SETUP
#line 451 "input_lexer.ll"
index_status(yyextra)=0; (*yylval)=gen(at_superieur_strict,2); return T_QUOTED_BINARY;
	YY_BREAK
case 145:
YY_RULE_SETUP
#line 452 "input_lexer.ll"
index_status(yyextra)=0; (*yylval)=gen(at_superieur_egal,2); return T_TEST_EQUAL;
	YY_BREAK
case 146:
YY_RULE_SETUP
#line 453 "input_lexer.ll"
index_status(yyextra)=0; (*yylval)=gen(at_superieur_egal,2); return T_QUOTED_BINARY;
	YY_BREAK
case 147:
YY_RULE_SETUP
#line 454 "input_lexer.ll"
spread_formula(yyextra)=!index_status(yyextra); index_status(yyextra)=0; (*yylval)=gen(at_equal,2); return T_EQUAL;
	YY_BREAK
case 148:
YY_RULE_SETUP
#line 455 "input_lexer.ll"
spread_formula(yyextra)=!index_status(yyextra); index_status(yyextra)=0; (*yylval)=gen(at_equal2,2); return T_EQUAL;
	YY_BREAK
case 149:
YY_RULE_SETUP
#line 456 "input_lexer.ll"
index_status(yyextra)=0; (*yylval)=gen(at_equal,2); return T_QUOTED_BINARY;
	YY_BREAK
case 150:
YY_RULE_SETUP
#line 457 "input_lexer.ll"
index_status(yyextra)=0; (*yylval)=gen(at_dollar,2); if (xcas_mode(yyextra)>0) return T_DOLLAR_MAPLE; else return T_DOLLAR;
	YY_BREAK
case 151:
YY_RULE_SETUP
#line 458 "input_lexer.ll"
index_status(yyextra)=0; (*yylval)=gen(at_dollar,2); return T_DOLLAR_MAPLE;
	YY_BREAK
case 152:
YY_RULE_SETUP
#line 459 "input_lexer.ll"
index_status(yyextra)=0; (*yylval)=gen(at_dollar,2); return T_QUOTED_BINARY;
	YY_BREAK
case 153:
YY_RULE_SETUP
#line 460 "input_lexer.ll"
index_status(yyextra)=0; (*yylval)=gen(at_dollar,2); return T_QUOTED_BINARY;
	YY_BREAK
case 154:
YY_RULE_SETUP
#line 461 "input_lexer.ll"
index_status(yyextra)=0; (*yylval)=gen(at_sto,2); return T_AFFECT;
	YY_BREAK
case 155:
YY_RULE_SETUP
#line 462 "input_lexer.ll"
index_status(yyextra)=0; (*yylval)=gen(at_sto,2); return T_QUOTED_BINARY;
	YY_BREAK
case 156:
YY_RULE_SETUP
#line 463 "input_lexer.ll"
index_status(yyextra)=0; (*yylval)=gen(at_sto,2); return T_QUOTED_BINARY;
	YY_BREAK
case 157:
YY_RULE_SETUP
#line 464 "input_lexer.ll"
index_status(yyextra)=0; (*yylval)=gen(at_sto,2); return TI_STO;
	YY_BREAK
case 158:
YY_RULE_SETUP
#line 465 "input_lexer.ll"
index_status(yyextra)=0; (*yylval)=gen(at_sto,2); return TI_STO;
	YY_BREAK
case 159:
YY_RULE_SETUP
#line 466 "input_lexer.ll"
index_status(yyextra)=0; if (xcas_mode(yyextra)==3){ (*yylval)=gen(at_sto,2); return TI_STO; } else return T_MAPSTO;
	YY_BREAK
case 160:
YY_RULE_SETUP
#line 467 "input_lexer.ll"
index_status(yyextra)=0; (*yylval)=gen(at_sto,2); return TI_STO;
	YY_BREAK
case 161:
YY_RULE_SETUP
#line 468 "input_lexer.ll"
index_status(yyextra)=0; (*yylval)=gen(at_sto,2); return TI_STO;
	YY_BREAK
case 162:
YY_RULE_SETUP
#line 469 "input_lexer.ll"
index_status(yyextra)=0; (*yylval)=gen(at_array_sto,2); return T_AFFECT;
	YY_BREAK
case 163:
YY_RULE_SETUP
#line 470 "input_lexer.ll"
index_status(yyextra)=0; (*yylval)=gen(at_array_sto,2); return T_AFFECT;
	YY_BREAK
case 164:
YY_RULE_SETUP
#line 471 "input_lexer.ll"
index_status(yyextra)=1; yytext[0]='0'; (*yylval) = symb_double_deux_points(makevecteur(_IDNT_id_at,chartab2gen(yytext,yyextra))); return T_SYMBOL;
	YY_BREAK
case 165:
YY_RULE_SETUP
#line 472 "input_lexer.ll"
if (xcas_mode(yyextra)!=3) {index_status(yyextra)=0; (*yylval)=gen(at_compose,2); return T_COMPOSE; } BEGIN(comment_hash);
	YY_BREAK
case 166:
YY_RULE_SETUP
#line 473 "input_lexer.ll"
index_status(yyextra)=0; (*yylval)=gen(at_composepow,2); return T_POW;
	YY_BREAK
case 167:
YY_RULE_SETUP
#line 474 "input_lexer.ll"
index_status(yyextra)=0; (*yylval)=gen(at_composepow,2); return T_QUOTED_BINARY;
	YY_BREAK
case 168:
YY_RULE_SETUP
#line 475 "input_lexer.ll"
index_status(yyextra)=0; (*yylval)=gen(at_composepow,2); return T_QUOTED_BINARY;
	YY_BREAK
case 169:
YY_RULE_SETUP
#line 476 "input_lexer.ll"
index_status(yyextra)=0; (*yylval)=gen(at_compose,2); return T_QUOTED_BINARY;
	YY_BREAK
case 170:
YY_RULE_SETUP
#line 477 "input_lexer.ll"
index_status(yyextra)=0; (*yylval)=gen(at_compose,2); return T_QUOTED_BINARY;
	YY_BREAK
case 171:
YY_RULE_SETUP
#line 478 "input_lexer.ll"
index_status(yyextra)=0; (*yylval)=gen(at_and,2); return T_AND_OP;
	YY_BREAK
case 172:
YY_RULE_SETUP
#line 479 "input_lexer.ll"
index_status(yyextra)=0; (*yylval)=gen(at_and,2); return T_AND_OP;
	YY_BREAK
case 173:
YY_RULE_SETUP
#line 480 "input_lexer.ll"
index_status(yyextra)=0; (*yylval)=gen(at_and,2); return T_AND_OP;
	YY_BREAK
case 174:
YY_RULE_SETUP
#line 481 "input_lexer.ll"
index_status(yyextra)=0; (*yylval)=gen(at_and,2); return T_QUOTED_BINARY;
	YY_BREAK
case 175:
YY_RULE_SETUP
#line 482 "input_lexer.ll"
index_status(yyextra)=0; (*yylval)=gen(at_and,2); return T_QUOTED_BINARY;
	YY_BREAK
case 176:
YY_RULE_SETUP
#line 483 "input_lexer.ll"
index_status(yyextra)=0; (*yylval)=gen(at_and,2); return T_QUOTED_BINARY;
	YY_BREAK
case 177:
YY_RULE_SETUP
#line 484 "input_lexer.ll"
index_status(yyextra)=0; (*yylval)=gen(at_tilocal,2); return T_PIPE;
	YY_BREAK
case 178:
YY_RULE_SETUP
#line 485 "input_lexer.ll"
index_status(yyextra)=0; (*yylval)=gen(at_ou,2); return T_AND_OP;
	YY_BREAK
case 179:
YY_RULE_SETUP
#line 486 "input_lexer.ll"
index_status(yyextra)=0; (*yylval)=gen(at_ou,2); return T_QUOTED_BINARY;
	YY_BREAK
case 180:
YY_RULE_SETUP
#line 487 "input_lexer.ll"
index_status(yyextra)=0; (*yylval)=gen(at_ou,2); return T_QUOTED_BINARY;
	YY_BREAK
case 181:
YY_RULE_SETUP
#line 488 "input_lexer.ll"
index_status(yyextra)=0; (*yylval)=gen(at_ou,2); return T_QUOTED_BINARY;
	YY_BREAK
case 182:
YY_RULE_SETUP
#line 489 "input_lexer.ll"
index_status(yyextra)=0; (*yylval)=gen(at_ou,2); return T_AND_OP;
	YY_BREAK
case 183:
YY_RULE_SETUP
#line 490 "input_lexer.ll"
index_status(yyextra)=0; (*yylval)=gen(at_xor,2); return T_AND_OP;
	YY_BREAK
case 184:
YY_RULE_SETUP
#line 491 "input_lexer.ll"
index_status(yyextra)=0; (*yylval)=gen(at_xor,2); return T_QUOTED_BINARY;
	YY_BREAK
case 185:
YY_RULE_SETUP
#line 492 "input_lexer.ll"
index_status(yyextra)=0; (*yylval)=gen(at_xor,2); return T_QUOTED_BINARY;
	YY_BREAK
case 186:
YY_RULE_SETUP
#line 493 "input_lexer.ll"
index_status(yyextra)=0; (*yylval)=gen(at_xor,2); return T_AND_OP;
	YY_BREAK
case 187:
YY_RULE_SETUP
#line 494 "input_lexer.ll"
index_status(yyextra)=0; (*yylval)=gen(at_interval,2); return T_INTERVAL;
	YY_BREAK
case 188:
YY_RULE_SETUP
#line 495 "input_lexer.ll"
index_status(yyextra)=0; (*yylval)=gen(at_interval,2); return T_UNARY_OP;
	YY_BREAK
case 189:
YY_RULE_SETUP
#line 496 "input_lexer.ll"
index_status(yyextra)=0; (*yylval)=gen(at_interval,2); return T_INTERVAL;
	YY_BREAK
case 190:
YY_RULE_SETUP
#line 497 "input_lexer.ll"
index_status(yyextra)=0; (*yylval)=gen(at_interval,2); return T_QUOTED_BINARY;
	YY_BREAK
case 191:
YY_RULE_SETUP
#line 498 "input_lexer.ll"
index_status(yyextra)=0; (*yylval)=gen(at_interval,2); return T_QUOTED_BINARY;
	YY_BREAK
case 192:
YY_RULE_SETUP
#line 499 "input_lexer.ll"
if (xcas_mode(yyextra) || index_status(yyextra)) { (*yylval)=gen(at_factorial); return T_FACTORIAL; } else { index_status(yyextra)=0; (*yylval)=gen(at_not,1); return T_NOT; }
	YY_BREAK
/* standard functions */
case 193:
YY_RULE_SETUP
#line 502 "input_lexer.ll"
index_status(yyextra)=1; (*yylval)=symbolic(at_Ans,0); return T_LITERAL;
	YY_BREAK
case 194:
YY_RULE_SETUP
#line 503 "input_lexer.ll"
index_status(yyextra)=0; (*yylval)=gen(at_plus,2); return T_PLUS;
	YY_BREAK
case 195:
YY_RULE_SETUP
#line 504 "input_lexer.ll"
index_status(yyextra)=0; (*yylval)=gen(at_increment,1); return T_FACTORIAL;
	YY_BREAK
case 196:
YY_RULE_SETUP
#line 505 "input_lexer.ll"
index_status(yyextra)=0; (*yylval)=gen(at_increment,1); return T_UNION;
	YY_BREAK
case 197:
YY_RULE_SETUP
#line 506 "input_lexer.ll"
index_status(yyextra)=0; (*yylval)=gen(at_decrement,1); return T_FACTORIAL;
	YY_BREAK
case 198:
YY_RULE_SETUP
#line 507 "input_lexer.ll"
index_status(yyextra)=0; (*yylval)=gen(at_decrement,1); return T_UNION;
	YY_BREAK
case 199:
YY_RULE_SETUP
#line 508 "input_lexer.ll"
index_status(yyextra)=0; (*yylval)=gen(at_pointplus,2); return T_PLUS;
	YY_BREAK
case 200:
YY_RULE_SETUP
#line 509 "input_lexer.ll"
index_status(yyextra)=0; if (python_compat(yyextra)) { (*yylval)=gen(at_bitand,2); return T_AND_OP; } else { *yylval=gen(at_plus,2); return T_PLUS; }
	YY_BREAK
case 201:
YY_RULE_SETUP
#line 510 "input_lexer.ll"
index_status(yyextra)=0; (*yylval)=gen(at_bitnot,1); return T_NOT;
	YY_BREAK
case 202:
YY_RULE_SETUP
#line 511 "input_lexer.ll"
index_status(yyextra)=0; (*yylval)=gen(at_sqrt,2); return T_NOT;
	YY_BREAK
case 203:
YY_RULE_SETUP
#line 512 "input_lexer.ll"
index_status(yyextra)=0; (*yylval)=gen(at_polar_complex,2); return T_MOD;
	YY_BREAK
case 204:
YY_RULE_SETUP
#line 513 "input_lexer.ll"
index_status(yyextra)=1; (*yylval)=2; return T_SQ;
	YY_BREAK
case 205:
YY_RULE_SETUP
#line 514 "input_lexer.ll"
index_status(yyextra)=1; (*yylval)=3; return T_SQ;
	YY_BREAK
case 206:
YY_RULE_SETUP
#line 515 "input_lexer.ll"
index_status(yyextra)=1; (*yylval)=4; return T_SQ;
	YY_BREAK
case 207:
YY_RULE_SETUP
#line 516 "input_lexer.ll"
index_status(yyextra)=1; (*yylval)=5; return T_SQ;
	YY_BREAK
case 208:
YY_RULE_SETUP
#line 517 "input_lexer.ll"
index_status(yyextra)=1; (*yylval)=6; return T_SQ;
	YY_BREAK
case 209:
YY_RULE_SETUP
#line 518 "input_lexer.ll"
index_status(yyextra)=1; (*yylval)=7; return T_SQ;
	YY_BREAK
case 210:
YY_RULE_SETUP
#line 519 "input_lexer.ll"
index_status(yyextra)=1; (*yylval)=8; return T_SQ;
	YY_BREAK
case 211:
YY_RULE_SETUP
#line 520 "input_lexer.ll"
index_status(yyextra)=1; (*yylval)=9; return T_SQ;
	YY_BREAK
case 212:
YY_RULE_SETUP
#line 521 "input_lexer.ll"
index_status(yyextra)=1; (*yylval)=-1; return T_SQ;
	YY_BREAK
case 213:
YY_RULE_SETUP
#line 522 "input_lexer.ll"
index_status(yyextra)=1; (*yylval)=-1; return T_SQ;
	YY_BREAK
/* "','"                   index_status(yyextra)=0; (*yylval)=gen(at_makevector,2); return T_QUOTED_BINARY; commented because of f('a','b') */
case 214:
YY_RULE_SETUP
#line 524 "input_lexer.ll"
index_status(yyextra)=0; (*yylval)=gen(at_plus,2); return T_QUOTED_BINARY;
	YY_BREAK
case 215:
YY_RULE_SETUP
#line 525 "input_lexer.ll"
index_status(yyextra)=0; (*yylval)=gen(at_plus,2); return T_QUOTED_BINARY;
	YY_BREAK
case 216:
YY_RULE_SETUP
#line 526 "input_lexer.ll"
index_status(yyextra)=0; (*yylval)=gen(at_binary_minus,2); return T_MOINS; // return (calc_mode(yyextra)==38)?T_MOINS38:T_MOINS;
	YY_BREAK
case 217:
YY_RULE_SETUP
#line 527 "input_lexer.ll"
index_status(yyextra)=0; if (calc_mode(yyextra)==38){ (*yylval)=gen(at_neg,2); return T_NEG38; } else { CERR << 1 << endl; (*yylval)=gen(at_binary_minus,2); return T_MOINS;}
	YY_BREAK
case 218:
YY_RULE_SETUP
#line 528 "input_lexer.ll"
index_status(yyextra)=0; (*yylval)=gen(at_pointminus,2); return T_PLUS;
	YY_BREAK
case 219:
YY_RULE_SETUP
#line 529 "input_lexer.ll"
index_status(yyextra)=0; (*yylval)=gen(at_binary_minus,2); return T_QUOTED_BINARY;
	YY_BREAK
case 220:
YY_RULE_SETUP
#line 530 "input_lexer.ll"
index_status(yyextra)=0; (*yylval)=gen(at_binary_minus,2); return T_QUOTED_BINARY;
	YY_BREAK
/* "×"                     index_status(yyextra)=0; (*yylval)=gen(at_prod,2); return T_FOIS; */
case 221:
YY_RULE_SETUP
#line 532 "input_lexer.ll"
index_status(yyextra)=0; (*yylval)=gen(at_prod,2); return T_FOIS;
	YY_BREAK
case 222:
YY_RULE_SETUP
#line 533 "input_lexer.ll"
index_status(yyextra)=0; (*yylval)=gen(at_cross,2); return T_FOIS;
	YY_BREAK
case 223:
YY_RULE_SETUP
#line 534 "input_lexer.ll"
index_status(yyextra)=0; (*yylval)=gen(at_multcrement,1); return T_UNION;
	YY_BREAK
case 224:
YY_RULE_SETUP
#line 535 "input_lexer.ll"
index_status(yyextra)=0; if (abs_calc_mode(yyextra)==38){return T_DOUBLE_DEUX_POINTS; } else {(*yylval)=gen(at_struct_dot,2); return T_COMPOSE;}
	YY_BREAK
case 225:
YY_RULE_SETUP
#line 536 "input_lexer.ll"
index_status(yyextra)=0; (*yylval)=gen(at_ampersand_times,2); return T_FOIS;
	YY_BREAK
case 226:
YY_RULE_SETUP
#line 537 "input_lexer.ll"
index_status(yyextra)=0; (*yylval)=gen(at_quote_pow,2); return T_POW;
	YY_BREAK
case 227:
YY_RULE_SETUP
#line 538 "input_lexer.ll"
index_status(yyextra)=0; (*yylval)=gen(at_pointprod,2); return T_FOIS;
	YY_BREAK
case 228:
YY_RULE_SETUP
#line 539 "input_lexer.ll"
index_status(yyextra)=0; (*yylval)=gen(at_prod,2); return T_QUOTED_BINARY;
	YY_BREAK
case 229:
YY_RULE_SETUP
#line 540 "input_lexer.ll"
index_status(yyextra)=0; (*yylval)=gen(at_prod,2); return T_QUOTED_BINARY;
	YY_BREAK
case 230:
YY_RULE_SETUP
#line 541 "input_lexer.ll"
index_status(yyextra)=0; (*yylval)=gen(at_division,2); return T_DIV;
	YY_BREAK
case 231:
YY_RULE_SETUP
#line 542 "input_lexer.ll"
index_status(yyextra)=0; (*yylval)=gen(at_iquo,2); return T_DIV;
	YY_BREAK
case 232:
YY_RULE_SETUP
#line 543 "input_lexer.ll"
index_status(yyextra)=0; (*yylval)=gen(at_irem,2); return T_DIV;
	YY_BREAK
case 233:
YY_RULE_SETUP
#line 544 "input_lexer.ll"
index_status(yyextra)=0; (*yylval)=gen(at_iquosto,2); return T_UNION;
	YY_BREAK
case 234:
YY_RULE_SETUP
#line 545 "input_lexer.ll"
index_status(yyextra)=0; (*yylval)=gen(at_iremsto,2); return T_UNION;
	YY_BREAK
case 235:
YY_RULE_SETUP
#line 546 "input_lexer.ll"
index_status(yyextra)=0; (*yylval)=gen(at_andsto,2); return T_UNION;
	YY_BREAK
case 236:
YY_RULE_SETUP
#line 547 "input_lexer.ll"
index_status(yyextra)=0; (*yylval)=gen(at_orsto,2); return T_UNION;
	YY_BREAK
case 237:
YY_RULE_SETUP
#line 548 "input_lexer.ll"
index_status(yyextra)=0; (*yylval)=gen(at_xorsto,2); return T_UNION;
	YY_BREAK
case 238:
YY_RULE_SETUP
#line 549 "input_lexer.ll"
index_status(yyextra)=0; (*yylval)=gen(at_shiftsto,2); return T_UNION;
	YY_BREAK
case 239:
YY_RULE_SETUP
#line 550 "input_lexer.ll"
index_status(yyextra)=0; (*yylval)=gen(at_rotatesto,2); return T_UNION;
	YY_BREAK
case 240:
YY_RULE_SETUP
#line 551 "input_lexer.ll"
index_status(yyextra)=0; (*yylval)=gen(at_divcrement,1); return T_DIV;
	YY_BREAK
case 241:
YY_RULE_SETUP
#line 552 "input_lexer.ll"
index_status(yyextra)=0; (*yylval)=gen(at_pointdivision,2); return T_DIV;
	YY_BREAK
case 242:
YY_RULE_SETUP
#line 553 "input_lexer.ll"
index_status(yyextra)=0; (*yylval)=gen(at_division,2); return T_QUOTED_BINARY;
	YY_BREAK
case 243:
YY_RULE_SETUP
#line 554 "input_lexer.ll"
index_status(yyextra)=0; (*yylval)=gen(at_division,2); return T_QUOTED_BINARY;
	YY_BREAK
case 244:
YY_RULE_SETUP
#line 555 "input_lexer.ll"
index_status(yyextra)=0; if (abs_calc_mode(yyextra)==38){ (*yylval)=gen(at_PERCENT); return T_UNARY_OP_38; } if (xcas_mode(yyextra)==3 || calc_mode(yyextra)==1) { (*yylval)=gen(at_pourcent); return T_FACTORIAL; } if (xcas_mode(yyextra)==1) { (*yylval)=symbolic(at_ans,vecteur(0)); return T_NUMBER; }  if (xcas_mode(yyextra) || python_compat(yyextra)) (*yylval)=gen(at_irem,2); else (*yylval)=0; return T_MOD;
	YY_BREAK
case 245:
YY_RULE_SETUP
#line 556 "input_lexer.ll"
index_status(yyextra)=0; if (xcas_mode(yyextra)==0){ (*yylval)=gen(at_iquorem,2); return T_MOD;} (*yylval)=symbolic(at_ans,-2); return T_NUMBER; 
	YY_BREAK
/* \xe2\x88\xa1             index_status(yyextra)=0; (*yylval)=gen(at_polar_complex,2); return T_MOD; */
case 246:
YY_RULE_SETUP
#line 558 "input_lexer.ll"
if (xcas_mode(yyextra)==0){ (*yylval)=gen(at_quorem,2); return T_MOD;} index_status(yyextra)=0; (*yylval)=symbolic(at_ans,-3); return T_NUMBER; 
	YY_BREAK
case 247:
YY_RULE_SETUP
#line 559 "input_lexer.ll"
index_status(yyextra)=0; (*yylval)=gen(at_irem,2); return T_QUOTED_BINARY;
	YY_BREAK
case 248:
YY_RULE_SETUP
#line 560 "input_lexer.ll"
index_status(yyextra)=0; (*yylval)=gen(at_equal2,2); return T_QUOTED_BINARY;
	YY_BREAK
case 249:
YY_RULE_SETUP
#line 561 "input_lexer.ll"
index_status(yyextra)=0; if (xcas_mode(yyextra)==3) { (*yylval)=gen(at_irem,2); return T_UNARY_OP; } else { if (xcas_mode(yyextra)) (*yylval)=gen(at_irem,2); else (*yylval)=0; return T_MOD; }
	YY_BREAK
case 250:
YY_RULE_SETUP
#line 562 "input_lexer.ll"
index_status(yyextra)=0; (*yylval)=gen(at_irem,2); return T_QUOTED_BINARY;
	YY_BREAK
case 251:
YY_RULE_SETUP
#line 563 "input_lexer.ll"
index_status(yyextra)=0; (*yylval)=gen(at_irem,2); return T_QUOTED_BINARY;
	YY_BREAK
/* "MOD"                   index_status(yyextra)=0; return T_MOD; */
case 252:
YY_RULE_SETUP
#line 565 "input_lexer.ll"
index_status(yyextra)=0; (*yylval)=gen(python_compat(yyextra)==2?at_bitxor:at_pow,2); return T_POW;
	YY_BREAK
case 253:
YY_RULE_SETUP
#line 566 "input_lexer.ll"
index_status(yyextra)=0; (*yylval)=gen(at_trn,1); return T_FACTORIAL;
	YY_BREAK
case 254:
YY_RULE_SETUP
#line 567 "input_lexer.ll"
(*yylval) = gen(at_pow,2); index_status(yyextra)=0; return T_UNARY_OP;
	YY_BREAK
case 255:
YY_RULE_SETUP
#line 568 "input_lexer.ll"
index_status(yyextra)=0; (*yylval)=gen(at_pow,2); return T_POW;
	YY_BREAK
case 256:
YY_RULE_SETUP
#line 569 "input_lexer.ll"
index_status(yyextra)=0; (*yylval)=gen(at_pointpow,2); return T_POW;
	YY_BREAK
case 257:
YY_RULE_SETUP
#line 570 "input_lexer.ll"
index_status(yyextra)=0; (*yylval)=gen(at_pow,2); return T_QUOTED_BINARY;
	YY_BREAK
case 258:
YY_RULE_SETUP
#line 571 "input_lexer.ll"
index_status(yyextra)=0; (*yylval)=gen(at_pow,2); return T_QUOTED_BINARY;
	YY_BREAK
case 259:
YY_RULE_SETUP
#line 572 "input_lexer.ll"
(*yylval) = gen(at_Digits,0); index_status(yyextra)=0; return T_DIGITS;
	YY_BREAK
case 260:
YY_RULE_SETUP
#line 573 "input_lexer.ll"
(*yylval) = gen(at_HDigits,0); index_status(yyextra)=0; return T_DIGITS;
	YY_BREAK
case 261:
YY_RULE_SETUP
#line 574 "input_lexer.ll"
(*yylval) = gen(at_HAngle,0); index_status(yyextra)=0; return T_DIGITS;
	YY_BREAK
case 262:
YY_RULE_SETUP
#line 575 "input_lexer.ll"
(*yylval) = gen(at_HFormat,0); index_status(yyextra)=0; return T_DIGITS;
	YY_BREAK
case 263:
YY_RULE_SETUP
#line 576 "input_lexer.ll"
(*yylval) = gen(at_HComplex,0); index_status(yyextra)=0; return T_DIGITS;
	YY_BREAK
case 264:
YY_RULE_SETUP
#line 577 "input_lexer.ll"
(*yylval) = gen(at_HLanguage,0); index_status(yyextra)=0; return T_DIGITS;
	YY_BREAK
case 265:
YY_RULE_SETUP
#line 578 "input_lexer.ll"
(*yylval) = gen(at_Digits,0); index_status(yyextra)=0; return T_DIGITS;
	YY_BREAK
case 266:
YY_RULE_SETUP
#line 579 "input_lexer.ll"
(*yylval) = gen(at_threads,0) ; index_status(yyextra)=0; return T_DIGITS;
	YY_BREAK
case 267:
YY_RULE_SETUP
#line 580 "input_lexer.ll"
(*yylval) = gen(at_scientific_format,0); index_status(yyextra)=0; return T_DIGITS;
	YY_BREAK
case 268:
YY_RULE_SETUP
#line 581 "input_lexer.ll"
(*yylval) = gen(at_angle_radian,0); index_status(yyextra)=0; return T_DIGITS;
	YY_BREAK
case 269:
YY_RULE_SETUP
#line 582 "input_lexer.ll"
(*yylval) = gen(at_approx_mode,0); index_status(yyextra)=0; return T_DIGITS;
	YY_BREAK
case 270:
YY_RULE_SETUP
#line 583 "input_lexer.ll"
(*yylval) = gen(at_all_trig_solutions,1); index_status(yyextra)=0; return T_DIGITS;
	YY_BREAK
case 271:
YY_RULE_SETUP
#line 584 "input_lexer.ll"
(*yylval) = gen(at_increasing_power,1); index_status(yyextra)=0; return T_DIGITS;
	YY_BREAK
case 272:
YY_RULE_SETUP
#line 585 "input_lexer.ll"
(*yylval) = gen(at_ntl_on,1); index_status(yyextra)=0; return T_DIGITS;
	YY_BREAK
case 273:
YY_RULE_SETUP
#line 586 "input_lexer.ll"
(*yylval) = gen(at_complex_mode,1); index_status(yyextra)=0; return T_DIGITS;
	YY_BREAK
case 274:
YY_RULE_SETUP
#line 587 "input_lexer.ll"
(*yylval) = gen(at_step_infolevel,1); index_status(yyextra)=0; return T_DIGITS;
	YY_BREAK
case 275:
YY_RULE_SETUP
#line 588 "input_lexer.ll"
(*yylval) = gen(at_keep_algext,1); index_status(yyextra)=0; return T_DIGITS;
	YY_BREAK
case 276:
YY_RULE_SETUP
#line 589 "input_lexer.ll"
(*yylval) = gen(at_complex_variables,0); index_status(yyextra)=0; return T_DIGITS;
	YY_BREAK
case 277:
YY_RULE_SETUP
#line 590 "input_lexer.ll"
(*yylval) = gen(at_epsilon,0); index_status(yyextra)=0; return T_DIGITS;
	YY_BREAK
case 278:
YY_RULE_SETUP
#line 591 "input_lexer.ll"
(*yylval) = gen(at_proba_epsilon,0); index_status(yyextra)=0; return T_DIGITS;
	YY_BREAK
case 279:
YY_RULE_SETUP
#line 593 "input_lexer.ll"
(*yylval) = gen(at_acos,1); index_status(yyextra)=0; return T_UNARY_OP;
	YY_BREAK
case 280:
YY_RULE_SETUP
#line 594 "input_lexer.ll"
(*yylval) = gen(at_randNorm,1); index_status(yyextra)=0; return T_UNARY_OP;
	YY_BREAK
case 281:
YY_RULE_SETUP
#line 595 "input_lexer.ll"
(*yylval) = gen(at_acosh,1); index_status(yyextra)=0; return T_UNARY_OP;
	YY_BREAK
case 282:
YY_RULE_SETUP
#line 596 "input_lexer.ll"
index_status(yyextra)=0; (*yylval)=gen(at_args,0); return T_QUOTED_BINARY;
	YY_BREAK
case 283:
YY_RULE_SETUP
#line 597 "input_lexer.ll"
(*yylval) = gen(at_asin,1); index_status(yyextra)=0; return T_UNARY_OP;
	YY_BREAK
case 284:
YY_RULE_SETUP
#line 598 "input_lexer.ll"
(*yylval) = gen(at_asinh,1); index_status(yyextra)=0; return T_UNARY_OP;
	YY_BREAK
case 285:
YY_RULE_SETUP
#line 599 "input_lexer.ll"
(*yylval) = gen(at_at,2); index_status(yyextra)=0; return T_UNARY_OP;
	YY_BREAK
case 286:
YY_RULE_SETUP
#line 600 "input_lexer.ll"
(*yylval) = gen(at_atan,1); index_status(yyextra)=0; return T_UNARY_OP;
	YY_BREAK
case 287:
YY_RULE_SETUP
#line 601 "input_lexer.ll"
(*yylval) = gen(at_atanh,1); index_status(yyextra)=0; return T_UNARY_OP;
	YY_BREAK
case 288:
YY_RULE_SETUP
#line 602 "input_lexer.ll"
(*yylval) = gen(at_backquote,1); index_status(yyextra)=0; return T_UNARY_OP;
	YY_BREAK
case 289:
YY_RULE_SETUP
#line 603 "input_lexer.ll"
(*yylval) = gen(at_bloc,1); index_status(yyextra)=0; return T_UNARY_OP;
	YY_BREAK
case 290:
YY_RULE_SETUP
#line 604 "input_lexer.ll"
index_status(yyextra)=0; (*yylval)=gen(at_break,0); return T_BREAK;
	YY_BREAK
case 291:
YY_RULE_SETUP
#line 605 "input_lexer.ll"
index_status(yyextra)=0; if (abs_calc_mode(yyextra)==38) return T_CASE38; else return T_CASE;
	YY_BREAK
case 292:
YY_RULE_SETUP
#line 606 "input_lexer.ll"
(*yylval) = gen(at_cont,1); index_status(yyextra)=0; return T_UNARY_OP;
	YY_BREAK
case 293:
YY_RULE_SETUP
#line 607 "input_lexer.ll"
(*yylval) = gen(at_debug,1); index_status(yyextra)=0; return T_UNARY_OP;
	YY_BREAK
case 294:
YY_RULE_SETUP
#line 608 "input_lexer.ll"
(*yylval) = gen(at_derive,2); index_status(yyextra)=0; return T_UNARY_OP;
	YY_BREAK
case 295:
YY_RULE_SETUP
#line 609 "input_lexer.ll"
if (xcas_mode(yyextra)==1 || xcas_mode(yyextra)==2) { (*yylval) = gen(at_function_diff,1); index_status(yyextra)=1; return T_UNARY_OP;} else { index_status(yyextra)=1; return find_or_make_symbol(yytext,(*yylval),yyscanner,true,yyextra); }
	YY_BREAK
case 296:
YY_RULE_SETUP
#line 610 "input_lexer.ll"
if (xcas_mode(yyextra)==1 || xcas_mode(yyextra)==2) { (*yylval)=e__IDNT_e; }else (*yylval)=symbolic(at_exp,1); index_status(yyextra)=1; return T_NUMBER;
	YY_BREAK
case 297:
YY_RULE_SETUP
#line 611 "input_lexer.ll"
(*yylval)=symbolic(at_exp,1); index_status(yyextra)=1; return T_NUMBER;
	YY_BREAK
case 298:
YY_RULE_SETUP
#line 612 "input_lexer.ll"
(*yylval)=symbolic(at_exp,1); index_status(yyextra)=1; return T_NUMBER;
	YY_BREAK
case 299:
YY_RULE_SETUP
#line 613 "input_lexer.ll"
(*yylval) = gen(at_equal,2); index_status(yyextra)=0; return T_UNARY_OP;
	YY_BREAK
case 300:
YY_RULE_SETUP
#line 614 "input_lexer.ll"
index_status(yyextra)=0; (*yylval)=gen(at_throw,1); return T_RETURN;
	YY_BREAK
case 301:
YY_RULE_SETUP
#line 615 "input_lexer.ll"
(*yylval) = gen(at_erase,0); index_status(yyextra)=0; return T_UNARY_OP;
	YY_BREAK
case 302:
YY_RULE_SETUP
#line 616 "input_lexer.ll"
index_status(yyextra)=0; (*yylval)=gen(at_throw,1); return T_RETURN;
	YY_BREAK
case 303:
YY_RULE_SETUP
#line 617 "input_lexer.ll"
if (xcas_mode(yyextra)==3) (*yylval)=gen(at_partfrac); else (*yylval) = gen(at_expand,1); index_status(yyextra)=0; return T_UNARY_OP;
	YY_BREAK
case 304:
YY_RULE_SETUP
#line 618 "input_lexer.ll"
(*yylval) = gen(at_insmod,1); index_status(yyextra)=0; return T_RETURN;
	YY_BREAK
case 305:
YY_RULE_SETUP
#line 619 "input_lexer.ll"
(*yylval) = gen(at_expand,1); index_status(yyextra)=0; return T_UNARY_OP;
	YY_BREAK
case 306:
YY_RULE_SETUP
#line 620 "input_lexer.ll"
index_status(yyextra)=0; (*yylval)=gen(at_for,4); return T_FOR;
	YY_BREAK
case 307:
YY_RULE_SETUP
#line 621 "input_lexer.ll"
index_status(yyextra)=0; (*yylval)=gen(at_for,4); return T_FOR;
	YY_BREAK
case 308:
YY_RULE_SETUP
#line 622 "input_lexer.ll"
(*yylval) = gen(at_halt,1); index_status(yyextra)=0; return T_UNARY_OP;
	YY_BREAK
case 309:
YY_RULE_SETUP
#line 623 "input_lexer.ll"
index_status(yyextra)=0; (*yylval)=4; return T_BLOC_END;
	YY_BREAK
case 310:
YY_RULE_SETUP
#line 624 "input_lexer.ll"
index_status(yyextra)=0; (*yylval)=9; return T_BLOC_END;
	YY_BREAK
case 311:
YY_RULE_SETUP
#line 625 "input_lexer.ll"
index_status(yyextra)=0; (*yylval)=3; return T_BLOC_END;
	YY_BREAK
case 312:
YY_RULE_SETUP
#line 626 "input_lexer.ll"
index_status(yyextra)=0; (*yylval)=gen(at_ifte,3); return T_IF;
	YY_BREAK
case 313:
YY_RULE_SETUP
#line 627 "input_lexer.ll"
index_status(yyextra)=0; (*yylval)=gen(at_ifte,3); if (rpn_mode(yyextra)) return T_RPN_IF; return T_IF; 
	YY_BREAK
case 314:
YY_RULE_SETUP
#line 628 "input_lexer.ll"
index_status(yyextra)=0; (*yylval)=gen(at_ifte,3); return T_IFTE;
	YY_BREAK
case 315:
YY_RULE_SETUP
#line 629 "input_lexer.ll"
index_status(yyextra)=0; (*yylval)=gen(at_when,3); return T_IFTE;
	YY_BREAK
case 316:
YY_RULE_SETUP
#line 630 "input_lexer.ll"
index_status(yyextra)=0; (*yylval)=gen(at_ifte,3); return T_QUOTED_BINARY;
	YY_BREAK
case 317:
YY_RULE_SETUP
#line 631 "input_lexer.ll"
index_status(yyextra)=0; (*yylval)=gen(at_ifte,3); return T_QUOTED_BINARY;
	YY_BREAK
case 318:
YY_RULE_SETUP
#line 632 "input_lexer.ll"
index_status(yyextra)=0; (*yylval)=gen(at_ifte,3); return T_QUOTED_BINARY;
	YY_BREAK
case 319:
YY_RULE_SETUP
#line 633 "input_lexer.ll"
if (xcas_mode(yyextra)==1) (*yylval) = gen(at_maple_ifactors); else (*yylval) = gen(at_ifactors,1); index_status(yyextra)=0; return T_UNARY_OP;
	YY_BREAK
case 320:
YY_RULE_SETUP
#line 634 "input_lexer.ll"
index_status(yyextra)=0; (*yylval)=gen(at_intersect,2); return T_QUOTED_BINARY;
	YY_BREAK
case 321:
YY_RULE_SETUP
#line 635 "input_lexer.ll"
index_status(yyextra)=0; (*yylval)=gen(at_intersect,2); return T_QUOTED_BINARY;
	YY_BREAK
case 322:
YY_RULE_SETUP
#line 636 "input_lexer.ll"
(*yylval) = gen(at_kill,1); index_status(yyextra)=0; return T_UNARY_OP;
	YY_BREAK
case 323:
YY_RULE_SETUP
#line 637 "input_lexer.ll"
(*yylval) = gen(at_ln,1); index_status(yyextra)=1; return T_UNARY_OP; /* index_status(yyextra)=1 to accept log[] for a basis log */
	YY_BREAK
case 324:
YY_RULE_SETUP
#line 638 "input_lexer.ll"
(*yylval) = gen(at_asin,1); index_status(yyextra)=1; return T_UNARY_OP;
	YY_BREAK
case 325:
YY_RULE_SETUP
#line 639 "input_lexer.ll"
(*yylval) = gen(at_acos,1); index_status(yyextra)=1; return T_UNARY_OP;
	YY_BREAK
case 326:
YY_RULE_SETUP
#line 640 "input_lexer.ll"
(*yylval) = gen(at_atan,1); index_status(yyextra)=1; return T_UNARY_OP;
	YY_BREAK
case 327:
YY_RULE_SETUP
#line 641 "input_lexer.ll"
index_status(yyextra)=0; (*yylval)=gen(at_minus,2); return T_QUOTED_BINARY;
	YY_BREAK
case 328:
YY_RULE_SETUP
#line 642 "input_lexer.ll"
index_status(yyextra)=0; (*yylval)=gen(at_minus,2); return T_QUOTED_BINARY;
	YY_BREAK
case 329:
YY_RULE_SETUP
#line 643 "input_lexer.ll"
(*yylval) = gen(at_not,1); if (xcas_mode(yyextra) || python_compat(yyextra)) return T_NOT;  index_status(yyextra)=0; return T_UNARY_OP;
	YY_BREAK
case 330:
YY_RULE_SETUP
#line 644 "input_lexer.ll"
(*yylval) = gen(at_not,1); return T_NOT;  
	YY_BREAK
case 331:
YY_RULE_SETUP
#line 645 "input_lexer.ll"
(*yylval) = gen(at_not,1); return T_IN;  
	YY_BREAK
case 332:
YY_RULE_SETUP
#line 646 "input_lexer.ll"
(*yylval) = gen(at_neg,1); index_status(yyextra)=0; return T_UNARY_OP;
	YY_BREAK
case 333:
YY_RULE_SETUP
#line 647 "input_lexer.ll"
index_status(yyextra)=0; (*yylval)=gen(at_not,1); return T_QUOTED_BINARY;
	YY_BREAK
case 334:
YY_RULE_SETUP
#line 648 "input_lexer.ll"
index_status(yyextra)=0; (*yylval)=gen(at_not,1); return T_QUOTED_BINARY;
	YY_BREAK
case 335:
YY_RULE_SETUP
#line 649 "input_lexer.ll"
(*yylval) = gen(at_greduce,1); index_status(yyextra)=0; return T_UNARY_OP;
	YY_BREAK
case 336:
YY_RULE_SETUP
#line 650 "input_lexer.ll"
index_status(yyextra)=0; (*yylval)=gen(at_of,2); return T_QUOTED_BINARY;
	YY_BREAK
case 337:
YY_RULE_SETUP
#line 651 "input_lexer.ll"
if (xcas_mode(yyextra)==1) (*yylval) = gen(at_maple_op,1); else (*yylval) = gen(at_feuille,1); index_status(yyextra)=0; return T_UNARY_OP;
	YY_BREAK
case 338:
YY_RULE_SETUP
#line 652 "input_lexer.ll"
(*yylval) = gen(at_feuille,1); index_status(yyextra)=0; return T_UNARY_OP;
	YY_BREAK
case 339:
YY_RULE_SETUP
#line 653 "input_lexer.ll"
(*yylval)=2; index_status(yyextra)=0; return T_LOCAL;
	YY_BREAK
case 340:
YY_RULE_SETUP
#line 654 "input_lexer.ll"
(*yylval) = gen(at_pcoeff,1); index_status(yyextra)=0; return T_UNARY_OP;
	YY_BREAK
case 341:
YY_RULE_SETUP
#line 655 "input_lexer.ll"
(*yylval) = gen(at_funcplot,2); index_status(yyextra)=0; return T_UNARY_OP;
	YY_BREAK
case 342:
YY_RULE_SETUP
#line 656 "input_lexer.ll"
(*yylval) = gen(at_user_operator,6); index_status(yyextra)=0; return T_UNARY_OP;
	YY_BREAK
case 343:
YY_RULE_SETUP
#line 657 "input_lexer.ll"
if (rpn_mode(yyextra)) {(*yylval)=gen(at_purge,0); index_status(yyextra)=0; return T_RPN_OP;} else {(*yylval) = gen(at_purge,1); index_status(yyextra)=0; return T_UNARY_OP;};
	YY_BREAK
case 344:
YY_RULE_SETUP
#line 658 "input_lexer.ll"
if (rpn_mode(yyextra)) {(*yylval)=gen(at_purge,0); index_status(yyextra)=0; return T_RPN_OP;} else {(*yylval) = gen(at_purge,1); index_status(yyextra)=0; return T_UNARY_OP;};
	YY_BREAK
case 345:
YY_RULE_SETUP
#line 659 "input_lexer.ll"
if (rpn_mode(yyextra)) {(*yylval)=gen(at_purge,0); index_status(yyextra)=0; return T_RPN_OP;} else {(*yylval) = gen(at_purge,1); index_status(yyextra)=0; return T_UNARY_OP;};
	YY_BREAK
case 346:
YY_RULE_SETUP
#line 660 "input_lexer.ll"
(*yylval) = gen(at_srand,1); index_status(yyextra)=0; return T_RETURN;
	YY_BREAK
case 347:
YY_RULE_SETUP
#line 661 "input_lexer.ll"
(*yylval) = gen(at_for,1) ; index_status(yyextra)=0; return T_REPEAT;
	YY_BREAK
case 348:
YY_RULE_SETUP
#line 662 "input_lexer.ll"
(*yylval) = gen(at_for,1) ; index_status(yyextra)=0; return T_REPEAT;
	YY_BREAK
case 349:
YY_RULE_SETUP
#line 663 "input_lexer.ll"
(*yylval) = gen(at_for,1) ;index_status(yyextra)=0; return T_REPEAT;
	YY_BREAK
case 350:
YY_RULE_SETUP
#line 664 "input_lexer.ll"
(*yylval) = gen(at_return,1) ; index_status(yyextra)=0; return T_RETURN;
	YY_BREAK
case 351:
YY_RULE_SETUP
#line 665 "input_lexer.ll"
(*yylval) = gen(at_return,1) ; index_status(yyextra)=0; return T_RETURN;
	YY_BREAK
case 352:
YY_RULE_SETUP
#line 666 "input_lexer.ll"
(*yylval) = gen(at_return,1) ; index_status(yyextra)=0; return T_RETURN;
	YY_BREAK
case 353:
YY_RULE_SETUP
#line 667 "input_lexer.ll"
(*yylval) = gen(at_return,1) ; index_status(yyextra)=0; return T_QUOTED_BINARY;
	YY_BREAK
case 354:
YY_RULE_SETUP
#line 668 "input_lexer.ll"
(*yylval) = gen(at_maple_root,1); index_status(yyextra)=1; return T_UNARY_OP;
	YY_BREAK
case 355:
YY_RULE_SETUP
#line 669 "input_lexer.ll"
(*yylval) = gen(at_same,1); index_status(yyextra)=0; return T_UNARY_OP;
	YY_BREAK
case 356:
YY_RULE_SETUP
#line 670 "input_lexer.ll"
(*yylval) = gen(at_sst,1); index_status(yyextra)=0; return T_UNARY_OP;
	YY_BREAK
case 357:
YY_RULE_SETUP
#line 671 "input_lexer.ll"
(*yylval) = gen(at_sst_in,1); index_status(yyextra)=0; return T_UNARY_OP;
	YY_BREAK
case 358:
YY_RULE_SETUP
#line 672 "input_lexer.ll"
if (xcas_mode(yyextra)==1) (*yylval) = gen(at_maple_subs,2); else (*yylval) = gen(at_subs,2); index_status(yyextra)=0; return T_UNARY_OP;
	YY_BREAK
case 359:
YY_RULE_SETUP
#line 673 "input_lexer.ll"
if (xcas_mode(yyextra)==1) (*yylval) = gen(at_maple_subsop,2); else (*yylval) = gen(at_subsop,2); index_status(yyextra)=0; return T_UNARY_OP;
	YY_BREAK
case 360:
YY_RULE_SETUP
#line 674 "input_lexer.ll"
index_status(yyextra)=0; (*yylval)=gen(at_union,2); return T_QUOTED_BINARY;
	YY_BREAK
case 361:
YY_RULE_SETUP
#line 675 "input_lexer.ll"
index_status(yyextra)=0; (*yylval)=gen(at_union,2); return T_QUOTED_BINARY;
	YY_BREAK
case 362:
YY_RULE_SETUP
#line 676 "input_lexer.ll"
(*yylval) = gen(at_virgule,2); index_status(yyextra)=0; return T_UNARY_OP;
	YY_BREAK
case 363:
YY_RULE_SETUP
#line 677 "input_lexer.ll"
(*yylval) = gen(at_VARS,0); index_status(yyextra)=0; return T_UNARY_OP;
	YY_BREAK
case 364:
YY_RULE_SETUP
#line 678 "input_lexer.ll"
index_status(yyextra)=0; (*yylval)=gen(at_for,4); if (xcas_mode(yyextra)==3) return TI_WHILE; if (xcas_mode(yyextra)!=0) return T_MUPMAP_WHILE; return T_WHILE;
	YY_BREAK
case 365:
YY_RULE_SETUP
#line 679 "input_lexer.ll"
index_status(yyextra)=0; (*yylval)=gen(at_for,4); return T_MUPMAP_WHILE; /* return T_RPN_WHILE; */
	YY_BREAK
case 366:
YY_RULE_SETUP
#line 680 "input_lexer.ll"
index_status(yyextra)=0; (*yylval)=gen(at_for,4); return T_DO; /* must be here for DO ... END loop */
	YY_BREAK
case 367:
YY_RULE_SETUP
#line 681 "input_lexer.ll"
index_status(yyextra)=0; (*yylval)=gen(at_for,4); return T_DO; /* must be here for DO ... END loop */
	YY_BREAK
case 368:
YY_RULE_SETUP
#line 682 "input_lexer.ll"
(*yylval) = gen(at_Text,1); index_status(yyextra)=0; return T_RETURN;
	YY_BREAK
case 369:
YY_RULE_SETUP
#line 683 "input_lexer.ll"
(*yylval) = gen(at_DropDown,1); index_status(yyextra)=0; return T_RETURN;
	YY_BREAK
case 370:
YY_RULE_SETUP
#line 684 "input_lexer.ll"
(*yylval) = gen(at_Popup,1); index_status(yyextra)=0; return T_RETURN;
	YY_BREAK
case 371:
YY_RULE_SETUP
#line 685 "input_lexer.ll"
(*yylval) = gen(at_Request,1); index_status(yyextra)=0; return T_RETURN;
	YY_BREAK
case 372:
YY_RULE_SETUP
#line 686 "input_lexer.ll"
(*yylval) = gen(at_Title,1); index_status(yyextra)=0; return T_RETURN;
	YY_BREAK
case 373:
YY_RULE_SETUP
#line 687 "input_lexer.ll"
(*yylval)=0; index_status(yyextra)=0; return TI_PRGM;
	YY_BREAK
case 374:
YY_RULE_SETUP
#line 688 "input_lexer.ll"
(*yylval)=0; index_status(yyextra)=0; return TI_PRGM;
	YY_BREAK
case 375:
YY_RULE_SETUP
#line 689 "input_lexer.ll"
(*yylval)=0; index_status(yyextra)=0; return TI_PRGM;
	YY_BREAK
case 376:
YY_RULE_SETUP
#line 690 "input_lexer.ll"
index_status(yyextra)=0; (*yylval)=gen(at_ifte,3); return T_IF;
	YY_BREAK
case 377:
YY_RULE_SETUP
#line 691 "input_lexer.ll"
(*yylval) = gen(at_return,1) ; index_status(yyextra)=0; return T_RETURN;
	YY_BREAK
case 378:
YY_RULE_SETUP
#line 692 "input_lexer.ll"
index_status(yyextra)=0; (*yylval)=gen(at_breakpoint,0); return T_BREAK;
	YY_BREAK
case 379:
YY_RULE_SETUP
#line 693 "input_lexer.ll"
index_status(yyextra)=0; (*yylval)=gen(at_for,0); return TI_LOOP;
	YY_BREAK
case 380:
YY_RULE_SETUP
#line 694 "input_lexer.ll"
index_status(yyextra)=0; (*yylval)=gen(at_for,0); return TI_FOR;
	YY_BREAK
case 381:
YY_RULE_SETUP
#line 695 "input_lexer.ll"
index_status(yyextra)=0; (*yylval)=gen(at_for,0); return TI_WHILE;
	YY_BREAK
case 382:
YY_RULE_SETUP
#line 696 "input_lexer.ll"
index_status(yyextra)=0; (*yylval)=gen(at_for,0); return T_CONTINUE;
	YY_BREAK
case 383:
YY_RULE_SETUP
#line 697 "input_lexer.ll"
(*yylval) = gen(at_print,1) ; index_status(yyextra)=0; return T_RETURN;
	YY_BREAK
case 384:
YY_RULE_SETUP
#line 698 "input_lexer.ll"
(*yylval) = gen(at_Pause,1) ; index_status(yyextra)=0; return T_RETURN;
	YY_BREAK
case 385:
YY_RULE_SETUP
#line 699 "input_lexer.ll"
(*yylval) = gen(at_label,1) ; index_status(yyextra)=0; return T_RETURN;
	YY_BREAK
case 386:
YY_RULE_SETUP
#line 700 "input_lexer.ll"
(*yylval) = gen(at_goto,1) ; index_status(yyextra)=0; return T_RETURN;
	YY_BREAK
case 387:
YY_RULE_SETUP
#line 701 "input_lexer.ll"
(*yylval) = gen(at_Dialog,1) ; index_status(yyextra)=0; return TI_DIALOG; 
	YY_BREAK
case 388:
YY_RULE_SETUP
#line 702 "input_lexer.ll"
(*yylval) = gen(at_Row,0) ; index_status(yyextra)=0; return T_DIGITS;
	YY_BREAK
case 389:
YY_RULE_SETUP
#line 703 "input_lexer.ll"
(*yylval) = gen(at_Col,0) ; index_status(yyextra)=0; return T_DIGITS;
	YY_BREAK
case 390:
YY_RULE_SETUP
#line 705 "input_lexer.ll"
index_status(yyextra)=0; (*yylval)=gen(at_DELTALIST); return T_UNARY_OP_38; 
	YY_BREAK
case 391:
YY_RULE_SETUP
#line 706 "input_lexer.ll"
index_status(yyextra)=0; (*yylval)=gen(at_PILIST); return T_UNARY_OP_38; 
	YY_BREAK
case 392:
YY_RULE_SETUP
#line 707 "input_lexer.ll"
index_status(yyextra)=0;(*yylval)=gen(at_HPSUM); return T_UNARY_OP_38; 
	YY_BREAK
case 393:
YY_RULE_SETUP
#line 708 "input_lexer.ll"
index_status(yyextra)=0; (*yylval)=gen(at_SIGMALIST); return T_UNARY_OP_38;
	YY_BREAK
case 394:
YY_RULE_SETUP
#line 709 "input_lexer.ll"
index_status(yyextra)=0;(*yylval)=gen(at_HPDIFF); return T_UNARY_OP_38; 
	YY_BREAK
case 395:
YY_RULE_SETUP
#line 710 "input_lexer.ll"
index_status(yyextra)=0;(*yylval)=gen(at_HPINT); return T_UNARY_OP_38; 
	YY_BREAK
case 396:
YY_RULE_SETUP
#line 711 "input_lexer.ll"
index_status(yyextra)=0; (*yylval)=gen(at_inferieur_egal,2); return T_TEST_EQUAL;
	YY_BREAK
case 397:
YY_RULE_SETUP
#line 712 "input_lexer.ll"
index_status(yyextra)=0; (*yylval)=gen(at_different,2); return T_TEST_EQUAL;
	YY_BREAK
case 398:
YY_RULE_SETUP
#line 713 "input_lexer.ll"
index_status(yyextra)=0; (*yylval)=gen(at_superieur_egal,2); return T_TEST_EQUAL;
	YY_BREAK
case 399:
YY_RULE_SETUP
#line 714 "input_lexer.ll"
index_status(yyextra)=0;(*yylval)=gen(at_product); return T_UNARY_OP; 
	YY_BREAK
/* old format for physical constants
"_hbar_"        (*yylval) = symbolic(at_unit,makevecteur(1.05457266e-34,_J_unit*_s_unit)); index_status(yyextra)=0; return T_SYMBOL;
"_c_"        (*yylval) = symbolic(at_unit,makevecteur(299792458,_m_unit/_s_unit)); index_status(yyextra)=0; return T_SYMBOL;
"_g_"        (*yylval) = symbolic(at_unit,makevecteur(9.80665,_m_unit*unitpow(_s_unit,-2))); index_status(yyextra)=0; return T_SYMBOL;
"_IO_" (*yylval) = symbolic(at_unit,makevecteur(1e-12,_W_unit*unitpow(_m_unit,-2))); index_status(yyextra)=0; return T_SYMBOL; 
"_epsilonox_" (*yylval) = 3.9; index_status(yyextra)=0; return T_SYMBOL; 
"_epsilonsi_" (*yylval) = 11.9; index_status(yyextra)=0; return T_SYMBOL; 
"_qepsilon0_" (*yylval) = symbolic(at_unit,makevecteur(1.4185979e-30,_F_unit*_C_unit/_m_unit)); index_status(yyextra)=0; return T_SYMBOL; 
"_epsilon0q_" (*yylval) = symbolic(at_unit,makevecteur(55263469.6,_F_unit/(_m_unit*_C_unit))); index_status(yyextra)=0; return T_SYMBOL; 
"_kq_" (*yylval) = symbolic(at_unit,makevecteur(8.617386e-5,_J_unit/(_K_unit*_C_unit))); index_status(yyextra)=0; return T_SYMBOL; 
"_c3_" (*yylval) = symbolic(at_unit,makevecteur(.002897756,_m_unit*_K_unit)); index_status(yyextra)=0; return T_SYMBOL; 
"_lambdac_" (*yylval) = symbolic(at_unit,makevecteur( 0.00242631058e-9,_m_unit)); index_status(yyextra)=0; return T_SYMBOL; 
"_f0_" (*yylval) = symbolic(at_unit,makevecteur(2.4179883e14,_Hz_unit)); index_status(yyextra)=0; return T_SYMBOL; 
"_lambda0_" (*yylval) = symbolic(at_unit,makevecteur(1239.8425e-9,_m_unit)); index_status(yyextra)=0; return T_SYMBOL; 
"_muN_" (*yylval) = symbolic(at_unit,makevecteur(5.0507866e-27,_J_unit/_T_unit)); index_status(yyextra)=0; return T_SYMBOL; 
"_muB_" (*yylval) = symbolic(at_unit,makevecteur( 9.2740154e-24,_J_unit/_T_unit)); index_status(yyextra)=0; return T_SYMBOL; 
"_a0_" (*yylval) = symbolic(at_unit,makevecteur(.0529177249e-9,_m_unit)); index_status(yyextra)=0; return T_SYMBOL; 
"_Rinfinity_" (*yylval) = symbolic(at_unit,makevecteur(10973731.534,unitpow(_m_unit,-1))); index_status(yyextra)=0; return T_SYMBOL; 
"_Faraday_" (*yylval) = symbolic(at_unit,makevecteur(96485.309,_C_unit/_mol_unit)); index_status(yyextra)=0; return T_SYMBOL; 
"_phi_" (*yylval) = symbolic(at_unit,makevecteur(2.06783461e-15,_Wb_unit)); index_status(yyextra)=0; return T_SYMBOL; 
"_alpha_" (*yylval) = 7.29735308e-3; index_status(yyextra)=0; return T_SYMBOL; 
"_mpme_" (*yylval) = 1836.152701; index_status(yyextra)=0; return T_SYMBOL; 
"_mp_" (*yylval) = symbolic(at_unit,makevecteur(1.6726231e-27,_kg_unit)); index_status(yyextra)=0; return T_SYMBOL; 
"_qme_" (*yylval) = symbolic(at_unit,makevecteur(1.75881962e11,_C_unit/_kg_unit)); index_status(yyextra)=0; return T_SYMBOL; 
"_me_" (*yylval) = symbolic(at_unit,makevecteur(9.1093897e-31,_kg_unit)); index_status(yyextra)=0; return T_SYMBOL; 
"_qe_" (*yylval) = symbolic(at_unit,makevecteur(1.60217733e-19,_C_unit)); index_status(yyextra)=0; return T_SYMBOL; 
"_h_" (*yylval) = symbolic(at_unit,makevecteur(6.6260755e-34,_J_unit*_s_unit)); index_status(yyextra)=0; return T_SYMBOL; 
"_G_" (*yylval) = symbolic(at_unit,makevecteur(6.67408e-11,unitpow(_m_unit,3)*unitpow(_s_unit,-2)*unitpow(_kg_unit,-1))); index_status(yyextra)=0; return T_SYMBOL; 
"_mu0_" (*yylval) = symbolic(at_unit,makevecteur(1.25663706144e-6,_H_unit/_m_unit)); index_status(yyextra)=0; return T_SYMBOL; 
"_epsilon0_" (*yylval) = symbolic(at_unit,makevecteur(8.85418781761e-12,_F_unit/_m_unit)); index_status(yyextra)=0; return T_SYMBOL; 
"_sigma_" (*yylval) = symbolic(at_unit,makevecteur( 5.67051e-8,_W_unit*unitpow(_m_unit,-2)*unitpow(_K_unit,-4))); index_status(yyextra)=0; return T_SYMBOL; 
"_StdP_" (*yylval) = symbolic(at_unit,makevecteur(101325.0,_Pa_unit)); index_status(yyextra)=0; return T_SYMBOL; 
"_StdT_" (*yylval) = symbolic(at_unit,makevecteur(273.15,_K_unit)); index_status(yyextra)=0; return T_SYMBOL; 
"_R_" (*yylval) = symbolic(at_unit,makevecteur(8.31451,_J_unit/_molK_unit)); index_status(yyextra)=0; return T_SYMBOL; 
"_Vm_" (*yylval) = symbolic(at_unit,makevecteur(22.4141,_l_unit/_mol_unit)); index_status(yyextra)=0; return T_SYMBOL; 
"_k_" (*yylval) = symbolic(at_unit,makevecteur(1.380658e-23,_J_unit/_K_unit)); index_status(yyextra)=0; return T_SYMBOL; 
"_NA_" (*yylval) = symbolic(at_unit,makevecteur(6.0221367e23,unitpow(_mol_unit,-1))); index_status(yyextra)=0; return T_SYMBOL; 
"_mSun_" (*yylval) = symbolic(at_unit,makevecteur(1.989e30,_kg_unit)); index_status(yyextra)=0; return T_SYMBOL; 
"_RSun_" (*yylval) = symbolic(at_unit,makevecteur(6.955e8,_m_unit)); index_status(yyextra)=0; return T_SYMBOL; 
"_PSun_" (*yylval) = symbolic(at_unit,makevecteur(3.846e26,_W_unit)); index_status(yyextra)=0; return T_SYMBOL; 
"_mEarth_" (*yylval) = symbolic(at_unit,makevecteur(5.9736e24,_kg_unit)); index_status(yyextra)=0; return T_SYMBOL; 
"_REarth_" (*yylval) = symbolic(at_unit,makevecteur(6.371e6,_m_unit)); index_status(yyextra)=0; return T_SYMBOL; 
"_sd_" (*yylval) = symbolic(at_unit,makevecteur(8.61640905e4,_s_unit)); index_status(yyextra)=0; return T_SYMBOL; 
"_syr_" (*yylval) = symbolic(at_unit,makevecteur(3.15581498e7,_s_unit)); index_status(yyextra)=0; return T_SYMBOL; 
                        */
/* numbers, also accept DMS e.g 1°15′27″13 */
case 400:
#line 762 "input_lexer.ll"
case 401:
#line 763 "input_lexer.ll"
case 402:
#line 764 "input_lexer.ll"
case 403:
#line 765 "input_lexer.ll"
case 404:
#line 766 "input_lexer.ll"
case 405:
#line 767 "input_lexer.ll"
case 406:
#line 768 "input_lexer.ll"
case 407:
#line 769 "input_lexer.ll"
case 408:
#line 770 "input_lexer.ll"
case 409:
#line 771 "input_lexer.ll"
case 410:
#line 772 "input_lexer.ll"
case 411:
#line 773 "input_lexer.ll"
case 412:
#line 774 "input_lexer.ll"
case 413:
#line 775 "input_lexer.ll"
case 414:
#line 776 "input_lexer.ll"
case 415:
#line 777 "input_lexer.ll"
case 416:
#line 778 "input_lexer.ll"
case 417:
#line 779 "input_lexer.ll"
case 418:
#line 780 "input_lexer.ll"
case 419:
#line 781 "input_lexer.ll"
case 420:
#line 782 "input_lexer.ll"
case 421:
#line 783 "input_lexer.ll"
case 422:
#line 784 "input_lexer.ll"
case 423:
#line 785 "input_lexer.ll"
case 424:
YY_RULE_SETUP
#line 785 "input_lexer.ll"
{ 
  index_status(yyextra)=1;
  int l=strlen(yytext);
  int interv=0; // set to non-zero if ? in the number
  int dot=-1;
  for (int i=0;i<l;++i){
    if (yytext[i]=='?'){
      interv=i; // mark ? position and remove it from the string
      for (;i<l;++i){
	yytext[i]=yytext[i+1];
      }
      --l;
      break;
    }
    if (yytext[i]=='.')
      dot=i;
  }
  // CERR << yytext << " " << interv << endl;
  if (dot>=0 && interv>1){
    --interv; // interv is the relative precision of the interval
    if (interv && dot>=1 && yytext[dot-1]=='0')
      --interv;
    ++dot;
    while (interv && dot<l && yytext[dot]=='0'){
      --interv; ++dot;
    }
  }
  char ch,ch2;
  if (l>2 && yytext[1]!='x' && (yytext[l-1]=='o' || yytext[l-1]=='b' || yytext[l-1]=='h') ){
    char base=yytext[l-1];
    for (int i=l-1;i>1;--i){
      yytext[i]=yytext[i-1];
    }
    if (base=='h')
      base='x';
    yytext[1]=base;
  }
  else {
    for (l=0;(ch=*(yytext+l));++l){
      if (ch=='x')
	break;
      if (ch=='e' || ch=='E'){
	if ( (ch2=*(yytext+l+1)) && (ch2=='e' || ch2=='E')){
	  ++l;
	  for (;(ch=*(yytext+l));++l)
	    *(yytext+l-1)=ch;
	  *(yytext+l-1)=0;
	  --l;
	}
      }
#ifndef BCD
      if ( (ch==-30 && *(yytext+l+1)==-128) || (ch==-62 && *(yytext+l+1)==-80) ){
	*yylval=0; return T_NUMBER;
      }
#endif
      if (ch==-30 && *(yytext+l+1)==-120 &&  *(yytext+l+2)==-110){
	l += 3;
	for (;(ch=*(yytext+l));++l)
	  *(yytext+l-2)=ch;
	*(yytext+l-2)=0;
	l -= 3;
	*(yytext+l)='-';
      }
    }
  }
  (*yylval) = chartab2gen(yytext,yyextra); 
  if (interv){
    double d=evalf_double(*yylval,1,context0)._DOUBLE_val;
    if (d<0 && interv>1)
      --interv;
    double tmp=std::floor(std::log(absdouble(d))/std::log(10.0));
    tmp=(std::pow(10.,1+tmp-interv));
    *yylval=eval(gen(makevecteur(d-tmp,d+tmp),_INTERVAL__VECT),1,context0);
  }
  return T_NUMBER; 
}
	YY_BREAK
/* UNITS 
"_"{A}{AN}* {
  std::pair<const char * const * const,const char * const * const> pp=equal_range(unitname_tab,unitname_tab_end,yytext,tri2);
  if (pp.first!=pp.second && pp.second!=unitname_tab_end){
    gen tmp=mksa_register_unit(*pp.first,unitptr_tab[pp.first-unitname_tab]);
    (*yylval)=tmp;
    index_status(yyextra)=0;
    return T_SYMBOL;
  }
  int res=find_or_make_symbol(yytext+1,(*yylval),yyscanner,false,yyextra);
 (*yylval)=symb_unit(1,(*yylval),yyextra);
 return res;
}
			*/
/* symbols */
case 425:
#line 878 "input_lexer.ll"
case 426:
YY_RULE_SETUP
#line 878 "input_lexer.ll"
{
 index_status(yyextra)=1;
 int res=find_or_make_symbol(yytext,(*yylval),yyscanner,true,yyextra);
 if (res==T_NUMBER)
   *yylval=(*yylval)(string2gen(unlocalize(yytext),false),yyextra);
 return res;
} 
	YY_BREAK
case 427:
YY_RULE_SETUP
#line 885 "input_lexer.ll"
if (!xcas_mode(yyextra) || xcas_mode(yyextra)==3) { 
  // CERR << "hash" << endl;
  (*yylval)=gen(at_hash,1); return TI_HASH; 
} else BEGIN(comment_hash);
	YY_BREAK
case 428:
/* rule 428 can match eol */
YY_RULE_SETUP
#line 889 "input_lexer.ll"
BEGIN(INITIAL); index_status(yyextra)=0; increment_lexer_line_number_setcol(yyscanner,yyextra);  /* comment_s(yyextra)=string(yytext); (*yylval)=string2gen(comment_s(yyextra).substr(0,comment_s(yyextra).size()-1),false); return T_COMMENT; */
	YY_BREAK
/* everything else */
case 429:
YY_RULE_SETUP
#line 891 "input_lexer.ll"
(*yylval)=string2gen(string(yytext),false); return T_STRING;
	YY_BREAK
case 430:
YY_RULE_SETUP
#line 893 "input_lexer.ll"
ECHO;
	YY_BREAK
#line 4200 "input_lexer.cc"
case YY_STATE_EOF(INITIAL):
case YY_STATE_EOF(comment):
case YY_STATE_EOF(comment_hash):
case YY_STATE_EOF(str):
case YY_STATE_EOF(backquote):
	yyterminate();

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - yyg->yytext_ptr) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = yyg->yy_hold_char;
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed yyin at a new source and called
			 * giac_yylex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			yyg->yy_n_chars = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = yyin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( yyg->yy_c_buf_p <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			yyg->yy_c_buf_p = yyg->yytext_ptr + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state( yyscanner );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state , yyscanner);

			yy_bp = yyg->yytext_ptr + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++yyg->yy_c_buf_p;
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = yyg->yy_c_buf_p;
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer( yyscanner ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				yyg->yy_did_buffer_switch_on_eof = 0;

				if ( giac_yywrap(yyscanner ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * yytext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					yyg->yy_c_buf_p = yyg->yytext_ptr + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! yyg->yy_did_buffer_switch_on_eof )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				yyg->yy_c_buf_p =
					yyg->yytext_ptr + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state( yyscanner );

				yy_cp = yyg->yy_c_buf_p;
				yy_bp = yyg->yytext_ptr + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				yyg->yy_c_buf_p =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars];

				yy_current_state = yy_get_previous_state( yyscanner );

				yy_cp = yyg->yy_c_buf_p;
				yy_bp = yyg->yytext_ptr + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
} /* end of giac_yylex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	register char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	register char *source = yyg->yytext_ptr;
	register int number_to_move, i;
	int ret_val;

	if ( yyg->yy_c_buf_p > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( yyg->yy_c_buf_p - yyg->yytext_ptr - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) (yyg->yy_c_buf_p - yyg->yytext_ptr) - 1;

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars = 0;

	else
		{
			int num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER;

			int yy_c_buf_p_offset =
				(int) (yyg->yy_c_buf_p - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				int new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					giac_yyrealloc((void *) b->yy_ch_buf,b->yy_buf_size + 2 ,yyscanner );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = 0;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			yyg->yy_c_buf_p = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			yyg->yy_n_chars, (size_t) num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars;
		}

	if ( yyg->yy_n_chars == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			giac_yyrestart(yyin  ,yyscanner);
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if ((yy_size_t) (yyg->yy_n_chars + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		yy_size_t new_size = yyg->yy_n_chars + number_to_move + (yyg->yy_n_chars >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) giac_yyrealloc((void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf,new_size ,yyscanner );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
	}

	yyg->yy_n_chars += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars + 1] = YY_END_OF_BUFFER_CHAR;

	yyg->yytext_ptr = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (yyscan_t yyscanner)
{
	register yy_state_type yy_current_state;
	register char *yy_cp;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	yy_current_state = yyg->yy_start;

	for ( yy_cp = yyg->yytext_ptr + YY_MORE_ADJ; yy_cp < yyg->yy_c_buf_p; ++yy_cp )
		{
		register YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		if ( yy_accept[yy_current_state] )
			{
			yyg->yy_last_accepting_state = yy_current_state;
			yyg->yy_last_accepting_cpos = yy_cp;
			}
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 1316 )
				yy_c = yy_meta[(unsigned int) yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state , yyscan_t yyscanner)
{
	register int yy_is_jam;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner; /* This var may be unused depending upon options. */
	register char *yy_cp = yyg->yy_c_buf_p;

	register YY_CHAR yy_c = 1;
	if ( yy_accept[yy_current_state] )
		{
		yyg->yy_last_accepting_state = yy_current_state;
		yyg->yy_last_accepting_cpos = yy_cp;
		}
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 1316 )
			yy_c = yy_meta[(unsigned int) yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
	yy_is_jam = (yy_current_state == 1315);

	return yy_is_jam ? 0 : yy_current_state;
}

    static void yyunput (int c, register char * yy_bp , yyscan_t yyscanner)
{
	register char *yy_cp;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

    yy_cp = yyg->yy_c_buf_p;

	/* undo effects of setting up yytext */
	*yy_cp = yyg->yy_hold_char;

	if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
		{ /* need to shift things up to make room */
		/* +2 for EOB chars. */
		register int number_to_move = yyg->yy_n_chars + 2;
		register char *dest = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[
					YY_CURRENT_BUFFER_LVALUE->yy_buf_size + 2];
		register char *source =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move];

		while ( source > YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			*--dest = *--source;

		yy_cp += (int) (dest - source);
		yy_bp += (int) (dest - source);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars =
			yyg->yy_n_chars = YY_CURRENT_BUFFER_LVALUE->yy_buf_size;

		if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
			YY_FATAL_ERROR( "flex scanner push-back overflow" );
		}

	*--yy_cp = (char) c;

	yyg->yytext_ptr = yy_bp;
	yyg->yy_hold_char = *yy_cp;
	yyg->yy_c_buf_p = yy_cp;
}

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (yyscan_t yyscanner)
#else
    static int input  (yyscan_t yyscanner)
#endif

{
	int c;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	*yyg->yy_c_buf_p = yyg->yy_hold_char;

	if ( *yyg->yy_c_buf_p == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( yyg->yy_c_buf_p < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars] )
			/* This was really a NUL. */
			*yyg->yy_c_buf_p = '\0';

		else
			{ /* need more input */
			int offset = yyg->yy_c_buf_p - yyg->yytext_ptr;
			++yyg->yy_c_buf_p;

			switch ( yy_get_next_buffer( yyscanner ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					giac_yyrestart(yyin ,yyscanner);

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( giac_yywrap(yyscanner ) )
						return EOF;

					if ( ! yyg->yy_did_buffer_switch_on_eof )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput(yyscanner);
#else
					return input(yyscanner);
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					yyg->yy_c_buf_p = yyg->yytext_ptr + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) yyg->yy_c_buf_p;	/* cast for 8-bit char's */
	*yyg->yy_c_buf_p = '\0';	/* preserve yytext */
	yyg->yy_hold_char = *++yyg->yy_c_buf_p;

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * @param yyscanner The scanner object.
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void giac_yyrestart  (FILE * input_file , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	if ( ! YY_CURRENT_BUFFER ){
        giac_yyensure_buffer_stack (yyscanner);
		YY_CURRENT_BUFFER_LVALUE =
            giac_yy_create_buffer(yyin,YY_BUF_SIZE ,yyscanner);
	}

	giac_yy_init_buffer(YY_CURRENT_BUFFER,input_file ,yyscanner);
	giac_yy_load_buffer_state(yyscanner );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * @param yyscanner The scanner object.
 */
    void giac_yy_switch_to_buffer  (YY_BUFFER_STATE  new_buffer , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	/* TODO. We should be able to replace this entire function body
	 * with
	 *		giac_yypop_buffer_state();
	 *		giac_yypush_buffer_state(new_buffer);
     */
	giac_yyensure_buffer_stack (yyscanner);
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*yyg->yy_c_buf_p = yyg->yy_hold_char;
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = yyg->yy_c_buf_p;
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars;
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	giac_yy_load_buffer_state(yyscanner );

	/* We don't actually know whether we did this switch during
	 * EOF (giac_yywrap()) processing, but the only time this flag
	 * is looked at is after giac_yywrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	yyg->yy_did_buffer_switch_on_eof = 1;
}

static void giac_yy_load_buffer_state  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	yyg->yy_n_chars = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	yyg->yytext_ptr = yyg->yy_c_buf_p = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	yyin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	yyg->yy_hold_char = *yyg->yy_c_buf_p;
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * @param yyscanner The scanner object.
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE giac_yy_create_buffer  (FILE * file, int  size , yyscan_t yyscanner)
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) giac_yyalloc(sizeof( struct yy_buffer_state ) ,yyscanner );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in giac_yy_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) giac_yyalloc(b->yy_buf_size + 2 ,yyscanner );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in giac_yy_create_buffer()" );

	b->yy_is_our_buffer = 1;

	giac_yy_init_buffer(b,file ,yyscanner);

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with giac_yy_create_buffer()
 * @param yyscanner The scanner object.
 */
    void giac_yy_delete_buffer (YY_BUFFER_STATE  b , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		giac_yyfree((void *) b->yy_ch_buf ,yyscanner );

	giac_yyfree((void *) b ,yyscanner );
}

#ifndef __cplusplus
extern int isatty (int );
#endif /* __cplusplus */
    
/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a giac_yyrestart() or at EOF.
 */
    static void giac_yy_init_buffer  (YY_BUFFER_STATE  b, FILE * file , yyscan_t yyscanner)

{
	int oerrno = errno;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	giac_yy_flush_buffer(b ,yyscanner);

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then giac_yy_init_buffer was _probably_
     * called from giac_yyrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = file ? (isatty( fileno(file) ) > 0) : 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * @param yyscanner The scanner object.
 */
    void giac_yy_flush_buffer (YY_BUFFER_STATE  b , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		giac_yy_load_buffer_state(yyscanner );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  @param yyscanner The scanner object.
 */
void giac_yypush_buffer_state (YY_BUFFER_STATE new_buffer , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	if (new_buffer == NULL)
		return;

	giac_yyensure_buffer_stack(yyscanner);

	/* This block is copied from giac_yy_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*yyg->yy_c_buf_p = yyg->yy_hold_char;
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = yyg->yy_c_buf_p;
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars;
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		yyg->yy_buffer_stack_top++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from giac_yy_switch_to_buffer. */
	giac_yy_load_buffer_state(yyscanner );
	yyg->yy_did_buffer_switch_on_eof = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  @param yyscanner The scanner object.
 */
void giac_yypop_buffer_state (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	if (!YY_CURRENT_BUFFER)
		return;

	giac_yy_delete_buffer(YY_CURRENT_BUFFER ,yyscanner);
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if (yyg->yy_buffer_stack_top > 0)
		--yyg->yy_buffer_stack_top;

	if (YY_CURRENT_BUFFER) {
		giac_yy_load_buffer_state(yyscanner );
		yyg->yy_did_buffer_switch_on_eof = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void giac_yyensure_buffer_stack (yyscan_t yyscanner)
{
	int num_to_alloc;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	if (!yyg->yy_buffer_stack) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
		num_to_alloc = 1;
		yyg->yy_buffer_stack = (struct yy_buffer_state**)giac_yyalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								, yyscanner);
		if ( ! yyg->yy_buffer_stack )
			YY_FATAL_ERROR( "out of dynamic memory in giac_yyensure_buffer_stack()" );
								  
		memset(yyg->yy_buffer_stack, 0, num_to_alloc * sizeof(struct yy_buffer_state*));
				
		yyg->yy_buffer_stack_max = num_to_alloc;
		yyg->yy_buffer_stack_top = 0;
		return;
	}

	if (yyg->yy_buffer_stack_top >= (yyg->yy_buffer_stack_max) - 1){

		/* Increase the buffer to prepare for a possible push. */
		int grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = yyg->yy_buffer_stack_max + grow_size;
		yyg->yy_buffer_stack = (struct yy_buffer_state**)giac_yyrealloc
								(yyg->yy_buffer_stack,
								num_to_alloc * sizeof(struct yy_buffer_state*)
								, yyscanner);
		if ( ! yyg->yy_buffer_stack )
			YY_FATAL_ERROR( "out of dynamic memory in giac_yyensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset(yyg->yy_buffer_stack + yyg->yy_buffer_stack_max, 0, grow_size * sizeof(struct yy_buffer_state*));
		yyg->yy_buffer_stack_max = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * @param yyscanner The scanner object.
 * @return the newly allocated buffer state object. 
 */
YY_BUFFER_STATE giac_yy_scan_buffer  (char * base, yy_size_t  size , yyscan_t yyscanner)
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return 0;

	b = (YY_BUFFER_STATE) giac_yyalloc(sizeof( struct yy_buffer_state ) ,yyscanner );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in giac_yy_scan_buffer()" );

	b->yy_buf_size = size - 2;	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = 0;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	giac_yy_switch_to_buffer(b ,yyscanner );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to giac_yylex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * @param yyscanner The scanner object.
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       giac_yy_scan_bytes() instead.
 */
YY_BUFFER_STATE giac_yy_scan_string (yyconst char * yystr , yyscan_t yyscanner)
{
    
	return giac_yy_scan_bytes(yystr,strlen(yystr) ,yyscanner);
}

/** Setup the input buffer state to scan the given bytes. The next call to giac_yylex() will
 * scan from a @e copy of @a bytes.
 * @param yybytes the byte buffer to scan
 * @param _yybytes_len the number of bytes in the buffer pointed to by @a bytes.
 * @param yyscanner The scanner object.
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE giac_yy_scan_bytes  (yyconst char * yybytes, int  _yybytes_len , yyscan_t yyscanner)
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	int i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = _yybytes_len + 2;
	buf = (char *) giac_yyalloc(n ,yyscanner );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in giac_yy_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = giac_yy_scan_buffer(buf,n ,yyscanner);
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in giac_yy_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yy_fatal_error (yyconst char* msg , yyscan_t yyscanner)
{
    	(void) fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		yytext[yyleng] = yyg->yy_hold_char; \
		yyg->yy_c_buf_p = yytext + yyless_macro_arg; \
		yyg->yy_hold_char = *yyg->yy_c_buf_p; \
		*yyg->yy_c_buf_p = '\0'; \
		yyleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the user-defined data for this scanner.
 * @param yyscanner The scanner object.
 */
YY_EXTRA_TYPE giac_yyget_extra  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyextra;
}

/** Get the current line number.
 * @param yyscanner The scanner object.
 */
int giac_yyget_lineno  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    
        if (! YY_CURRENT_BUFFER)
            return 0;
    
    return yylineno;
}

/** Get the current column number.
 * @param yyscanner The scanner object.
 */
int giac_yyget_column  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    
        if (! YY_CURRENT_BUFFER)
            return 0;
    
    return yycolumn;
}

/** Get the input stream.
 * @param yyscanner The scanner object.
 */
FILE *giac_yyget_in  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyin;
}

/** Get the output stream.
 * @param yyscanner The scanner object.
 */
FILE *giac_yyget_out  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyout;
}

/** Get the length of the current token.
 * @param yyscanner The scanner object.
 */
int giac_yyget_leng  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyleng;
}

/** Get the current token.
 * @param yyscanner The scanner object.
 */

char *giac_yyget_text  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yytext;
}

/** Set the user-defined data. This data is never touched by the scanner.
 * @param user_defined The data to be associated with this scanner.
 * @param yyscanner The scanner object.
 */
void giac_yyset_extra (YY_EXTRA_TYPE  user_defined , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yyextra = user_defined ;
}

/** Set the current line number.
 * @param line_number
 * @param yyscanner The scanner object.
 */
void giac_yyset_lineno (int  line_number , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

        /* lineno is only valid if an input buffer exists. */
        if (! YY_CURRENT_BUFFER )
           yy_fatal_error( "giac_yyset_lineno called with no buffer" , yyscanner); 
    
    yylineno = line_number;
}

/** Set the current column.
 * @param line_number
 * @param yyscanner The scanner object.
 */
void giac_yyset_column (int  column_no , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

        /* column is only valid if an input buffer exists. */
        if (! YY_CURRENT_BUFFER )
           yy_fatal_error( "giac_yyset_column called with no buffer" , yyscanner); 
    
    yycolumn = column_no;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param in_str A readable stream.
 * @param yyscanner The scanner object.
 * @see giac_yy_switch_to_buffer
 */
void giac_yyset_in (FILE *  in_str , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yyin = in_str ;
}

void giac_yyset_out (FILE *  out_str , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yyout = out_str ;
}

int giac_yyget_debug  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yy_flex_debug;
}

void giac_yyset_debug (int  bdebug , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yy_flex_debug = bdebug ;
}

/* Accessor methods for yylval and yylloc */

YYSTYPE * giac_yyget_lval  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yylval;
}

void giac_yyset_lval (YYSTYPE *  yylval_param , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yylval = yylval_param;
}

/* User-visible API */

/* giac_yylex_init is special because it creates the scanner itself, so it is
 * the ONLY reentrant function that doesn't take the scanner as the last argument.
 * That's why we explicitly handle the declaration, instead of using our macros.
 */

int giac_yylex_init(yyscan_t* ptr_yy_globals)

{
    if (ptr_yy_globals == NULL){
        errno = EINVAL;
        return 1;
    }

    *ptr_yy_globals = (yyscan_t) giac_yyalloc ( sizeof( struct yyguts_t ), NULL );

    if (*ptr_yy_globals == NULL){
        errno = ENOMEM;
        return 1;
    }

    /* By setting to 0xAA, we expose bugs in yy_init_globals. Leave at 0x00 for releases. */
    memset(*ptr_yy_globals,0x00,sizeof(struct yyguts_t));

    return yy_init_globals ( *ptr_yy_globals );
}

/* giac_yylex_init_extra has the same functionality as giac_yylex_init, but follows the
 * convention of taking the scanner as the last argument. Note however, that
 * this is a *pointer* to a scanner, as it will be allocated by this call (and
 * is the reason, too, why this function also must handle its own declaration).
 * The user defined value in the first argument will be available to giac_yyalloc in
 * the yyextra field.
 */

int giac_yylex_init_extra(YY_EXTRA_TYPE yy_user_defined,yyscan_t* ptr_yy_globals )

{
    struct yyguts_t dummy_yyguts;

    giac_yyset_extra (yy_user_defined, &dummy_yyguts);

    if (ptr_yy_globals == NULL){
        errno = EINVAL;
        return 1;
    }
	
    *ptr_yy_globals = (yyscan_t) giac_yyalloc ( sizeof( struct yyguts_t ), &dummy_yyguts );
	
    if (*ptr_yy_globals == NULL){
        errno = ENOMEM;
        return 1;
    }
    
    /* By setting to 0xAA, we expose bugs in
    yy_init_globals. Leave at 0x00 for releases. */
    memset(*ptr_yy_globals,0x00,sizeof(struct yyguts_t));
    
    giac_yyset_extra (yy_user_defined, *ptr_yy_globals);
    
    return yy_init_globals ( *ptr_yy_globals );
}

static int yy_init_globals (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from giac_yylex_destroy(), so don't allocate here.
     */

    yyg->yy_buffer_stack = 0;
    yyg->yy_buffer_stack_top = 0;
    yyg->yy_buffer_stack_max = 0;
    yyg->yy_c_buf_p = (char *) 0;
    yyg->yy_init = 0;
    yyg->yy_start = 0;

    yyg->yy_start_stack_ptr = 0;
    yyg->yy_start_stack_depth = 0;
    yyg->yy_start_stack =  NULL;

/* Defined in main.c */
#ifdef YY_STDINIT
    yyin = stdin;
    yyout = stdout;
#else
    yyin = (FILE *) 0;
    yyout = (FILE *) 0;
#endif

    /* For future reference: Set errno on error, since we are called by
     * giac_yylex_init()
     */
    return 0;
}

/* giac_yylex_destroy is for both reentrant and non-reentrant scanners. */
int giac_yylex_destroy  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		giac_yy_delete_buffer(YY_CURRENT_BUFFER ,yyscanner );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		giac_yypop_buffer_state(yyscanner);
	}

	/* Destroy the stack itself. */
	giac_yyfree(yyg->yy_buffer_stack ,yyscanner);
	yyg->yy_buffer_stack = NULL;

    /* Destroy the start condition stack. */
        giac_yyfree(yyg->yy_start_stack ,yyscanner );
        yyg->yy_start_stack = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * giac_yylex() is called, initialization will occur. */
    yy_init_globals( yyscanner);

    /* Destroy the main struct (reentrant only). */
    giac_yyfree ( yyscanner , yyscanner );
    yyscanner = NULL;
    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, yyconst char * s2, int n , yyscan_t yyscanner)
{
	register int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * s , yyscan_t yyscanner)
{
	register int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *giac_yyalloc (yy_size_t  size , yyscan_t yyscanner)
{
	return (void *) malloc( size );
}

void *giac_yyrealloc  (void * ptr, yy_size_t  size , yyscan_t yyscanner)
{
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return (void *) realloc( (char *) ptr, size );
}

void giac_yyfree (void * ptr , yyscan_t yyscanner)
{
	free( (char *) ptr );	/* see giac_yyrealloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 893 "input_lexer.ll"



/*
 *  Routines
 */
#ifndef NO_NAMESPACE_GIAC
  namespace giac {
#endif // ndef NO_NAMESPACE_GIAC

    // Set the input string
    // export GIAC_DEBUG=-2 to renew static_lexer.h/static_extern.h
    YY_BUFFER_STATE set_lexer_string(const std::string &s_orig,yyscan_t & scanner,GIAC_CONTEXT){
#if 0
#ifdef NSPIRE
      FILE * f= fopen("/documents/log.tns","w"); // ends up in My Documents
      fprintf(f,"%s",s_orig.c_str());
      fclose(f);
#else
      ofstream of("log"); // ends up in fir/windows/log
      of << s_orig<< endl;
#endif
#endif
      if (abs_calc_mode(contextptr)==38 && s_orig==string(s_orig.size(),' '))
	giac_yyerror(scanner,"Void string");
#if !defined RTOS_THREADX && !defined NSPIRE && !defined FXCG
      if (!builtin_lexer_functions_sorted){
#ifndef STATIC_BUILTIN_LEXER_FUNCTIONS
	sort(builtin_lexer_functions_begin(),builtin_lexer_functions_end(),tri);
#endif
	builtin_lexer_functions_sorted=true;
	int nfunc=builtin_lexer_functions_number;
	if (debug_infolevel==-2 || debug_infolevel==-4 || debug_infolevel==-5){
	  CERR << "Writing " << nfunc << " in static_lexer.h and static_extern.h "<< endl;
	  CERR << "Check at_FP->at_FRAC, at_IP->at_INT, at_lgamma->at_lower_incomplete_gamma, at_is_inside->at_est_dans, at_regroup->at_regrouper, at_ugamma->at_upper_incomplete_gamma, at_∡ -> at_polar_complex, at_LINEAR? -> at_IS_LINEAR" << endl;
	  /*
	  ofstream static_add_ll("static_add.ll");
	  for (int i=0;i<nfunc;i++){
	    static_add_ll << "\"" << builtin_lexer_functions_begin()[i].first << "\" " ;
	    static_add_ll << "*yylval=gen(at_" << translate_at(builtin_lexer_functions_begin()[i].first) << ",0); index_status(yyextra)=0; ";
	    static_add_ll << "return " << signed(builtin_lexer_functions_begin()[i].second.subtype)+256 << ";" ;
            static_add_ll << endl;
	  }
	  static_add_ll.close();
	  */
	  ofstream static_lexer("static_lexer.h");
	  for (int i=0;i<nfunc;i++){
	    static_lexer << "{\"" << builtin_lexer_functions_begin()[i].first << "\",13," << signed(builtin_lexer_functions_begin()[i].second.subtype) ;
	    if (debug_infolevel==-2)
	      static_lexer << ",0,*((ulonglong *) at_" << translate_at(builtin_lexer_functions_begin()[i].first) << ")";
	    else
	      static_lexer << ",0,0"; 
	    if (builtin_lexer_functions_begin()[i].second._FUNCptr->quoted())
	      static_lexer << "| 1";
	    static_lexer << "}" ;
	    if (i!=nfunc-1)
	      static_lexer << ",";
	    static_lexer << endl;
	  }
	  static_lexer.close();
	  if (debug_infolevel==-4){
	    ofstream static_lexer_("static_lexer_.h");
	    for (int i=0;i<nfunc;i++){
	      static_lexer_ << "*((size_t *) at_" << translate_at(builtin_lexer_functions_begin()[i].first) << ")";
	      if (i!=nfunc-1)
		static_lexer_ << ",";
	      static_lexer_ << endl;
	    }
	    static_lexer_.close();
	  }
	  if (debug_infolevel==-5){
	    ofstream static_lexer_("static_lexer_at.h");
	    for (int i=0;i<nfunc;i++){
	      static_lexer_ << "res->push_back(*(size_t *)at_" << translate_at(builtin_lexer_functions_begin()[i].first) <<")";
	      if (i!=nfunc-1)
		static_lexer_ << ",";
	      static_lexer_ << endl;
	    }
	    static_lexer_.close();
	  }
	  ofstream static_extern("static_extern.h");
	  static_extern << "#ifndef STATIC_EXTERN" << endl;
	  static_extern << "#define STATIC_EXTERN" << endl;
	  static_extern << "namespace giac{" << endl;
	  static_extern << "struct unary_function_ptr;" << endl;
	  for (int i=0;i<nfunc;i++){
	    static_extern << "extern const unary_function_ptr * const  at_" << translate_at(builtin_lexer_functions_begin()[i].first) << ";" << endl;
	  }
	  static_extern << "}" << endl;
	  static_extern << "#endif // STATIC_EXTERN" << endl;
	  static_extern.close();
	}
      }
#endif // RTOS_THREADX
      string s(s_orig),lexer_string;
#if defined NSPIRE || defined FXCG
      for (unsigned i=0;i<s.size()-1;++i){
	if (s[i]==']' && s[i+1]=='['){
	  string tmp=s.substr(0,i+1)+string(",");
	  s=tmp+s.substr(i+1,s.size()-i-1);
	}
      }
#endif
      bool instring=false;
      // stupid match of bracket then parenthesis
      int l=s.size(),nb=0,np=0;
      int i=0;
      if (lexer_close_parenthesis(contextptr)){
	for (;i<l;++i){
	  if (!instring && i && s[i]=='/' && s[i-1]=='/'){
	    // skip comment until end of line
	    for (;i<l;++i){
	      if (s[i]==13)
		break;
	    }
	    continue;
	  }
	  if (!instring && i>=2 && ( (s[i-2]=='-' && s[i-1]=='-') || (s[i-2]=='+' && s[i-1]=='+') ) && (s[i]=='.'|| (s[i]>='0' && s[i]<='9')) ){
	    s[i-2]='+';
	    s[i-1]=' ';
	  }
	  if (!instring && i && s[i]=='*' && s[i-1]=='/'){
	    // skip comment 
	    for (;i<l;++i){
	      if (s[i]=='/' && s[i-1]=='*')
		break;
	    }
	    if (i==l){
	      s = s.substr(0,l-1)+"*/"+s[l-1];
	      CERR << "unfinished comment, adding */" << endl << s << endl;
	    }
	    continue;
	  }
	  if (!instring && s[i]==92){
	    i += 2;
	    if (i>=l)
	      break;
	  }
	  if (instring){
	    if (s[i]=='"'&& (i==0 || s[i-1]!='\\'))
	      instring=false;
	  }
	  else {
	    switch (s[i]){
	    case '"':
	      instring=i==0 || s[i-1]!='\\';
	      break;
	    case '(':
	      ++np;
	      break;
	    case ')':
	      --np;
	      break;
	    case '[':
	      ++nb;
	      break;
	    case ']':
	      --nb;
	      break;
	    }
	  }
	}
	if (nb<0)
	  *logptr(contextptr) << "Too many ]" << endl;
	if (np<0)
	  *logptr(contextptr) << "Too many )" << endl;
	while (np<0 && i>=0 && s[i-1]==')'){
	  --i;
	  ++np;
	}
	while (nb<0 && i>=0 && s[i-1]==']'){
	  --i;
	  ++nb;
	}
	s=s.substr(0,i);
	if (nb>0){
	  *logptr(contextptr) << "Warning adding " << nb << " ] at end of input" << endl;
	  s=s+string(nb,']');
	}
	if (np>0){
	  *logptr(contextptr) << "Warning adding " << np << " ) at end of input" << endl;
	  s=s+string(np,')');
	}
      }
      index_status(contextptr)=0;
      opened_quote(contextptr)=0;
      in_rpn(contextptr)=0;
      lexer_line_number(contextptr)=1;
      first_error_line(contextptr)=0;
      spread_formula(contextptr)=0;
      l=s.size();
      for (;l;l--){
	if (s[l-1]!=' ')
	  break;
      }
      // strings ending with :;
      while (l>=4 && s[l-1]==';' && s[l-2]==':'){
	// skip spaces before :;
	int m;
	for (m=l-3;m>0;--m){
	  if (s[m]!=' ')
	    break;
	}
	if (m<=1 || s[m]!=';')
	  break;
	if (s[m-1]==':')
	  l = m+1;
	else {
	  s[m]=':';
	  s[m+1]=';';
	  l=m+2;
	}
      }
      s=s.substr(0,l);
      /* if (l && ( (s[l-1]==';') || (s[l-1]==':')))
	 l--; */
      string ss;
      for (int i=0;i<l;++i){
	if (s[i]=='\\' && s[i+1]=='\n'){
	  ++i;
	  continue;
	}
	if (i && (unsigned char)s[i]==0xc2 && (unsigned char)s[i+1]!=0xb0)
	  ss += ' ';
	if ( (unsigned char)s[i]==0xef && i<l-3 ){
          if ((unsigned char)s[i+1]==0x80 && (unsigned char)s[i+2]==0x80 ){  
	    ss+='e';
	    i+=2;
	    continue;
	  }
	}
	if ( (unsigned char)s[i]==0xe2 && i<l-3 ){
	  if ((unsigned char)s[i+1]==134 && (unsigned char)s[i+2]==146){
	    // 0xe2 0x86 0x92
	    ss += ' ';
	    ss += s[i];
	    ++i;
	    ss += s[i];
	    ++i;
	    ss += s[i];
	    ss += ' ';
	    continue;
	  }
          if ((unsigned char)s[i+1]==0x89){ 
	    ss += ' ';
	    ss += s[i];
	    ++i;
	    ss += s[i];
	    ++i;
	    ss += s[i];
	    ss += ' ';
	    continue;
	  } // 0xe2 0x89	  
          if ((unsigned char)s[i+1]==0x88){ 
	    // mathop, add blank before and after except following an e/E 
	    if ((unsigned char) s[i+2]==0x91){ // sigma
	      ss += " SIGMA";
	      i +=2;
	      continue;
	    }
	    if ((unsigned char) s[i+2]==0x86){ // delta
	      ss += " DELTA";
	      i +=2;
	      continue;
	    }
	    if ((unsigned char) s[i+2]==0x8f){ // pi
	      ss += " PI";
	      i +=2;
	      continue;
	    }
	    if ( i>1 && (s[i-1]=='e' || s[i-1]=='E')){
	      ss +='-';
	      i +=2;
	      continue;
	    }
	    if (i>2  && (s[i-1]==' ' && (s[i-2]=='e' || s[i-2]=='E')) ){
	      ss[ss.size()-1] = '-';
	      i += 3;
	      continue;
	    }
	    ss += ' ';
	    ss += s[i];
	    ++i;
	    ss += s[i];
	    ++i;
	    ss += s[i];
	    ss += ' ';
	    continue;
	  } // 0xe2 0x88
          if ((unsigned char)s[i+1]==0x96 && ((unsigned char)s[i+2]==0xba || (unsigned char)s[i+2]==182 )){  
	    // sto 
	    ss += s[i];
	    ++i;
	    ss += s[i];
	    ++i;
	    ss += s[i];
	    ss += ' ';
	    continue;
	  } // 0xe2 0x96
          if ((unsigned char)s[i+1]==0x86 && (unsigned char)s[i+2]==0x92){  
	    // sto 
	    ss += s[i];
	    ++i;
	    ss += s[i];
	    ++i;
	    ss += s[i];
	    ss += ' ';
	    continue;
	  } // 0xe2 0x96
	} //end if s[i]=0xe2
	if (s[i]=='.'){
	  if ( i && (i<l-1) && (s[i-1]!=' ') && (s[i+1]=='.') ){
	    ss+= " ..";
	    ++i;
	  }
	  else
	    ss+='.';
	}
	else {
	  if (xcas_mode(contextptr) > 0 && xcas_mode(contextptr) !=3){
	    if (s[i]=='#')
	      ss += "//";
	    else
	      ss += s[i];
	  }
	  else
	    ss+=s[i];
	}
      }
      // ofstream of("log"); of << s << endl << ss << endl; of.close();
      if (debug_infolevel>2)
	CERR << "lexer " << ss << endl;
      lexer_string = ss+" \n ÿ";
      giac_yylex_init(&scanner);
      giac_yyset_extra(contextptr,scanner);
      currently_scanned(contextptr)=lexer_string;
      YY_BUFFER_STATE state=giac_yy_scan_string(lexer_string.c_str(),scanner);
      return state;
    }

    int delete_lexer_string(YY_BUFFER_STATE & state,yyscan_t & scanner){
      giac_yy_delete_buffer(state,scanner);
      giac_yylex_destroy(scanner);
      return 1;
    }
#ifdef STATIC_BUILTIN_LEXER_FUNCTIONS
    bool CasIsBuildInFunction(char const *s, gen &g){ 
      // binary search in builtin_lexer_functions
      int i=0, j=builtin_lexer_functions_number-1;
      int cmp;
      cmp= strcmp(s,builtin_lexer_functions[i].s);
      if (cmp==0) goto found; if (cmp<0) return false;
      cmp= strcmp(s,builtin_lexer_functions[j].s);
      if (cmp==0) { i=j; goto found; } if (cmp>0) return false;
      while (1){
        if (i+1>=j) return false;
        int mid= (i+j)/2;
        cmp= strcmp(s,builtin_lexer_functions[mid].s);
        if (cmp==0) { i=mid; goto found; } 
        if (cmp>0) i= mid; else j=mid;
      }
    found:
#if defined NSPIRE 
      g= gen(int((*builtin_lexer_functions_())[i]+builtin_lexer_functions[i]._FUNC_));
#else
      g= gen(int(builtin_lexer_functions_[i]+builtin_lexer_functions[i]._FUNC_));
#endif
      g= gen(*g._FUNCptr);
      return true;
    }
#endif

#ifndef NO_NAMESPACE_GIAC
  } // namespace giac
#endif // ndef NO_NAMESPACE_GIAC
  

